/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Directive, Input } from '@angular/core';
import { ComponentMessages } from '@progress/kendo-angular-l10n';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export class MessagesDirective extends ComponentMessages {
    /* Tabs */
    /**
     * The name of the "Home" toolbar tab
     */
    home;
    /**
     * The name of the "File" toolbar tab
     */
    file;
    /**
     * The name of the "Insert" toolbar tab
     */
    insert;
    /**
     * The name of the "Format" toolbar tab
     */
    formatTab;
    /**
     * The name of the "Data" toolbar tab
     */
    dataTab;
    /* Section of Tools Messages */
    /**
     * The title of the Save File tool
     */
    saveFile;
    /**
     * The title of the Load File tool
     */
    loadFile;
    /**
     * The title of the Bold tool
     */
    bold;
    /**
     * The title of the Data Validation tool
     */
    dataValidation;
    /**
     * The text of the Cell Range input label in the data validation dialog
     */
    validationCellRange;
    /**
     * The text of the Criteria dropdown list label in the data validation dialog.
     */
    validationCriteria;
    /**
     * The text of the Comparer dropdown list label in the data validation dialog.
     */
    validationComparer;
    /**
     * The text of the Min value label in the data validation dialog.
     */
    validationMinValue;
    /**
     * The text of the Max value label in the data validation dialog.
     */
    validationMaxValue;
    /**
     * The text of the Start value label in the data validation dialog.
     */
    validationStartValue;
    /**
     * The text of the End value label in the data validation dialog.
     */
    validationEndValue;
    /**
     * The text of the Value label in the data validation dialog.
     */
    validationValue;
    /**
     * The text for the Show list button checkbox label in the data validation dialog.
     */
    validationShowListButtonCheckbox;
    /**
     * The text for the Show date button checkbox label in the data validation dialog.
     */
    validationShowDateButtonCheckbox;
    /**
     * The text for the Ignore blank checkbox label in the data validation dialog.
     */
    validationIgnoreBlankCheckbox;
    /**
     * The text for the On invalid data label in the data validation dialog.
     */
    validationOnInvalidData;
    /**
     * The text for the Reject input radio button label in the data validation dialog.
     */
    validationRejectInput;
    /**
     * The text for the Show warning radio button label in the data validation dialog.
     */
    validationShowWarning;
    /**
     * The text for the Show hint checkbox label in the data validation dialog.
     */
    validationShowHint;
    /**
     * The text of the Any value validation criteria.
     */
    anyValueValidationCriteria;
    /**
     * The text of the Number validation criteria.
     */
    numberValidationCriteria;
    /**
     * The text of the Text validation criteria.
     */
    textValidationCriteria;
    /**
     * The text of the Date validation criteria.
     */
    dateValidationCriteria;
    /**
     * The text of the Custom Formula validation criteria.
     */
    customFormulaValidationCriteria;
    /**
     * The text of the List validation criteria.
     */
    listValidationCriteria;
    /**
     * The text of the greater than validation comparer.
     */
    greaterThanValidationComparer;
    /**
     * The text of the less than validation comparer.
     */
    lessThanValidationComparer;
    /**
     * The text of the between validation comparer.
     */
    betweenValidationComparer;
    /**
     * The text of the not between validation comparer.
     */
    notBetweenValidationComparer;
    /**
     * The text of the equal to validation comparer.
     */
    equalToValidationComparer;
    /**
     * The text of the not equal to validation comparer.
     */
    notEqualToValidationComparer;
    /**
     * The text of the greater than or equal to validation comparer.
     */
    greaterThanOrEqualToValidationComparer;
    /**
     * The text of the less than or equal to validation comparer.
     */
    lessThanOrEqualToValidationComparer;
    /**
     * The text for the Custom hint input label in the data validation dialog.
     */
    validationHintMessage;
    /**
     * The text for the Custom hint title input label in the data validation dialog.
     */
    validationHintTitle;
    /**
     * The title of the Italic tool
     */
    italic;
    /**
     * The title of the Underline tool
     */
    underline;
    /**
     * The title of the Format tool
     */
    format;
    /**
     * The title of the Font Family tool
     */
    fontFamily;
    /**
     * The title of the Font Size tool
     */
    fontSize;
    /**
     * The title of the Undo tool
     */
    undo;
    /**
     * The title of the Redo tool
     */
    redo;
    /**
     * The title of the tool that changes the text background color
     */
    background;
    /**
     * The title of the tool that changes the text font color
     */
    color;
    /**
     * The title of the Grid Lines tool
     */
    gridLines;
    /**
     * The title of the tool that adds new column before currently selected column
     */
    addColumnLeft;
    /**
     * The title of the tool that adds new column after currently selected column
     */
    addColumnRight;
    /**
     * The title of the tool that adds new row below currently selected row
     */
    addRowBelow;
    /**
     * The title of the tool that adds new row above currently selected row
     */
    addRowAbove;
    /**
     * The title of the tool that deletes a column
     */
    deleteColumn;
    /**
     * The title of the tool that deletes a row
     */
    deleteRow;
    /**
     * The title of the Text Wrap tool
     */
    wrap;
    /**
     * The title of the Text Align tool
     */
    align;
    /**
     * The title of the Text Align Horizontal tool
     */
    alignHorizontal;
    /**
     * The title of the Text Align Vertical tool
     */
    alignVertical;
    /**
     * The title of the Text Align Left tool
     */
    alignLeft;
    /**
     * The title of the Text Align Center tool
     */
    alignCenter;
    /**
     * The title of the Text Align Right tool
     */
    alignRight;
    /**
     * The title of the Text Align Justify tool
     */
    alignJustify;
    /**
     * The title of the Text Align Top tool
     */
    alignTop;
    /**
     * The title of the Text Align Middle tool
     */
    alignMiddle;
    /**
     * The title of the Text Align Bottom tool
     */
    alignBottom;
    /* Dialogs */
    /**
     * The text of the Apply button in all Spreadsheet dialogs
     */
    dialogApply;
    /* Dialogs */
    /**
     * The text of the Cancel button in all Spreadsheet dialogs
     */
    dialogCancel;
    /**
     * The text of the Delete button in the Delete sheet dialog
     */
    dialogDelete;
    /**
     * The text of the Rename button in the Rename sheet dialog
     */
    dialogRename;
    /**
     * The text of the **Insert** button in all Spreadsheet dialogs
     */
    dialogInsert;
    /**
     * The text of the **Remove** button in all Spreadsheet dialogs
     */
    dialogRemove;
    /**
     * The text of the **Remove link** button in the Link tool dialog
     */
    dialogRemoveLink;
    /**
     * The title of the Delete sheet dialog
     */
    delete;
    /**
     * The title of the Rename sheet dialog
     */
    rename;
    /**
     * The title of the Name Box input
     */
    nameBox;
    /**
     * The title of the Formula input
     */
    formulaInput;
    /**
     * The title of the Add new sheet button
     */
    addSheet;
    /**
     * The title of the Sheets menu button
     */
    sheetsMenu;
    /**
     * The text of the View toolbar tab
     */
    view;
    /**
     * The title of the Cells Merge tool
     */
    merge;
    /**
     * The title of the Merge horizontally tool
     */
    mergeHorizontally;
    /**
     * The title of the Merge vertically tool
     */
    mergeVertically;
    /**
     * The title of the Merge all tool
     */
    mergeAll;
    /**
     * The title of the Unmerge tool
     */
    unmerge;
    /**
     * The title of the tool that inserts a link
     */
    insertLink;
    /**
     * The title of the tool that inserts a link
     */
    increaseDecimal;
    /**
     * The title of the tool that inserts a link
     */
    decreaseDecimal;
    /**
     * The title of the tool that increases the cell font size
     */
    increaseFontSize;
    /**
     * The title of the tool that decreases the cell font size
     */
    decreaseFontSize;
    /**
     * The content of the dialog that warns about an unsupported file type
     */
    openUnsupported;
    /**
     * The content of the dialog that warns about modifying a merged cell
     */
    modifyMerged;
    /**
     * The content of the dialog that warns about modifying a disabled cell
     */
    cannotModifyDisabled;
    /**
     * The text of the **OK** dialog button
     */
    dialogOk;
    /**
     * The title of an error dialog
     */
    dialogError;
    /**
     * The content of the dialog that warns about duplicated sheet name
     */
    duplicateSheetName;
    /**
     * The Copy command text
     */
    copy;
    /**
     * The Cut command text
     */
    cut;
    /**
     * The Paste command text
     */
    paste;
    /**
     * The Hide row command text
     */
    hideRow;
    /**
     * The Unhide row command text
     */
    unhideRow;
    /**
     * The Hide column command text
     */
    hideColumn;
    /**
     * The Unhide column command text
     */
    unhideColumn;
    /**
     * The text of the Sheet menu Delete option
     */
    sheetDelete;
    /**
     * The text of the Sheet menu Rename option
     */
    sheetRename;
    /**
     * The text of the Sheet menu Hide option
     */
    sheetHide;
    /**
     * The text of the Sheet menu Duplicate option
     */
    sheetDuplicate;
    /**
     * The text of the Sheet menu Move Left option
     */
    sheetMoveLeft;
    /**
     * The text of the Sheet menu Move Right option
     */
    sheetMoveRight;
    /**
     * The content of the dialog that warns about invalid name input.
     *
     * The content consists of a two-part message - the input value and a localizable string.
     * For user value input **A1%**, the default dialog content will be **Invalid name: A1%**.
     *
     * To allow reordering the input value and the localizable part, the `invalidNameError` accepts a string with a
     * placeholder for the input value, for example, **{inputValue} is invalid**. The `{inputValue}` placeholder will be replaced
     * internally with the current value, and the resulting label will be rendered as **A1% is invalid**.
     */
    invalidNameError;
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MessagesDirective, deps: null, target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: MessagesDirective, isStandalone: true, selector: "[kendoSpreadsheetMessages]", inputs: { home: "home", file: "file", insert: "insert", formatTab: "formatTab", dataTab: "dataTab", saveFile: "saveFile", loadFile: "loadFile", bold: "bold", dataValidation: "dataValidation", validationCellRange: "validationCellRange", validationCriteria: "validationCriteria", validationComparer: "validationComparer", validationMinValue: "validationMinValue", validationMaxValue: "validationMaxValue", validationStartValue: "validationStartValue", validationEndValue: "validationEndValue", validationValue: "validationValue", validationShowListButtonCheckbox: "validationShowListButtonCheckbox", validationShowDateButtonCheckbox: "validationShowDateButtonCheckbox", validationIgnoreBlankCheckbox: "validationIgnoreBlankCheckbox", validationOnInvalidData: "validationOnInvalidData", validationRejectInput: "validationRejectInput", validationShowWarning: "validationShowWarning", validationShowHint: "validationShowHint", anyValueValidationCriteria: "anyValueValidationCriteria", numberValidationCriteria: "numberValidationCriteria", textValidationCriteria: "textValidationCriteria", dateValidationCriteria: "dateValidationCriteria", customFormulaValidationCriteria: "customFormulaValidationCriteria", listValidationCriteria: "listValidationCriteria", greaterThanValidationComparer: "greaterThanValidationComparer", lessThanValidationComparer: "lessThanValidationComparer", betweenValidationComparer: "betweenValidationComparer", notBetweenValidationComparer: "notBetweenValidationComparer", equalToValidationComparer: "equalToValidationComparer", notEqualToValidationComparer: "notEqualToValidationComparer", greaterThanOrEqualToValidationComparer: "greaterThanOrEqualToValidationComparer", lessThanOrEqualToValidationComparer: "lessThanOrEqualToValidationComparer", validationHintMessage: "validationHintMessage", validationHintTitle: "validationHintTitle", italic: "italic", underline: "underline", format: "format", fontFamily: "fontFamily", fontSize: "fontSize", undo: "undo", redo: "redo", background: "background", color: "color", gridLines: "gridLines", addColumnLeft: "addColumnLeft", addColumnRight: "addColumnRight", addRowBelow: "addRowBelow", addRowAbove: "addRowAbove", deleteColumn: "deleteColumn", deleteRow: "deleteRow", wrap: "wrap", align: "align", alignHorizontal: "alignHorizontal", alignVertical: "alignVertical", alignLeft: "alignLeft", alignCenter: "alignCenter", alignRight: "alignRight", alignJustify: "alignJustify", alignTop: "alignTop", alignMiddle: "alignMiddle", alignBottom: "alignBottom", dialogApply: "dialogApply", dialogCancel: "dialogCancel", dialogDelete: "dialogDelete", dialogRename: "dialogRename", dialogInsert: "dialogInsert", dialogRemove: "dialogRemove", dialogRemoveLink: "dialogRemoveLink", delete: "delete", rename: "rename", nameBox: "nameBox", formulaInput: "formulaInput", addSheet: "addSheet", sheetsMenu: "sheetsMenu", view: "view", merge: "merge", mergeHorizontally: "mergeHorizontally", mergeVertically: "mergeVertically", mergeAll: "mergeAll", unmerge: "unmerge", insertLink: "insertLink", increaseDecimal: "increaseDecimal", decreaseDecimal: "decreaseDecimal", increaseFontSize: "increaseFontSize", decreaseFontSize: "decreaseFontSize", openUnsupported: "openUnsupported", modifyMerged: "modifyMerged", cannotModifyDisabled: "cannotModifyDisabled", dialogOk: "dialogOk", dialogError: "dialogError", duplicateSheetName: "duplicateSheetName", copy: "copy", cut: "cut", paste: "paste", hideRow: "hideRow", unhideRow: "unhideRow", hideColumn: "hideColumn", unhideColumn: "unhideColumn", sheetDelete: "sheetDelete", sheetRename: "sheetRename", sheetHide: "sheetHide", sheetDuplicate: "sheetDuplicate", sheetMoveLeft: "sheetMoveLeft", sheetMoveRight: "sheetMoveRight", invalidNameError: "invalidNameError" }, usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MessagesDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoSpreadsheetMessages]',
                    standalone: true
                }]
        }], propDecorators: { home: [{
                type: Input
            }], file: [{
                type: Input
            }], insert: [{
                type: Input
            }], formatTab: [{
                type: Input
            }], dataTab: [{
                type: Input
            }], saveFile: [{
                type: Input
            }], loadFile: [{
                type: Input
            }], bold: [{
                type: Input
            }], dataValidation: [{
                type: Input
            }], validationCellRange: [{
                type: Input
            }], validationCriteria: [{
                type: Input
            }], validationComparer: [{
                type: Input
            }], validationMinValue: [{
                type: Input
            }], validationMaxValue: [{
                type: Input
            }], validationStartValue: [{
                type: Input
            }], validationEndValue: [{
                type: Input
            }], validationValue: [{
                type: Input
            }], validationShowListButtonCheckbox: [{
                type: Input
            }], validationShowDateButtonCheckbox: [{
                type: Input
            }], validationIgnoreBlankCheckbox: [{
                type: Input
            }], validationOnInvalidData: [{
                type: Input
            }], validationRejectInput: [{
                type: Input
            }], validationShowWarning: [{
                type: Input
            }], validationShowHint: [{
                type: Input
            }], anyValueValidationCriteria: [{
                type: Input
            }], numberValidationCriteria: [{
                type: Input
            }], textValidationCriteria: [{
                type: Input
            }], dateValidationCriteria: [{
                type: Input
            }], customFormulaValidationCriteria: [{
                type: Input
            }], listValidationCriteria: [{
                type: Input
            }], greaterThanValidationComparer: [{
                type: Input
            }], lessThanValidationComparer: [{
                type: Input
            }], betweenValidationComparer: [{
                type: Input
            }], notBetweenValidationComparer: [{
                type: Input
            }], equalToValidationComparer: [{
                type: Input
            }], notEqualToValidationComparer: [{
                type: Input
            }], greaterThanOrEqualToValidationComparer: [{
                type: Input
            }], lessThanOrEqualToValidationComparer: [{
                type: Input
            }], validationHintMessage: [{
                type: Input
            }], validationHintTitle: [{
                type: Input
            }], italic: [{
                type: Input
            }], underline: [{
                type: Input
            }], format: [{
                type: Input
            }], fontFamily: [{
                type: Input
            }], fontSize: [{
                type: Input
            }], undo: [{
                type: Input
            }], redo: [{
                type: Input
            }], background: [{
                type: Input
            }], color: [{
                type: Input
            }], gridLines: [{
                type: Input
            }], addColumnLeft: [{
                type: Input
            }], addColumnRight: [{
                type: Input
            }], addRowBelow: [{
                type: Input
            }], addRowAbove: [{
                type: Input
            }], deleteColumn: [{
                type: Input
            }], deleteRow: [{
                type: Input
            }], wrap: [{
                type: Input
            }], align: [{
                type: Input
            }], alignHorizontal: [{
                type: Input
            }], alignVertical: [{
                type: Input
            }], alignLeft: [{
                type: Input
            }], alignCenter: [{
                type: Input
            }], alignRight: [{
                type: Input
            }], alignJustify: [{
                type: Input
            }], alignTop: [{
                type: Input
            }], alignMiddle: [{
                type: Input
            }], alignBottom: [{
                type: Input
            }], dialogApply: [{
                type: Input
            }], dialogCancel: [{
                type: Input
            }], dialogDelete: [{
                type: Input
            }], dialogRename: [{
                type: Input
            }], dialogInsert: [{
                type: Input
            }], dialogRemove: [{
                type: Input
            }], dialogRemoveLink: [{
                type: Input
            }], delete: [{
                type: Input
            }], rename: [{
                type: Input
            }], nameBox: [{
                type: Input
            }], formulaInput: [{
                type: Input
            }], addSheet: [{
                type: Input
            }], sheetsMenu: [{
                type: Input
            }], view: [{
                type: Input
            }], merge: [{
                type: Input
            }], mergeHorizontally: [{
                type: Input
            }], mergeVertically: [{
                type: Input
            }], mergeAll: [{
                type: Input
            }], unmerge: [{
                type: Input
            }], insertLink: [{
                type: Input
            }], increaseDecimal: [{
                type: Input
            }], decreaseDecimal: [{
                type: Input
            }], increaseFontSize: [{
                type: Input
            }], decreaseFontSize: [{
                type: Input
            }], openUnsupported: [{
                type: Input
            }], modifyMerged: [{
                type: Input
            }], cannotModifyDisabled: [{
                type: Input
            }], dialogOk: [{
                type: Input
            }], dialogError: [{
                type: Input
            }], duplicateSheetName: [{
                type: Input
            }], copy: [{
                type: Input
            }], cut: [{
                type: Input
            }], paste: [{
                type: Input
            }], hideRow: [{
                type: Input
            }], unhideRow: [{
                type: Input
            }], hideColumn: [{
                type: Input
            }], unhideColumn: [{
                type: Input
            }], sheetDelete: [{
                type: Input
            }], sheetRename: [{
                type: Input
            }], sheetHide: [{
                type: Input
            }], sheetDuplicate: [{
                type: Input
            }], sheetMoveLeft: [{
                type: Input
            }], sheetMoveRight: [{
                type: Input
            }], invalidNameError: [{
                type: Input
            }] } });
