/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Directive } from '@angular/core';
import { ToolBarButtonComponent } from '@progress/kendo-angular-toolbar';
import { SpreadsheetLocalizationService } from '../../localization/spreadsheet-localization.service';
import { SpreadsheetService } from '../../common/spreadsheet.service';
import { SpreadsheetToolsService } from '../tools.service';
import { SpreadsheetCommandButton } from '../shared/spreadsheet-command-button';
import { DEFAULT_FONT_VALUES } from '../shared/constants';
import * as i0 from "@angular/core";
import * as i1 from "@progress/kendo-angular-toolbar";
import * as i2 from "../../localization/spreadsheet-localization.service";
import * as i3 from "../../common/spreadsheet.service";
import * as i4 from "../tools.service";
/**
 * @hidden
 */
export class SpreadsheetIncreaseFontSizeDirective extends SpreadsheetCommandButton {
    value;
    constructor(button, localization, spreadsheetService, toolsService) {
        super('increaseFontSize', button, localization, spreadsheetService, toolsService, {
            command: 'PropertyChangeCommand',
            options: { property: 'fontSize' }
        });
        this.value = DEFAULT_FONT_VALUES.fontSize;
    }
    clickHandler() {
        const newValue = this.value + 1;
        const options = {
            command: 'PropertyChangeCommand',
            options: { property: 'fontSize', value: newValue || null }
        };
        this.spreadsheetService.spreadsheet.executeCommand(options);
    }
    ngAfterViewInit() {
        this.value = this.toolsService.toolsState['fontSize'];
        this.subs.add(this.toolsService.stateChange.subscribe(state => {
            this.value = state['fontSize'];
        }));
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetIncreaseFontSizeDirective, deps: [{ token: i1.ToolBarButtonComponent }, { token: i2.SpreadsheetLocalizationService }, { token: i3.SpreadsheetService }, { token: i4.SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetIncreaseFontSizeDirective, isStandalone: true, selector: "kendo-toolbar-button[kendoSpreadsheetIncreaseFontSize]", usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetIncreaseFontSizeDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'kendo-toolbar-button[kendoSpreadsheetIncreaseFontSize]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1.ToolBarButtonComponent }, { type: i2.SpreadsheetLocalizationService }, { type: i3.SpreadsheetService }, { type: i4.SpreadsheetToolsService }]; } });
