/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Component, forwardRef, Inject } from '@angular/core';
import { NgIf } from '@angular/common';
import { ToolBarComponent, ToolBarToolComponent } from '@progress/kendo-angular-toolbar';
import { DialogService } from '@progress/kendo-angular-dialog';
import { IconWrapperComponent } from '@progress/kendo-angular-icons';
import { SpreadsheetLocalizationService } from '../../localization/spreadsheet-localization.service';
import { SpreadsheetService } from '../../common/spreadsheet.service';
import { SpreadsheetToolsService } from '../tools.service';
import { SpreadsheetDropDownToolBase } from '../shared/spreadsheet-dropdown-tools-base';
import { FontSizeDropDownListComponent } from './font-size-dropdownlist.component';
import * as i0 from "@angular/core";
import * as i1 from "@progress/kendo-angular-dialog";
import * as i2 from "../../localization/spreadsheet-localization.service";
import * as i3 from "../../common/spreadsheet.service";
import * as i4 from "../tools.service";
import * as i5 from "@progress/kendo-angular-toolbar";
/**
 * A component which configures an existing `DropDownListComponent` as a Spreadsheet tool
 * ([see example](ToDo).
 * The component associates a `kendo-toolbar-dropdownlist` with a Spreadsheet command that changes the font size of a content block and
 * automatically defines the options of the drop-down list and sets its values ([see example](ToDo).
 *
 * @hidden
 */
export class SpreadsheetFontSizeComponent extends SpreadsheetDropDownToolBase {
    constructor(dialogService, localization, spreadsheetService, toolsService, toolbar) {
        super('fontSize', dialogService, localization, spreadsheetService, toolsService, toolbar);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetFontSizeComponent, deps: [{ token: i1.DialogService }, { token: i2.SpreadsheetLocalizationService }, { token: i3.SpreadsheetService }, { token: i4.SpreadsheetToolsService }, { token: ToolBarComponent }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetFontSizeComponent, isStandalone: true, selector: "kendo-toolbar-dropdownlist[kendoSpreadsheetFontSize]", providers: [{ provide: ToolBarToolComponent, useExisting: forwardRef(() => SpreadsheetFontSizeComponent) }], usesInheritance: true, ngImport: i0, template: `
        <ng-template #toolbarTemplate>
            <kendo-spreadsheet-fontsize-dropdownlist
                #element
                [data]="data"
                [(value)]="value"
                [title]="messageFor(command)"
                [tabindex]="tabindex"
                (valueChange)="onValueChange($event)"></kendo-spreadsheet-fontsize-dropdownlist>
        </ng-template>
        <ng-template #popupTemplate>
            <div #popupButton
                [tabindex]="tabindex"
                role="menuitem"
                class="k-item k-menu-item"
                (click)="openDialog()">
                <span
                    class="k-link k-menu-link">
                    <kendo-icon-wrapper [name]="icon" [svgIcon]="svgIcon"></kendo-icon-wrapper>
                    <span *ngIf="messageFor(command)" class="k-menu-link-text">{{messageFor(command)}}</span>
                </span>
            </div>
        </ng-template>
        <ng-template #sectionTemplate>
            <kendo-spreadsheet-fontsize-dropdownlist
                #element
                [data]="data"
                [(value)]="value"
                [title]="messageFor(command)"
                [tabindex]="tabindex"
                (valueChange)="onValueChange($event)"></kendo-spreadsheet-fontsize-dropdownlist>
        </ng-template>
    `, isInline: true, dependencies: [{ kind: "component", type: FontSizeDropDownListComponent, selector: "kendo-spreadsheet-fontsize-dropdownlist" }, { kind: "component", type: IconWrapperComponent, selector: "kendo-icon-wrapper", inputs: ["name", "svgIcon", "innerCssClass", "customFontClass", "size"], exportAs: ["kendoIconWrapper"] }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetFontSizeComponent, decorators: [{
            type: Component,
            args: [{
                    providers: [{ provide: ToolBarToolComponent, useExisting: forwardRef(() => SpreadsheetFontSizeComponent) }],
                    selector: 'kendo-toolbar-dropdownlist[kendoSpreadsheetFontSize]',
                    template: `
        <ng-template #toolbarTemplate>
            <kendo-spreadsheet-fontsize-dropdownlist
                #element
                [data]="data"
                [(value)]="value"
                [title]="messageFor(command)"
                [tabindex]="tabindex"
                (valueChange)="onValueChange($event)"></kendo-spreadsheet-fontsize-dropdownlist>
        </ng-template>
        <ng-template #popupTemplate>
            <div #popupButton
                [tabindex]="tabindex"
                role="menuitem"
                class="k-item k-menu-item"
                (click)="openDialog()">
                <span
                    class="k-link k-menu-link">
                    <kendo-icon-wrapper [name]="icon" [svgIcon]="svgIcon"></kendo-icon-wrapper>
                    <span *ngIf="messageFor(command)" class="k-menu-link-text">{{messageFor(command)}}</span>
                </span>
            </div>
        </ng-template>
        <ng-template #sectionTemplate>
            <kendo-spreadsheet-fontsize-dropdownlist
                #element
                [data]="data"
                [(value)]="value"
                [title]="messageFor(command)"
                [tabindex]="tabindex"
                (valueChange)="onValueChange($event)"></kendo-spreadsheet-fontsize-dropdownlist>
        </ng-template>
    `,
                    standalone: true,
                    imports: [FontSizeDropDownListComponent, IconWrapperComponent, NgIf]
                }]
        }], ctorParameters: function () { return [{ type: i1.DialogService }, { type: i2.SpreadsheetLocalizationService }, { type: i3.SpreadsheetService }, { type: i4.SpreadsheetToolsService }, { type: i5.ToolBarComponent, decorators: [{
                    type: Inject,
                    args: [ToolBarComponent]
                }] }]; } });
