/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Range, Sheet, SpreadsheetWidget, Workbook } from "@progress/kendo-spreadsheet-common";
/**
 * The event data of the Spreadsheet `change` event.
 */
export interface SpreadsheetChangeEvent {
    /**
     * The selected `Range` in the active sheet.
     */
    range: Range;
    /**
     * The `SpreadsheetWidget` instance, used in the Spreadsheet component.
     */
    sender: SpreadsheetWidget;
}
/**
 * The event data of the Spreadsheet `excelExport` event.
 */
export interface SpreadsheetExcelExportEvent {
    /**
     * The `SpreadsheetWidget` instance.
     */
    sender: SpreadsheetWidget;
    /**
     * The Excel workbook configuration object. Modifications of the workbook will be reflected in the output Excel document.
     */
    workbook: Workbook;
    /**
     * If invoked, the Spreadsheet will not save the generated file.
     */
    preventDefault: Function;
}
/**
 * The event data of the Spreadsheet `excelImport` event.
 */
export interface SpreadsheetExcelImportEvent {
    /**
     * The `SpreadsheetWidget` instance.
     */
    sender: SpreadsheetWidget;
    /**
     * The selected file.
     */
    file: File | Blob;
    /**
     * If invoked, the Spreadsheet will not load the selected file.
     */
    preventDefault: Function;
}
/**
 * The event data of the Spreadsheet `activeSheetChange` event.
 */
export interface SpreadsheetActiveSheetChangeEvent {
    /**
     * The `SpreadsheetWidget` instance.
     */
    sender: SpreadsheetWidget;
    /**
     * The new active sheet.
     */
    sheet: Sheet;
}
