/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import * as i0 from '@angular/core';
import { Injectable, EventEmitter, Output, Inject, Optional, Component, Input, Directive, HostBinding, ElementRef, ViewChild, ViewChildren, HostListener, InjectionToken, forwardRef, ViewContainerRef, NgModule } from '@angular/core';
import { NgFor, NgIf, NgStyle, NgSwitch, NgSwitchCase, NgForOf } from '@angular/common';
import { Subject, Subscription } from 'rxjs';
import { take, map } from 'rxjs/operators';
import { validatePackage } from '@progress/kendo-licensing';
import { SpreadsheetWidget, registerEditor, Matrix, dateToSerial, validation, calc, serialToDate } from '@progress/kendo-spreadsheet-common';
import * as i1$4 from '@progress/kendo-angular-intl';
import { localeData } from '@progress/kendo-angular-intl';
import { formulaFxIcon, trashIcon, copyIcon, pencilIcon, eyeSlashIcon, arrowRightIcon, arrowLeftIcon, alignCenterIcon, alignJustifyIcon, alignLeftIcon, alignRightIcon, alignTopIcon, alignMiddleIcon, alignBottomIcon, dropletIcon, boldIcon, foregroundColorIcon, italicIcon, arrowRotateCwIcon, underlineIcon, arrowRotateCcwIcon, textWrapIcon, tableColumnInsertLeftIcon, tableColumnInsertRightIcon, tableRowInsertAboveIcon, tableRowInsertBelowIcon, tableRowDeleteIcon, tableColumnDeleteIcon, bordersNoneIcon, folderOpenIcon, downloadIcon, customFormatIcon, fontSizeIcon, fontFamilyIcon, cellsMergeIcon, cellsMergeHorizontallyIcon, cellsMergeVerticallyIcon, tableUnmergeIcon, linkIcon, fontGrowIcon, fontShrinkIcon, decimalDecreaseIcon, exclamationCircleIcon, decimalIncreaseIcon, cutIcon, clipboardIcon, eyeIcon, plusIcon, menuIcon, caretAltDownIcon, calendarIcon } from '@progress/kendo-svg-icons';
import * as i1 from '@progress/kendo-angular-l10n';
import { LocalizationService, L10N_PREFIX, RTL, ComponentMessages } from '@progress/kendo-angular-l10n';
import * as i1$1 from '@progress/kendo-angular-popup';
import { PopupService } from '@progress/kendo-angular-popup';
import { MenuComponent, MenuItemComponent, ContextMenuComponent } from '@progress/kendo-angular-menu';
import { EventsOutsideAngularDirective, isDocumentAvailable, isPresent, Keys, hasObservers, shouldShowValidationUI, WatermarkOverlayComponent, ResizeBatchService } from '@progress/kendo-angular-common';
import * as i1$2 from '@progress/kendo-angular-dialog';
import { DialogContentBase, DialogActionsComponent, DialogContainerService, DialogService, WindowService, WindowContainerService } from '@progress/kendo-angular-dialog';
import { IconWrapperComponent, IconsService } from '@progress/kendo-angular-icons';
import * as i1$3 from '@progress/kendo-angular-toolbar';
import { ToolBarToolComponent, ToolBarComponent, ToolBarButtonComponent, ToolBarButtonGroupComponent, ToolBarSeparatorComponent, ToolBarDropDownButtonComponent } from '@progress/kendo-angular-toolbar';
import { TextBoxComponent, ColorPickerComponent, CheckBoxComponent, RadioButtonComponent } from '@progress/kendo-angular-inputs';
import { LabelComponent } from '@progress/kendo-angular-label';
import { ButtonComponent, DropDownButtonComponent } from '@progress/kendo-angular-buttons';
import { TabStripComponent, TabStripTabComponent, TabTemplateDirective } from '@progress/kendo-angular-layout';
import { ComboBoxComponent, DropDownListComponent, ItemTemplateDirective } from '@progress/kendo-angular-dropdowns';
import { saveAs } from '@progress/kendo-file-saver';
import { Workbook } from '@progress/kendo-ooxml';
import * as i4 from '@angular/forms';
import { FormGroup, FormControl, Validators, ReactiveFormsModule } from '@angular/forms';
import { CalendarComponent as CalendarComponent$1 } from '@progress/kendo-angular-dateinputs';

/**
 * @hidden
 */
const packageMetadata = {
    name: '@progress/kendo-angular-spreadsheet',
    productName: 'Kendo UI for Angular',
    productCode: 'KENDOUIANGULAR',
    productCodes: ['KENDOUIANGULAR'],
    publishDate: 1749540215,
    version: '19.1.1',
    licensingDocsUrl: 'https://www.telerik.com/kendo-angular-ui/my-license/?utm_medium=product&utm_source=kendoangular&utm_campaign=kendo-ui-angular-purchase-license-keys-warning',
};

let spreadsheetCounter = 0;
/**
 * @hidden
 */
class SpreadsheetService {
    spreadsheet;
    sheetsChanged = new Subject();
    onSheetsBarFocus = new Subject();
    activeSheetChanged = new Subject();
    selectionChanged = new Subject();
    dialogContainer;
    constructor() {
        spreadsheetCounter++;
    }
    set currentActiveSheet(value) {
        this._currentActiveSheet = value;
    }
    get currentActiveSheet() {
        return this._currentActiveSheet;
    }
    get activeSheet() {
        return this.spreadsheet.activeSheet()?.name();
    }
    get formulaListId() {
        return `k-spreadsheet-${spreadsheetCounter}-formula-list`;
    }
    get tablistId() {
        return `k-spreadsheet-${spreadsheetCounter}-tablist`;
    }
    _currentActiveSheet;
    notifySheetsChange(actionType, sheetInfo) {
        const sheets = this.spreadsheet.sheets();
        this.sheetsChanged.next({ sheets, sheet: sheetInfo, actionType });
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return []; } });

/**
 * @hidden
 */
class SpreadsheetToolsService {
    ngZone;
    stateChange = new EventEmitter();
    set toolsState(state) {
        this._toolsState = state;
    }
    get toolsState() {
        return this._toolsState;
    }
    toolsFunctions = [
        'bold',
        'italic',
        'underline',
        'fontFamily',
        'fontSize',
        'color',
        'background',
        'textAlign',
        'verticalAlign',
        'wrap',
        'gridLines',
        'format'
    ];
    _toolsState = {};
    constructor(ngZone) {
        this.ngZone = ngZone;
    }
    updateTools = (e) => {
        this.ngZone.run(() => {
            const state = {};
            this.toolsFunctions.forEach(tool => {
                if (typeof e.range[tool] === 'function') {
                    state[tool] = e.range[tool]();
                }
                else if (tool === 'gridLines') {
                    state[tool] = e.range.sheet().showGridLines();
                }
            });
            if (this.toolsFunctions.some(k => state[k] !== this.toolsState[k])) {
                this.toolsState = state;
                this.stateChange.emit(state);
            }
        });
    };
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetToolsService, deps: [{ token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetToolsService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetToolsService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: i0.NgZone }]; }, propDecorators: { stateChange: [{
                type: Output
            }] } });

/**
 * @hidden
 */
class SpreadsheetLocalizationService extends LocalizationService {
    constructor(prefix, messageService, _rtl) {
        super(prefix, messageService, _rtl);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetLocalizationService, deps: [{ token: L10N_PREFIX }, { token: i1.MessageService, optional: true }, { token: RTL, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetLocalizationService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetLocalizationService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [L10N_PREFIX]
                }] }, { type: i1.MessageService, decorators: [{
                    type: Optional
                }] }, { type: undefined, decorators: [{
                    type: Optional
                }, {
                    type: Inject,
                    args: [RTL]
                }] }]; } });

/**
 * @hidden
 */
const mapToSheetDescriptor = (sheetsArray) => {
    return sheetsArray.map((sheet) => {
        return {
            activeCell: sheet.activeCell(),
            columns: sheet._columns,
            defaultCellStyle: sheet._defaultCellStyle,
            drawings: sheet._drawings,
            frozenColumns: sheet.frozenColumns,
            frozenRows: sheet.frozenRows,
            hyperlinks: sheet._hyperlinks,
            mergedCells: sheet.mergedCells,
            name: sheet.name(),
            rows: sheet._rows,
            selection: sheet.selection(),
            showGridLines: sheet.showGridLines,
            state: sheet.state()
        };
    });
};
/**
 * @hidden
 */
const replaceMessagePlaceholder = (message, name, value) => message.replace(new RegExp(`\{\\s*${name}\\s*\}`, 'g'), value);
/**
 * @hidden
 */
const rowAndColPresent = (value) => {
    return (value && value.row !== null && value.col !== null && value.row > -1 && value.col > -1);
};

/**
 * @hidden
 */
class FormulaListComponent {
    element;
    spreadsheetService;
    renderer;
    maxHeight;
    data = [];
    itemClick;
    formulaFxIcon = formulaFxIcon;
    constructor(element, spreadsheetService, renderer) {
        this.element = element;
        this.spreadsheetService = spreadsheetService;
        this.renderer = renderer;
    }
    ngOnInit() {
        this.renderer.setAttribute(this.element.nativeElement, 'id', this.spreadsheetService.formulaListId);
    }
    handleMouseDown = (ev) => {
        ev.preventDefault();
    };
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FormulaListComponent, deps: [{ token: i0.ElementRef }, { token: SpreadsheetService }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: FormulaListComponent, isStandalone: true, selector: "kendo-spreadsheet-formula-list", inputs: { maxHeight: "maxHeight", data: "data", itemClick: "itemClick" }, ngImport: i0, template: `
        <ul #ulRef
            class="k-spreadsheet-formula-list k-list-ul k-list-md k-group k-reset"
            role="menu"
            [style.overflowY]="'auto'"
            [style.maxHeight]="maxHeight"
            [kendoEventsOutsideAngular]="{mousedown: handleMouseDown}">
                <li *ngFor="let item of data"
                    (click)="itemClick(item.text)"
                    class="k-list-item"
                    role="menuitem">
                    <kendo-icon-wrapper
                        [svgIcon]="formulaFxIcon"
                        name="formula-fx"
                    ></kendo-icon-wrapper>
                    <span className="k-list-item-text">{{item.text}}</span>
                </li>
        </ul>
    `, isInline: true, dependencies: [{ kind: "directive", type: EventsOutsideAngularDirective, selector: "[kendoEventsOutsideAngular]", inputs: ["kendoEventsOutsideAngular", "scope"] }, { kind: "directive", type: NgFor, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "component", type: IconWrapperComponent, selector: "kendo-icon-wrapper", inputs: ["name", "svgIcon", "innerCssClass", "customFontClass", "size"], exportAs: ["kendoIconWrapper"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FormulaListComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-spreadsheet-formula-list',
                    template: `
        <ul #ulRef
            class="k-spreadsheet-formula-list k-list-ul k-list-md k-group k-reset"
            role="menu"
            [style.overflowY]="'auto'"
            [style.maxHeight]="maxHeight"
            [kendoEventsOutsideAngular]="{mousedown: handleMouseDown}">
                <li *ngFor="let item of data"
                    (click)="itemClick(item.text)"
                    class="k-list-item"
                    role="menuitem">
                    <kendo-icon-wrapper
                        [svgIcon]="formulaFxIcon"
                        name="formula-fx"
                    ></kendo-icon-wrapper>
                    <span className="k-list-item-text">{{item.text}}</span>
                </li>
        </ul>
    `,
                    standalone: true,
                    imports: [EventsOutsideAngularDirective, NgFor, IconWrapperComponent]
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: SpreadsheetService }, { type: i0.Renderer2 }]; }, propDecorators: { maxHeight: [{
                type: Input
            }], data: [{
                type: Input
            }], itemClick: [{
                type: Input
            }] } });

/**
 * @hidden
 */
class FormulaInputDirective {
    element;
    popupService;
    spreadsheetService;
    localization;
    hostClasses = true;
    get title() {
        return this.localization.get('formulaInput');
    }
    role = 'combobox';
    ariaHasPopup = 'menu';
    ariaExpanded = 'false';
    get ariaControls() {
        return this.ariaExpanded === 'true' ? this.spreadsheetService.formulaListId : null;
    }
    formulaListMaxHeight;
    list;
    data;
    constructor(element, popupService, spreadsheetService, localization) {
        this.element = element;
        this.popupService = popupService;
        this.spreadsheetService = spreadsheetService;
        this.localization = localization;
    }
    popupRef;
    handler;
    get listElement() {
        return this.list?.element.nativeElement.firstElementChild;
    }
    get current() {
        return {
            element: this.element.nativeElement,
            list: {
                element: this.list?.element.nativeElement,
                data: (d) => {
                    if (d) {
                        this.data = d;
                        this.list && (this.list.data = d);
                    }
                    else {
                        return this.data;
                    }
                },
                itemClick: (handler) => {
                    this.handler = handler;
                },
                value: () => { return {}; },
                focus: () => {
                    const items = Array.from(this.listElement?.children || []);
                    return items.indexOf(this.focusedItem());
                },
                focusNext: () => this.focusNext(1),
                focusPrev: () => this.focusNext(-1),
                focusFirst: () => {
                    const list = this.listElement;
                    if (list && list.children.item(0)) {
                        this.unfocus();
                        list.children.item(0).classList.add('k-focus');
                    }
                },
                focusLast: () => {
                    const list = this.listElement;
                    if (list && list.children.length) {
                        this.unfocus();
                        list.children.item(list.children.length - 1).classList.add('k-focus');
                    }
                },
            },
            popup: {
                open: () => {
                    this.popupRef?.close();
                    this.popupRef = null;
                    this.popupRef = this.popupService.open({
                        anchor: this.element,
                        content: FormulaListComponent,
                        animate: { direction: 'down', duration: 100 }
                    });
                    const list = this.popupRef.content.instance;
                    this.list = list;
                    list.data = this.data;
                    list.itemClick = this.handler;
                    list.maxHeight = this.formulaListMaxHeight;
                    this.ariaExpanded = 'true';
                },
                close: () => {
                    this.popupRef?.close();
                    this.popupRef = null;
                    this.ariaExpanded = 'false';
                },
                position: () => { },
                visible: () => {
                    return this.popupRef;
                }
            }
        };
    }
    focusedItem = () => this.list?.element.nativeElement.querySelector('.k-focus');
    unfocus = () => {
        const focused = this.focusedItem();
        if (focused) {
            focused.classList.remove('k-focus');
        }
    };
    focusNext = (dir) => {
        const element = this.list?.element.nativeElement.firstElementChild;
        const items = Array.from((element && element.children) || []);
        const focused = this.focusedItem();
        let next;
        if (focused) {
            const index = items.indexOf(focused);
            focused.classList.remove('k-focus');
            next = items[index + dir] ? items[index + dir] : (dir === 1 ? items[0] : items[items.length - 1]);
        }
        else {
            next = (dir === 1 ? items[0] : items[items.length - 1]);
        }
        if (next) {
            next.classList.add('k-focus');
            const { offsetTop, offsetHeight, parentElement } = next;
            if (dir > 0) {
                if (offsetTop + offsetHeight >= parentElement.offsetHeight + parentElement.scrollTop) {
                    parentElement.scrollTop = Math.min(parentElement.scrollTop + offsetHeight, parentElement.scrollHeight - parentElement.offsetHeight);
                }
                if (next === items[0]) {
                    next.scrollIntoView();
                }
            }
            else {
                if (offsetTop <= parentElement.scrollTop) {
                    parentElement.scrollTop = Math.max(parentElement.scrollTop - offsetHeight, 0);
                }
                if (next === items[items.length - 1]) {
                    next.scrollIntoView();
                }
            }
        }
    };
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FormulaInputDirective, deps: [{ token: i0.ElementRef }, { token: i1$1.PopupService }, { token: SpreadsheetService }, { token: SpreadsheetLocalizationService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: FormulaInputDirective, isStandalone: true, selector: "[kendoSpreadsheetFormulaInput]", inputs: { formulaListMaxHeight: "formulaListMaxHeight" }, host: { properties: { "class.k-spreadsheet-formula-input": "this.hostClasses", "attr.title": "this.title", "attr.role": "this.role", "attr.aria-haspopup": "this.ariaHasPopup", "attr.aria-expanded": "this.ariaExpanded", "attr.aria-controls": "this.ariaControls" } }, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FormulaInputDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoSpreadsheetFormulaInput]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i1$1.PopupService }, { type: SpreadsheetService }, { type: SpreadsheetLocalizationService }]; }, propDecorators: { hostClasses: [{
                type: HostBinding,
                args: ['class.k-spreadsheet-formula-input']
            }], title: [{
                type: HostBinding,
                args: ['attr.title']
            }], role: [{
                type: HostBinding,
                args: ['attr.role']
            }], ariaHasPopup: [{
                type: HostBinding,
                args: ['attr.aria-haspopup']
            }], ariaExpanded: [{
                type: HostBinding,
                args: ['attr.aria-expanded']
            }], ariaControls: [{
                type: HostBinding,
                args: ['attr.aria-controls']
            }], formulaListMaxHeight: [{
                type: Input
            }] } });

/**
 * @hidden
 */
const getSheetActions = (items, item) => {
    const visibleItems = items.filter(item => item.state === 'visible');
    const itemIndex = item ? visibleItems.findIndex(i => i === item) : 0;
    return [{
            messageKey: 'sheetDelete',
            icon: 'trash',
            svgIcon: trashIcon,
            commandName: 'delete',
            dialogButton: 'dialogDelete',
            disabled: visibleItems.length === 1
        }, {
            messageKey: 'sheetDuplicate',
            icon: 'copy',
            svgIcon: copyIcon,
            commandName: 'copy'
        }, {
            messageKey: 'sheetRename',
            icon: 'pencil',
            svgIcon: pencilIcon,
            commandName: 'rename',
            dialogButton: 'dialogRename'
        }, {
            messageKey: 'sheetHide',
            icon: 'eye-slash',
            svgIcon: eyeSlashIcon,
            commandName: 'hide',
            disabled: visibleItems.length === 1
        }, {
            messageKey: 'sheetMoveRight',
            icon: 'arrow-right',
            svgIcon: arrowRightIcon,
            commandName: 'move',
            disabled: visibleItems.length === 1 || itemIndex === visibleItems.length - 1
        }, {
            messageKey: 'sheetMoveLeft',
            icon: 'arrow-left',
            svgIcon: arrowLeftIcon,
            commandName: 'move',
            disabled: visibleItems.length === 1 || itemIndex === 0
        }];
};

/**
 * @hidden
 */
class ErrorHandlingService {
    spreadsheetService;
    localization;
    dialogService;
    spreadsheet;
    sheetsChanged = new Subject();
    activeSheetChanged = new Subject();
    selectionChanged = new Subject();
    dialogContainer;
    constructor(spreadsheetService, localization, dialogService) {
        this.spreadsheetService = spreadsheetService;
        this.localization = localization;
        this.dialogService = dialogService;
    }
    set currentActiveSheet(value) {
        this._currentActiveSheet = value;
    }
    get currentActiveSheet() {
        return this._currentActiveSheet;
    }
    get activeSheet() {
        return this.spreadsheet.activeSheet()?.name();
    }
    _currentActiveSheet;
    notifySheetsChange(actionType, sheetInfo) {
        const sheets = this.spreadsheet.sheets();
        this.sheetsChanged.next({ sheets, sheet: sheetInfo, actionType });
    }
    handleErrorMessage(messageData) {
        this.openDialog(messageData);
    }
    openDialog(messageData) {
        let dialogContent;
        let dialogTitle;
        if (messageData.name === 'message') {
            const localizationMsg = this.messageFor('invalidNameError');
            let inputValue = messageData.text.split(' ').pop();
            if (messageData.text.startsWith('Parse')) {
                inputValue = inputValue.substring(0, inputValue.length - 1);
            }
            dialogContent = replaceMessagePlaceholder(localizationMsg, 'inputValue', inputValue);
        }
        else if (messageData.name === 'validationError') {
            dialogContent = messageData.text;
            dialogTitle = messageData.title;
        }
        else {
            dialogContent = this.messageFor(messageData.name);
        }
        const dialogSettings = {
            appendTo: this.spreadsheetService.dialogContainer,
            title: dialogTitle ?? this.messageFor('dialogError'),
            content: dialogContent,
            actions: [{
                    text: this.messageFor('dialogOk'),
                    themeColor: 'primary'
                }],
            width: 400,
            actionsLayout: 'start'
        };
        const dialog = this.dialogService.open(dialogSettings);
        const dialogInstance = dialog.dialog?.instance;
        dialogInstance.action.pipe(take(1)).subscribe((event) => {
            if (event.text === this.messageFor('dialogOk')) {
                messageData.close();
            }
        });
        dialogInstance.close.pipe(take(1)).subscribe(() => {
            messageData.close();
        });
    }
    messageFor(text) {
        return this.localization.get(text);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ErrorHandlingService, deps: [{ token: SpreadsheetService }, { token: i1.LocalizationService }, { token: i1$2.DialogService }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ErrorHandlingService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ErrorHandlingService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: SpreadsheetService }, { type: i1.LocalizationService }, { type: i1$2.DialogService }]; } });

/**
 * @hidden
 */
const commandIcons = {
    alignCenter: 'align-center',
    alignJustify: 'align-justify',
    alignLeft: 'align-left',
    alignRight: 'align-right',
    alignTop: 'align-top',
    alignMiddle: 'align-middle',
    alignBottom: 'align-bottom',
    align: 'align-left',
    alignHorizontal: 'align-left',
    alignVertical: 'align-middle',
    background: 'droplet',
    bold: 'bold',
    color: 'foreground-color',
    italic: 'italic',
    redo: 'arrow-rotate-cw',
    underline: 'underline',
    undo: 'arrow-rotate-ccw',
    wrap: 'text-wrap',
    addColumnLeft: 'table-column-insert-left',
    addColumnRight: 'table-column-insert-right',
    addRowAbove: 'table-row-insert-above',
    addRowBelow: 'table-row-insert-below',
    deleteRow: 'table-row-delete',
    deleteColumn: 'table-column-delete',
    gridLines: 'borders-none',
    folderOpen: 'folder-open',
    download: 'download',
    format: 'custom-format',
    fontSize: 'font-size',
    fontFamily: 'font-family',
    merge: 'cells-merge',
    mergeAll: 'cells-merge',
    mergeHorizontally: 'cells-merge-horizontally',
    mergeVertically: 'cells-merge-vertically',
    unmerge: 'table-unmerge',
    insertLink: 'hyperlink',
    increaseFontSize: 'font-grow',
    decreaseFontSize: 'font-shrink',
    increaseDecimal: 'decimal-increase',
    decreaseDecimal: 'decimal-decrease',
    dataValidation: 'exclamation-circle',
    copy: 'copy',
    cut: 'cut',
    paste: 'clipboard',
    hideRow: 'eye-slash',
    unhideRow: 'eye',
    hideColumn: 'eye-slash',
    unhideColumn: 'eye'
};
/**
 * @hidden
 */
const commandSVGIcons = {
    alignCenter: alignCenterIcon,
    alignJustify: alignJustifyIcon,
    alignLeft: alignLeftIcon,
    alignRight: alignRightIcon,
    alignTop: alignTopIcon,
    alignMiddle: alignMiddleIcon,
    alignBottom: alignBottomIcon,
    align: alignLeftIcon,
    alignHorizontal: alignLeftIcon,
    alignVertical: alignMiddleIcon,
    background: dropletIcon,
    bold: boldIcon,
    color: foregroundColorIcon,
    italic: italicIcon,
    redo: arrowRotateCwIcon,
    underline: underlineIcon,
    undo: arrowRotateCcwIcon,
    wrap: textWrapIcon,
    addColumnLeft: tableColumnInsertLeftIcon,
    addColumnRight: tableColumnInsertRightIcon,
    addRowAbove: tableRowInsertAboveIcon,
    addRowBelow: tableRowInsertBelowIcon,
    deleteRow: tableRowDeleteIcon,
    deleteColumn: tableColumnDeleteIcon,
    gridLines: bordersNoneIcon,
    folderOpen: folderOpenIcon,
    download: downloadIcon,
    format: customFormatIcon,
    fontSize: fontSizeIcon,
    fontFamily: fontFamilyIcon,
    merge: cellsMergeIcon,
    mergeAll: cellsMergeIcon,
    mergeHorizontally: cellsMergeHorizontallyIcon,
    mergeVertically: cellsMergeVerticallyIcon,
    unmerge: tableUnmergeIcon,
    insertLink: linkIcon,
    increaseFontSize: fontGrowIcon,
    decreaseFontSize: fontShrinkIcon,
    decreaseDecimal: decimalDecreaseIcon,
    dataValidation: exclamationCircleIcon,
    increaseDecimal: decimalIncreaseIcon,
    copy: copyIcon,
    cut: cutIcon,
    paste: clipboardIcon,
    hideRow: eyeSlashIcon,
    unhideRow: eyeIcon,
    hideColumn: eyeSlashIcon,
    unhideColumn: eyeIcon
};

/**
 * @hidden
 */
class InsertLinkDialogComponent extends DialogContentBase {
    dialog;
    urlLink = '';
    title;
    constructor(dialog) {
        super(dialog);
        this.dialog = dialog;
    }
    setData(args) {
        this.urlLink = args.link;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: InsertLinkDialogComponent, deps: [{ token: i1$2.DialogRef }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: InsertLinkDialogComponent, isStandalone: true, selector: "ng-component", usesInheritance: true, ngImport: i0, template: `
    <form class="k-form k-form-md" method="dialog">
        <div class="k-form-field">
            <kendo-label [for]="textbox" text="URL"></kendo-label>
                <kendo-textbox #textbox
                    [(value)]="urlLink">
                </kendo-textbox>
        </div>
    </form>
    `, isInline: true, dependencies: [{ kind: "component", type: LabelComponent, selector: "kendo-label", inputs: ["text", "for", "optional", "labelCssStyle", "labelCssClass"], exportAs: ["kendoLabel"] }, { kind: "component", type: TextBoxComponent, selector: "kendo-textbox", inputs: ["focusableId", "title", "type", "disabled", "readonly", "tabindex", "value", "selectOnFocus", "showSuccessIcon", "showErrorIcon", "clearButton", "successIcon", "successSvgIcon", "errorIcon", "errorSvgIcon", "clearButtonIcon", "clearButtonSvgIcon", "size", "rounded", "fillMode", "tabIndex", "placeholder", "maxlength", "inputAttributes"], outputs: ["valueChange", "inputFocus", "inputBlur", "focus", "blur"], exportAs: ["kendoTextBox"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: InsertLinkDialogComponent, decorators: [{
            type: Component,
            args: [{
                    template: `
    <form class="k-form k-form-md" method="dialog">
        <div class="k-form-field">
            <kendo-label [for]="textbox" text="URL"></kendo-label>
                <kendo-textbox #textbox
                    [(value)]="urlLink">
                </kendo-textbox>
        </div>
    </form>
    `,
                    standalone: true,
                    imports: [LabelComponent, TextBoxComponent]
                }]
        }], ctorParameters: function () { return [{ type: i1$2.DialogRef }]; } });

/**
 * @hidden
 */
class ActionDialogComponent extends DialogContentBase {
    dialog;
    commandName;
    value;
    tabindex;
    constructor(dialog) {
        super(dialog);
        this.dialog = dialog;
    }
    setData(args) {
        this.value = args.value;
        this.tabindex = args.tabindex;
        this.commandName = args.commandName;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ActionDialogComponent, deps: [{ token: i1$2.DialogRef }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: ActionDialogComponent, isStandalone: true, selector: "ng-component", usesInheritance: true, ngImport: i0, template: `
        <ng-container *ngIf="commandName === 'delete'">
            <p>The deleted sheet data will be lost.</p>
            <p>Are you sure you want to proceed?</p>
        </ng-container>

        <form class="k-form k-form-md" *ngIf="commandName === 'rename'" method="dialog">
            <div class="k-form-field">
                <kendo-label [for]="textbox" text="Rename sheet"></kendo-label>
                <div class="k-form-field-wrap">
                    <kendo-textbox #textbox
                        autocomplete="off"
                        placeholder="Sheet name"
                        [(value)]="value">
                    </kendo-textbox>
                </div>
            </div>
        </form>
    `, isInline: true, dependencies: [{ kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: LabelComponent, selector: "kendo-label", inputs: ["text", "for", "optional", "labelCssStyle", "labelCssClass"], exportAs: ["kendoLabel"] }, { kind: "component", type: TextBoxComponent, selector: "kendo-textbox", inputs: ["focusableId", "title", "type", "disabled", "readonly", "tabindex", "value", "selectOnFocus", "showSuccessIcon", "showErrorIcon", "clearButton", "successIcon", "successSvgIcon", "errorIcon", "errorSvgIcon", "clearButtonIcon", "clearButtonSvgIcon", "size", "rounded", "fillMode", "tabIndex", "placeholder", "maxlength", "inputAttributes"], outputs: ["valueChange", "inputFocus", "inputBlur", "focus", "blur"], exportAs: ["kendoTextBox"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ActionDialogComponent, decorators: [{
            type: Component,
            args: [{
                    template: `
        <ng-container *ngIf="commandName === 'delete'">
            <p>The deleted sheet data will be lost.</p>
            <p>Are you sure you want to proceed?</p>
        </ng-container>

        <form class="k-form k-form-md" *ngIf="commandName === 'rename'" method="dialog">
            <div class="k-form-field">
                <kendo-label [for]="textbox" text="Rename sheet"></kendo-label>
                <div class="k-form-field-wrap">
                    <kendo-textbox #textbox
                        autocomplete="off"
                        placeholder="Sheet name"
                        [(value)]="value">
                    </kendo-textbox>
                </div>
            </div>
        </form>
    `,
                    standalone: true,
                    imports: [NgIf, LabelComponent, TextBoxComponent]
                }]
        }], ctorParameters: function () { return [{ type: i1$2.DialogRef }]; } });

/**
 * @hidden
 */
class SheetsBarComponent {
    spreadsheetService;
    element;
    renderer;
    localization;
    dialogService;
    ngZone;
    hostClasses = true;
    sheets;
    sheetDescriptors;
    subs = new Subscription();
    constructor(spreadsheetService, element, renderer, localization, dialogService, ngZone) {
        this.spreadsheetService = spreadsheetService;
        this.element = element;
        this.renderer = renderer;
        this.localization = localization;
        this.dialogService = dialogService;
        this.ngZone = ngZone;
        this.subs.add(spreadsheetService.onSheetsBarFocus.subscribe(() => ngZone.run(() => this.tabstrip.selectTab(this.sheets.findIndex(sh => sh.text === spreadsheetService.currentActiveSheet)))));
    }
    addButton;
    menuButton;
    tabstrip;
    actionDdbs;
    actionDdbRefs;
    get activeSheet() {
        return this.spreadsheetService.spreadsheet?.activeSheet()?.name();
    }
    plusIcon = plusIcon;
    menuIcon = menuIcon;
    caretAltDownIcon = caretAltDownIcon;
    selected = false;
    sheetsMenuList = [];
    openedDdb = null;
    tabListSub;
    hiddenStateIcons = {
        hidden: 'eye-slash',
        visible: 'eye'
    };
    hiddenStateSVGIcons = {
        hidden: eyeSlashIcon,
        visible: eyeIcon
    };
    get tablistId() {
        return this.spreadsheetService.tablistId;
    }
    ngAfterViewInit() {
        if (!isDocumentAvailable() || !this.element.nativeElement) {
            return;
        }
        const tablist = this.element.nativeElement.querySelector('.k-tabstrip-items');
        this.renderer.setAttribute(tablist, 'id', this.tablistId);
        this.tabListSub = this.renderer.listen(tablist, 'keydown', this.onTabListKeyDown.bind(this));
    }
    ngOnChanges(changes) {
        if (changes['sheets']) {
            this.sheetsMenuList = this.sheets?.map(sheet => ({
                text: sheet.text,
                icon: this.hiddenStateIcons[sheet.state],
                svgIcon: this.hiddenStateSVGIcons[sheet.state]
            }));
            this.sheets = changes['sheets'].currentValue?.map((sheet, _, items) => ({
                ...sheet,
                sheetActions: getSheetActions(items, sheet)
                    .map(item => ({ ...item, text: this.messageFor(item.messageKey) }))
            }));
        }
    }
    ngOnDestroy() {
        if (this.tabListSub) {
            this.tabListSub();
        }
        this.subs.unsubscribe();
    }
    onAddClick = () => {
        if (this.spreadsheetService.spreadsheet) {
            this.spreadsheetService.spreadsheet.view.sheetsbar.onAddSelect();
            this.notifySheetsChange();
        }
    };
    onTabSelect(ev) {
        if (ev.title !== this.activeSheet) {
            this.selectSheet(ev.title);
        }
    }
    onOpen(ddb) {
        if (isPresent(this.openedDdb) && this.openedDdb !== ddb) {
            this.openedDdb.toggle(false);
        }
        this.openedDdb = ddb;
    }
    onClose() {
        this.openedDdb = null;
        const activeTabIdx = this.sheets.findIndex(sheet => sheet.active);
        this.tabstrip.selectTab(activeTabIdx);
    }
    onActionClick(dataItem, sheet) {
        if (dataItem.disabled) {
            return;
        }
        if (dataItem.commandName === 'delete' || dataItem.commandName === 'rename') {
            this.openDialog(dataItem, sheet);
        }
        else {
            this.actionsCallback[dataItem.commandName](sheet, dataItem.messageKey);
        }
    }
    onMenuItemClick(item) {
        const sheet = this.sheets.find(s => s.text === item.text);
        sheet.state = 'visible';
        this.spreadsheetService.spreadsheet.sheets().find(sh => sh.name() === sheet.text)._state('visible');
        this.selectSheet(sheet.text);
    }
    messageFor(key) {
        return this.localization.get(key);
    }
    openDialog(dataItem, sheet) {
        const dialogSettings = {
            appendTo: this.spreadsheetService.dialogContainer,
            title: this.messageFor(dataItem.commandName),
            content: ActionDialogComponent,
            actions: [{
                    text: this.messageFor(dataItem.dialogButton),
                    themeColor: 'primary'
                }, {
                    text: this.messageFor('dialogCancel')
                }],
            actionsLayout: 'stretched',
            autoFocusedElement: '.k-textbox .k-input-inner, .k-button-solid-primary'
        };
        const dialog = this.dialogService.open(dialogSettings);
        const dialogInstance = dialog.dialog.instance;
        const dialogContent = dialog.content.instance;
        dialogInstance.action.pipe(take(1)).subscribe((event) => {
            if (event.text === this.messageFor(dataItem.dialogButton)) {
                const sheetsBar = this.spreadsheetService.spreadsheet.view.sheetsbar;
                if (sheetsBar) {
                    const allSheets = this.spreadsheetService.spreadsheet.sheets();
                    const sheetIndex = allSheets.findIndex(s => s.name() === sheet.text);
                    dataItem.commandName === 'delete' ? sheetsBar.onSheetRemove(sheet.text) : sheetsBar.onSheetRename(dialogContent.value, sheetIndex);
                    this.notifySheetsChange();
                }
            }
        });
        dialogContent.setData({
            value: sheet.text,
            tabindex: -1,
            commandName: dataItem.commandName
        });
    }
    getCopyRegex(sheetName) {
        const newName = sheetName.replaceAll('(', '\\(').replaceAll(')', '\\)');
        const st = `(${newName})\\s?\\(`;
        return new RegExp(st, 's');
    }
    actionsCallback = {
        copy: (sheetInfo) => {
            let copies = 0;
            const regex = this.getCopyRegex(sheetInfo.text);
            this.sheets.forEach(sheet => {
                const isPresent = regex.test(sheet.text);
                if (isPresent) {
                    copies += 1;
                }
            });
            const sheetToCopy = this.spreadsheetService.spreadsheet.sheets().find(s => s.name() === sheetInfo.text);
            const newName = `${sheetInfo.text} (${copies + 1})`;
            this.spreadsheetService.spreadsheet.insertSheet({ data: { ...sheetToCopy.toJSON(), name: newName }, index: sheetInfo.index + 1 });
            this.selectSheet(newName);
        },
        move: (sheetInfo, itemKey) => {
            const isMoveRight = itemKey === 'sheetMoveRight';
            let oldIndex = -1;
            let newIndex = -1;
            const sheets = this.spreadsheetService.spreadsheet.sheets();
            if (isMoveRight) {
                for (let i = 0; i < sheets.length; i++) {
                    if (sheets[i].name() === sheetInfo.text) {
                        oldIndex = i;
                    }
                    if (oldIndex > -1 && i > oldIndex && sheets[i]._state() === 'visible') {
                        newIndex = i;
                        break;
                    }
                }
            }
            else {
                for (let i = sheets.length - 1; i >= 0; i--) {
                    if (sheets[i].name() === sheetInfo.text) {
                        oldIndex = i;
                    }
                    if (oldIndex > -1 && (i < oldIndex) && sheets[i]._state() === 'visible') {
                        newIndex = i;
                        break;
                    }
                }
            }
            const sheetsBar = this.spreadsheetService.spreadsheet.view.sheetsbar;
            sheetsBar.onSheetReorderEnd({ oldIndex, newIndex });
            this.selectSheet(sheetInfo.text);
            this.notifySheetsChange();
        },
        hide: (sheet) => {
            sheet.state = 'hidden';
            const sheets = this.spreadsheetService.spreadsheet.sheets();
            const sheetIndex = sheets.findIndex(s => s.name() === sheet.text);
            sheets[sheetIndex]._state('hidden');
            const newSelectedIndex = sheetIndex < sheets.length - 1 ? sheetIndex + 1 : 0;
            const sheetToSelect = sheets[newSelectedIndex].name();
            this.selectSheet(sheetToSelect);
            this.notifySheetsChange();
        }
    };
    selectSheet(sheetName) {
        const spreadsheetSheet = this.spreadsheetService.spreadsheet.sheets().find(s => s.name() === sheetName);
        this.spreadsheetService.spreadsheet.activeSheet(spreadsheetSheet);
        this.spreadsheetService.currentActiveSheet = sheetName;
        this.spreadsheetService.activeSheetChanged.next(spreadsheetSheet);
        this.notifySheetsChange();
    }
    onTabListKeyDown(ev) {
        const buttonEl = ev.target.querySelector('kendo-dropdownbutton');
        const index = Array.from(this.actionDdbRefs).findIndex(el => el.nativeElement === buttonEl);
        const ddb = Array.from(this.actionDdbs)[index];
        if (!ddb) {
            return;
        }
        const altKey = ev.altKey;
        const arrowDown = ev.keyCode === Keys.ArrowDown;
        const shouldOpenDdb = altKey && arrowDown && !ddb.isOpen;
        if (shouldOpenDdb) {
            ev.preventDefault();
            ddb.togglePopupVisibility();
        }
    }
    notifySheetsChange() {
        this.ngZone.run(() => {
            const newSheets = this.spreadsheetService.spreadsheet.sheets();
            const sheetDesc = mapToSheetDescriptor(newSheets);
            this.sheets = sheetDesc
                .flatMap((item, index, items) => item.state === 'visible' ? [{
                    ...item,
                    inEdit: false,
                    first: index === 0,
                    last: index === items.length - 1,
                    text: item.name,
                    active: (item.name === this.activeSheet) || items.length === 1,
                    index,
                    sheetActions: getSheetActions(items, item)
                        .map(item => ({ ...item, text: this.messageFor(item.messageKey) }))
                }] : []);
            this.sheetsMenuList = this.sheets?.map(sheet => ({
                text: sheet.text,
                icon: this.hiddenStateIcons[sheet.state],
                svgIcon: this.hiddenStateSVGIcons[sheet.state]
            }));
        });
        this.ngZone.onStable.pipe(take(1)).subscribe(() => this.spreadsheetService.spreadsheet.view.clipboard.focus());
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SheetsBarComponent, deps: [{ token: SpreadsheetService }, { token: i0.ElementRef }, { token: i0.Renderer2 }, { token: SpreadsheetLocalizationService }, { token: i1$2.DialogService }, { token: i0.NgZone }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: SheetsBarComponent, isStandalone: true, selector: "[kendoSpreadsheetSheetsBar]", inputs: { sheets: "sheets", sheetDescriptors: "sheetDescriptors" }, host: { properties: { "class.k-spreadsheet-sheets-bar": "this.hostClasses" } }, viewQueries: [{ propertyName: "addButton", first: true, predicate: ["addButton"], descendants: true }, { propertyName: "menuButton", first: true, predicate: ["menuButton"], descendants: true }, { propertyName: "tabstrip", first: true, predicate: ["tabstrip"], descendants: true }, { propertyName: "actionDdbs", predicate: ["sheetDdb"], descendants: true }, { propertyName: "actionDdbRefs", predicate: ["sheetDdb"], descendants: true, read: ElementRef }], usesOnChanges: true, ngImport: i0, template: `
        <button kendoButton #addButton
            [title]="messageFor('addSheet')"
            type="button"
            fillMode="flat"
            class="k-spreadsheet-sheet-add"
            icon="plus"
            [svgIcon]="plusIcon"
            [kendoEventsOutsideAngular]="{click: onAddClick}"
            [attr.aria-controls]="tablistId">
        </button>
        <kendo-dropdownbutton #menuButton
            fillMode="flat"
            buttonClass="k-spreadsheet-sheets-menu"
            icon="menu"
            [svgIcon]="menuIcon"
            [data]="sheetsMenuList"
            (itemClick)="onMenuItemClick($event)"
            (open)="onOpen(menuButton)"
            [buttonAttributes]="{title: messageFor('sheetsMenu')}"
            [attr.aria-controls]="tablistId">
        </kendo-dropdownbutton>
        <kendo-tabstrip #tabstrip
            [tabPosition]="'bottom'"
            [showContentArea]="false"
            [scrollable]="{ scrollButtonsPosition: 'end', mouseScroll: false }"
            class="k-spreadsheet-sheets"
            (tabSelect)="onTabSelect($event)">
            <ng-container *ngFor="let sheet of sheets">
                <kendo-tabstrip-tab
                    *ngIf="sheet.state === 'visible'"
                    [title]="sheet.text"
                    [selected]="sheet.text === activeSheet">
                    <ng-template kendoTabTemplate>
                        <span class="k-link">
                            <span class="k-link-text">{{sheet.text}}</span>
                        </span>
                        <span class="k-item-actions">
                            <kendo-dropdownbutton #sheetDdb
                                fillMode="flat"
                                icon="caret-alt-down"
                                [svgIcon]="caretAltDownIcon"
                                buttonClass="k-menu-button"
                                [data]="sheet.sheetActions"
                                [buttonAttributes]="{'aria-hidden': 'true', 'tabindex': '-1', role: 'presentation'}"
                                (open)="onOpen(sheetDdb)"
                                (close)="onClose()"
                                (click)="$event.stopPropagation()"
                                (itemClick)="onActionClick($event, sheet)">
                            </kendo-dropdownbutton>
                        </span>
                    </ng-template>
                </kendo-tabstrip-tab>
            </ng-container>
        </kendo-tabstrip>
    `, isInline: true, dependencies: [{ kind: "component", type: ButtonComponent, selector: "button[kendoButton]", inputs: ["arrowIcon", "toggleable", "togglable", "selected", "tabIndex", "imageUrl", "iconClass", "icon", "disabled", "size", "rounded", "fillMode", "themeColor", "svgIcon", "primary", "look"], outputs: ["selectedChange", "click"], exportAs: ["kendoButton"] }, { kind: "directive", type: EventsOutsideAngularDirective, selector: "[kendoEventsOutsideAngular]", inputs: ["kendoEventsOutsideAngular", "scope"] }, { kind: "component", type: DropDownButtonComponent, selector: "kendo-dropdownbutton", inputs: ["arrowIcon", "icon", "svgIcon", "iconClass", "imageUrl", "textField", "data", "size", "rounded", "fillMode", "themeColor", "buttonAttributes"], outputs: ["itemClick", "focus", "blur"], exportAs: ["kendoDropDownButton"] }, { kind: "component", type: TabStripComponent, selector: "kendo-tabstrip", inputs: ["height", "animate", "tabAlignment", "tabPosition", "keepTabContent", "closable", "scrollable", "size", "closeIcon", "closeIconClass", "closeSVGIcon", "showContentArea"], outputs: ["tabSelect", "tabClose", "tabScroll"], exportAs: ["kendoTabStrip"] }, { kind: "directive", type: NgFor, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: TabStripTabComponent, selector: "kendo-tabstrip-tab", inputs: ["title", "disabled", "cssClass", "cssStyle", "selected", "closable", "closeIcon", "closeIconClass", "closeSVGIcon"], exportAs: ["kendoTabStripTab"] }, { kind: "directive", type: TabTemplateDirective, selector: "[kendoTabTemplate]" }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SheetsBarComponent, decorators: [{
            type: Component,
            args: [{
                    selector: '[kendoSpreadsheetSheetsBar]',
                    template: `
        <button kendoButton #addButton
            [title]="messageFor('addSheet')"
            type="button"
            fillMode="flat"
            class="k-spreadsheet-sheet-add"
            icon="plus"
            [svgIcon]="plusIcon"
            [kendoEventsOutsideAngular]="{click: onAddClick}"
            [attr.aria-controls]="tablistId">
        </button>
        <kendo-dropdownbutton #menuButton
            fillMode="flat"
            buttonClass="k-spreadsheet-sheets-menu"
            icon="menu"
            [svgIcon]="menuIcon"
            [data]="sheetsMenuList"
            (itemClick)="onMenuItemClick($event)"
            (open)="onOpen(menuButton)"
            [buttonAttributes]="{title: messageFor('sheetsMenu')}"
            [attr.aria-controls]="tablistId">
        </kendo-dropdownbutton>
        <kendo-tabstrip #tabstrip
            [tabPosition]="'bottom'"
            [showContentArea]="false"
            [scrollable]="{ scrollButtonsPosition: 'end', mouseScroll: false }"
            class="k-spreadsheet-sheets"
            (tabSelect)="onTabSelect($event)">
            <ng-container *ngFor="let sheet of sheets">
                <kendo-tabstrip-tab
                    *ngIf="sheet.state === 'visible'"
                    [title]="sheet.text"
                    [selected]="sheet.text === activeSheet">
                    <ng-template kendoTabTemplate>
                        <span class="k-link">
                            <span class="k-link-text">{{sheet.text}}</span>
                        </span>
                        <span class="k-item-actions">
                            <kendo-dropdownbutton #sheetDdb
                                fillMode="flat"
                                icon="caret-alt-down"
                                [svgIcon]="caretAltDownIcon"
                                buttonClass="k-menu-button"
                                [data]="sheet.sheetActions"
                                [buttonAttributes]="{'aria-hidden': 'true', 'tabindex': '-1', role: 'presentation'}"
                                (open)="onOpen(sheetDdb)"
                                (close)="onClose()"
                                (click)="$event.stopPropagation()"
                                (itemClick)="onActionClick($event, sheet)">
                            </kendo-dropdownbutton>
                        </span>
                    </ng-template>
                </kendo-tabstrip-tab>
            </ng-container>
        </kendo-tabstrip>
    `,
                    standalone: true,
                    imports: [ButtonComponent, EventsOutsideAngularDirective, DropDownButtonComponent, TabStripComponent, NgFor, NgIf, TabStripTabComponent, TabTemplateDirective]
                }]
        }], ctorParameters: function () { return [{ type: SpreadsheetService }, { type: i0.ElementRef }, { type: i0.Renderer2 }, { type: SpreadsheetLocalizationService }, { type: i1$2.DialogService }, { type: i0.NgZone }]; }, propDecorators: { hostClasses: [{
                type: HostBinding,
                args: ['class.k-spreadsheet-sheets-bar']
            }], sheets: [{
                type: Input
            }], sheetDescriptors: [{
                type: Input
            }], addButton: [{
                type: ViewChild,
                args: ['addButton']
            }], menuButton: [{
                type: ViewChild,
                args: ['menuButton']
            }], tabstrip: [{
                type: ViewChild,
                args: ['tabstrip']
            }], actionDdbs: [{
                type: ViewChildren,
                args: ['sheetDdb']
            }], actionDdbRefs: [{
                type: ViewChildren,
                args: ['sheetDdb', { read: ElementRef }]
            }] } });

/**
 * @hidden
 */
class NameBoxComponent {
    ngZone;
    host;
    localization;
    renderer;
    hostClass = true;
    keyDownHandler() {
        const editor = this.spreadsheetWidget.view.nameEditor;
        if (editor) {
            const name = this.inputElement.value;
            editor.trigger('enter', { value: name });
        }
    }
    combobox;
    data;
    spreadsheetWidget;
    constructor(ngZone, host, localization, renderer) {
        this.ngZone = ngZone;
        this.host = host;
        this.localization = localization;
        this.renderer = renderer;
    }
    ngAfterViewInit() {
        this.renderer.setAttribute(this.inputElement, 'title', this.title);
        this.renderer.setAttribute(this.inputElement, 'aria-label', this.title);
    }
    value;
    get inputElement() {
        return this.host.nativeElement.querySelector('.k-input-inner');
    }
    get current() {
        return {
            value: (val) => {
                if (val === undefined) {
                    const item = this.combobox && this.combobox.value;
                    return item ? (item.name || item) : item;
                }
                else {
                    this.ngZone.run(() => {
                        this.value = { name: val } || null;
                    });
                }
            }
        };
    }
    get title() {
        return this.localization.get('nameBox');
    }
    onSelectionChange(value) {
        const editor = this.spreadsheetWidget.view.nameEditor;
        if (editor && value) {
            const name = value.name;
            if (name !== this.value.name) {
                editor.trigger('select', { name });
                this.value = { name };
            }
        }
    }
    onOpen() {
        const editor = this.spreadsheetWidget.view.nameEditor;
        if (editor) {
            this.data = editor.readData();
        }
    }
    valueNormalizer = (text) => text.pipe(map((content) => ({ name: content })));
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NameBoxComponent, deps: [{ token: i0.NgZone }, { token: i0.ElementRef }, { token: SpreadsheetLocalizationService }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: NameBoxComponent, isStandalone: true, selector: "[kendoSpreadsheetNameBox]", inputs: { data: "data", spreadsheetWidget: "spreadsheetWidget" }, host: { listeners: { "keydown.enter": "keyDownHandler()" }, properties: { "class.k-spreadsheet-name-editor": "this.hostClass" } }, viewQueries: [{ propertyName: "combobox", first: true, predicate: ["combobox"], descendants: true }], ngImport: i0, template: `
        <kendo-combobox #combobox
            [popupSettings]="{popupClass: 'k-spreadsheet-names-popup'}"
            fillMode="flat"
            [clearButton]="false"
            textField="name"
            valueField="name"
            [data]="data"
            [allowCustom]="true"
            (selectionChange)="onSelectionChange($event)"
            [value]="value"
            (open)="onOpen()"
            [valueNormalizer]="valueNormalizer"
            [attr.title]="title"
        ></kendo-combobox>
    `, isInline: true, dependencies: [{ kind: "component", type: ComboBoxComponent, selector: "kendo-combobox", inputs: ["icon", "svgIcon", "inputAttributes", "showStickyHeader", "focusableId", "allowCustom", "data", "value", "textField", "valueField", "valuePrimitive", "valueNormalizer", "placeholder", "adaptiveMode", "adaptiveTitle", "adaptiveSubtitle", "popupSettings", "listHeight", "loading", "suggest", "clearButton", "disabled", "itemDisabled", "readonly", "tabindex", "tabIndex", "filterable", "virtual", "size", "rounded", "fillMode"], outputs: ["valueChange", "selectionChange", "filterChange", "open", "opened", "close", "closed", "focus", "blur", "inputFocus", "inputBlur", "escape"], exportAs: ["kendoComboBox"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NameBoxComponent, decorators: [{
            type: Component,
            args: [{
                    selector: '[kendoSpreadsheetNameBox]',
                    template: `
        <kendo-combobox #combobox
            [popupSettings]="{popupClass: 'k-spreadsheet-names-popup'}"
            fillMode="flat"
            [clearButton]="false"
            textField="name"
            valueField="name"
            [data]="data"
            [allowCustom]="true"
            (selectionChange)="onSelectionChange($event)"
            [value]="value"
            (open)="onOpen()"
            [valueNormalizer]="valueNormalizer"
            [attr.title]="title"
        ></kendo-combobox>
    `,
                    standalone: true,
                    imports: [ComboBoxComponent]
                }]
        }], ctorParameters: function () { return [{ type: i0.NgZone }, { type: i0.ElementRef }, { type: SpreadsheetLocalizationService }, { type: i0.Renderer2 }]; }, propDecorators: { hostClass: [{
                type: HostBinding,
                args: ['class.k-spreadsheet-name-editor']
            }], keyDownHandler: [{
                type: HostListener,
                args: ['keydown.enter']
            }], combobox: [{
                type: ViewChild,
                args: ['combobox']
            }], data: [{
                type: Input
            }], spreadsheetWidget: [{
                type: Input
            }] } });

const DEFAULT_FONT_FAMILY = 'Arial';
const DEFAULT_FONT_SIZE = 12;
/**
 * @hidden
 */
const DEFAULT_FONT_VALUES = {
    fontSize: DEFAULT_FONT_SIZE,
    fontFamily: DEFAULT_FONT_FAMILY
};
/**
 * @hidden
 */
const FONT_FAMILIES = ['Arial', 'Courier New', 'Georgia', 'Times New Roman', 'Trebuchet MS', 'Verdana'];
/**
 * @hidden
 */
const FONT_SIZES = [8, 9, 10, 11, 12, 13, 14, 16, 18, 20, 22, 24, 26, 28, 36, 48, 72];
/**
 * @hidden
 */
const FONT_DATA = {
    fontFamily: FONT_FAMILIES,
    fontSize: FONT_SIZES
};
/**
 * @hidden
 */
const FORMATS = [
    { text: 'Automatic', value: null },
    { text: 'Text', value: '@' },
    { text: 'Number', value: '#,0.00' },
    { text: 'Percent', value: '0.00%' },
    { text: 'Financial', value: '_("$"* #,##0.00_);_("$"* (#,##0.00);_("$"* "-"??_);_(@_)' },
    { text: 'Currency', value: '$#,##0.00;[Red]$#,##0.00' },
    { text: 'Date', value: 'm/d/yyyy' },
    { text: 'Time', value: 'h:mm:ss AM/PM' },
    { text: 'Date time', value: 'm/d/yyyy h:mm' },
    { text: 'Duration', value: '[h]:mm:ss' }
];
/**
 * @hidden
 */
const ALIGNS = [
    { icon: commandIcons.alignLeft, svgIcon: commandSVGIcons.alignLeft, textKey: 'Align Left', commandName: 'textAlign', value: 'left', cssClass: '', commandId: 'alignLeft' },
    { icon: commandIcons.alignCenter, svgIcon: commandSVGIcons.alignCenter, textKey: 'Align Center', commandName: 'textAlign', value: 'center', cssClass: '', commandId: 'alignCenter' },
    { icon: commandIcons.alignRight, svgIcon: commandSVGIcons.alignRight, textKey: 'Align Right', commandName: 'textAlign', value: 'right', cssClass: '', commandId: 'alignRight' },
    { icon: commandIcons.alignJustify, svgIcon: commandSVGIcons.alignJustify, textKey: 'Align Justify', commandName: 'textAlign', value: 'justify', cssClass: '', commandId: 'alignJustify' },
    { icon: commandIcons.alignTop, svgIcon: commandSVGIcons.alignTop, textKey: 'Align Top', commandName: 'verticalAlign', value: 'top', cssClass: '', commandId: 'alignTop' },
    { icon: commandIcons.alignMiddle, svgIcon: commandSVGIcons.alignMiddle, textKey: 'Align Middle', commandName: 'verticalAlign', value: 'center', cssClass: '', commandId: 'alignMiddle' },
    { icon: commandIcons.alignBottom, svgIcon: commandSVGIcons.alignBottom, textKey: 'Align Bottom', commandName: 'verticalAlign', value: 'bottom', cssClass: '', commandId: 'alignBottom' }
];
/**
 * @hidden
 */
const MERGE = [
    { icon: commandIcons.mergeAll, svgIcon: commandSVGIcons.mergeAll, textKey: 'Merge all', commandName: 'cells', value: 'cells', disabled: false, commandId: 'mergeAll' },
    { icon: commandIcons.mergeHorizontally, svgIcon: commandSVGIcons.mergeHorizontally, textKey: 'Merge horizontally', commandName: 'horizontally', value: 'horizontally', disabled: false, commandId: 'mergeHorizontally' },
    { icon: commandIcons.mergeVertically, svgIcon: commandSVGIcons.mergeVertically, textKey: 'Merge vertically', commandName: 'vertically', value: 'vertically', disabled: false, commandId: 'mergeVertically' },
    { icon: commandIcons.unmerge, svgIcon: commandSVGIcons.unmerge, textKey: 'Unmerge', commandName: 'unmerge', value: 'unmerge', disabled: false, commandId: 'unmerge' }
];
/**
 * @hidden
 */
const MY_TOKEN = new InjectionToken('COMMAND_TOKEN');

/**
 * @hidden
 */
class SpreadsheetCommandBaseDirective {
    command;
    button;
    localization;
    spreadsheetService;
    toolsService;
    subs = new Subscription();
    constructor(command, button, localization, spreadsheetService, toolsService) {
        this.command = command;
        this.button = button;
        this.localization = localization;
        this.spreadsheetService = spreadsheetService;
        this.toolsService = toolsService;
        const text = this.localization.get(this.command);
        if (text) {
            this.button.showText = 'menu';
            this.button.showIcon = 'always';
            this.button.text = text;
        }
        if (!this.button.toolbarOptions.icon) {
            this.button.icon = commandIcons[this.command];
        }
        if (!this.button.toolbarOptions.svgIcon) {
            this.button.svgIcon = commandSVGIcons[this.command];
        }
        this.button.title = text;
        this.button.fillMode = 'flat';
        this.subs.add(this.toolsService.stateChange.subscribe(state => {
            this.toolsService.ngZone.onStable.pipe(take(1)).subscribe(() => this.button.selected = state[command]);
        }));
    }
    ngOnInit() {
        this.subs.add(this.button.click.subscribe((this.clickHandler.bind(this))));
        this.subs.add(this.button.pointerdown.subscribe((this.pointerdownHandler.bind(this))));
    }
    ngOnDestroy() {
        this.subs.unsubscribe();
    }
    clickHandler() { }
    pointerdownHandler(_event) { }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetCommandBaseDirective, deps: [{ token: MY_TOKEN }, { token: i1$3.ToolBarButtonComponent }, { token: i1.LocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetCommandBaseDirective, selector: "[kendoSpreadsheetCommandBase]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetCommandBaseDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoSpreadsheetCommandBase]'
                }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [MY_TOKEN]
                }] }, { type: i1$3.ToolBarButtonComponent }, { type: i1.LocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
 * @hidden
 */
class SpreadsheetCommandButton extends SpreadsheetCommandBaseDirective {
    command;
    button;
    localization;
    spreadsheetService;
    toolsService;
    commandOptions;
    constructor(command, button, localization, spreadsheetService, toolsService, commandOptions) {
        super(command, button, localization, spreadsheetService, toolsService);
        this.command = command;
        this.button = button;
        this.localization = localization;
        this.spreadsheetService = spreadsheetService;
        this.toolsService = toolsService;
        this.commandOptions = commandOptions;
    }
    clickHandler() {
        if (this.commandOptions.command === 'PropertyChangeCommand') {
            this.commandOptions.options.value = !this.toolsService.toolsState[this.command];
        }
        this.spreadsheetService.spreadsheet.executeCommand(this.commandOptions);
    }
}

/**
 * @hidden
 */
class SpreadsheetGridLinesDirective extends SpreadsheetCommandButton {
    constructor(button, localization, spreadsheetService, toolsService) {
        super('gridLines', button, localization, spreadsheetService, toolsService, {
            command: 'GridLinesChangeCommand',
            options: { property: 'gridLines',
                value: !button.selected
            }
        });
    }
    clickHandler() {
        const sheet = this.spreadsheetService.spreadsheet.activeSheet();
        if (sheet) {
            const value = !sheet.showGridLines();
            const options = {
                command: 'GridLinesChangeCommand', options: { property: 'gridLines', value }
            };
            this.spreadsheetService.spreadsheet.executeCommand(options);
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetGridLinesDirective, deps: [{ token: i1$3.ToolBarButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetGridLinesDirective, isStandalone: true, selector: "kendo-toolbar-button[kendoSpreadsheetGridLines]", usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetGridLinesDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'kendo-toolbar-button[kendoSpreadsheetGridLines]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
 * @hidden
 */
class SpreadsheetMergeDirective {
    host;
    spreadsheetService;
    commandName = 'merge';
    subs = new Subscription();
    selectedRange;
    constructor(host, localization, spreadsheetService) {
        this.host = host;
        this.spreadsheetService = spreadsheetService;
        host.svgIcon = commandSVGIcons[this.commandName];
        host.icon = commandIcons[this.commandName];
        host.arrowIcon = true;
        host.fillMode = 'flat';
        host.data = MERGE.map(item => ({ ...item, textKey: localization.get(item.commandId) }));
        this.subs.add(host.itemClick.subscribe((e) => this.onItemClick(e)));
        host.title = localization.get(this.commandName);
        host.textField = 'textKey';
    }
    ngOnInit() {
        this.subs.add(this.host.open.subscribe(() => {
            const sheet = this.spreadsheetService.spreadsheet.activeSheet();
            const isMergedCellWithinRange = this.hasMergedCells(sheet);
            const unmergeItem = this.host.data.find(i => i.commandName === 'unmerge');
            unmergeItem.disabled = !isMergedCellWithinRange;
        }));
        this.subs.add(this.spreadsheetService.selectionChanged.subscribe(range => this.selectedRange = range));
    }
    ngOnDestroy() {
        this.subs.unsubscribe();
    }
    onItemClick(item) {
        if (item.disabled) {
            return;
        }
        const value = item.value || null;
        const options = {
            command: 'MergeCellCommand', options: { property: item.commandName, value }
        };
        this.spreadsheetService.spreadsheet.executeCommand(options);
    }
    hasMergedCells(sheet) {
        const range = sheet._ref(this.selectedRange);
        return sheet._getMergedCells(range).hasMerged;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetMergeDirective, deps: [{ token: i1$3.ToolBarDropDownButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetMergeDirective, isStandalone: true, selector: "[kendoSpreadsheetMerge]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetMergeDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoSpreadsheetMerge]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarDropDownButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }]; } });

/**
 * @hidden
 */
class SpreadsheetIncreaseDecimalDirective extends SpreadsheetCommandButton {
    constructor(button, localization, spreadsheetService, toolsService) {
        super('increaseDecimal', button, localization, spreadsheetService, toolsService, {
            command: 'AdjustDecimalsCommand'
        });
    }
    clickHandler() {
        const options = {
            command: 'AdjustDecimalsCommand',
            options: { value: 1 }
        };
        this.spreadsheetService.spreadsheet.executeCommand(options);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetIncreaseDecimalDirective, deps: [{ token: i1$3.ToolBarButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetIncreaseDecimalDirective, isStandalone: true, selector: "kendo-toolbar-button[kendoSpreadsheetIncreaseDecimal]", usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetIncreaseDecimalDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'kendo-toolbar-button[kendoSpreadsheetIncreaseDecimal]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
 * @hidden
 */
class SpreadsheetDecreaseDecimalDirective extends SpreadsheetCommandButton {
    constructor(button, localization, spreadsheetService, toolsService) {
        super('decreaseDecimal', button, localization, spreadsheetService, toolsService, {
            command: 'AdjustDecimalsCommand'
        });
    }
    clickHandler() {
        const options = {
            command: 'AdjustDecimalsCommand',
            options: { value: -1 }
        };
        this.spreadsheetService.spreadsheet.executeCommand(options);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetDecreaseDecimalDirective, deps: [{ token: i1$3.ToolBarButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetDecreaseDecimalDirective, isStandalone: true, selector: "kendo-toolbar-button[kendoSpreadsheetDecreaseDecimal]", usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetDecreaseDecimalDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'kendo-toolbar-button[kendoSpreadsheetDecreaseDecimal]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
 * @hidden
 */
class SpreadsheetDeleteRowButtonDirective extends SpreadsheetCommandButton {
    constructor(button, localization, spreadsheetService, toolsService) {
        super('deleteRow', button, localization, spreadsheetService, toolsService, {
            command: 'DeleteRowCommand',
            options: { property: 'deleteRow' }
        });
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetDeleteRowButtonDirective, deps: [{ token: i1$3.ToolBarButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetDeleteRowButtonDirective, isStandalone: true, selector: "kendo-toolbar-button[kendoSpreadsheetDeleteRowButton]", usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetDeleteRowButtonDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'kendo-toolbar-button[kendoSpreadsheetDeleteRowButton]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
 * @hidden
 */
class SpreadsheetDeleteColumnButtonDirective extends SpreadsheetCommandButton {
    constructor(button, localization, spreadsheetService, toolsService) {
        super('deleteColumn', button, localization, spreadsheetService, toolsService, {
            command: 'DeleteColumnCommand',
            options: { property: 'deleteColumn' }
        });
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetDeleteColumnButtonDirective, deps: [{ token: i1$3.ToolBarButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetDeleteColumnButtonDirective, isStandalone: true, selector: "kendo-toolbar-button[kendoSpreadsheetDeleteColumnButton]", usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetDeleteColumnButtonDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'kendo-toolbar-button[kendoSpreadsheetDeleteColumnButton]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
 * @hidden
 */
class SpreadsheetAddRowAboveButtonDirective extends SpreadsheetCommandButton {
    constructor(button, localization, spreadsheetService, toolsService) {
        super('addRowAbove', button, localization, spreadsheetService, toolsService, {
            command: 'AddRowCommand',
            options: { property: 'addRowAbove',
                value: 'above'
            }
        });
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetAddRowAboveButtonDirective, deps: [{ token: i1$3.ToolBarButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetAddRowAboveButtonDirective, isStandalone: true, selector: "kendo-toolbar-button[kendoSpreadsheetAddRowAboveButton]", usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetAddRowAboveButtonDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'kendo-toolbar-button[kendoSpreadsheetAddRowAboveButton]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
 * @hidden
 */
class SpreadsheetAddRowBelowButtonDirective extends SpreadsheetCommandButton {
    constructor(button, localization, spreadsheetService, toolsService) {
        super('addRowBelow', button, localization, spreadsheetService, toolsService, {
            command: 'AddRowCommand',
            options: { property: 'addRowBelow',
                value: 'below'
            }
        });
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetAddRowBelowButtonDirective, deps: [{ token: i1$3.ToolBarButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetAddRowBelowButtonDirective, isStandalone: true, selector: "kendo-toolbar-button[kendoSpreadsheetAddRowBelowButton]", usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetAddRowBelowButtonDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'kendo-toolbar-button[kendoSpreadsheetAddRowBelowButton]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
 * @hidden
 */
class SpreadsheetAddColumnRightButtonDirective extends SpreadsheetCommandButton {
    constructor(button, localization, spreadsheetService, toolsService) {
        super('addColumnRight', button, localization, spreadsheetService, toolsService, {
            command: 'AddColumnCommand',
            options: { property: 'addColumnRight',
                value: 'right'
            }
        });
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetAddColumnRightButtonDirective, deps: [{ token: i1$3.ToolBarButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetAddColumnRightButtonDirective, isStandalone: true, selector: "kendo-toolbar-button[kendoSpreadsheetAddColumnRightButton]", usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetAddColumnRightButtonDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'kendo-toolbar-button[kendoSpreadsheetAddColumnRightButton]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
 * @hidden
 */
class SpreadsheetAddColumnLeftButtonDirective extends SpreadsheetCommandButton {
    constructor(button, localization, spreadsheetService, toolsService) {
        super('addColumnLeft', button, localization, spreadsheetService, toolsService, {
            command: 'AddColumnCommand',
            options: { property: 'addColumnLeft',
                value: 'left'
            }
        });
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetAddColumnLeftButtonDirective, deps: [{ token: i1$3.ToolBarButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetAddColumnLeftButtonDirective, isStandalone: true, selector: "kendo-toolbar-button[kendoSpreadsheetAddColumnLeftButton]", usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetAddColumnLeftButtonDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'kendo-toolbar-button[kendoSpreadsheetAddColumnLeftButton]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
 * @hidden
 */
class SpreadsheetInsertLinkDirective extends SpreadsheetCommandButton {
    dialogService;
    currentRange;
    constructor(button, localization, spreadsheetService, toolsService, dialogService) {
        super('insertLink', button, localization, spreadsheetService, toolsService, {
            command: 'HyperlinkCommand'
        });
        this.dialogService = dialogService;
        this.subs.add(spreadsheetService.selectionChanged.subscribe(range => this.currentRange = range));
    }
    ngOnDestroy() {
        this.subs.unsubscribe();
    }
    clickHandler() {
        const sheet = this.spreadsheetService.spreadsheet.activeSheet();
        if (sheet) {
            this.openDialog();
        }
    }
    /**
     * @hidden
     */
    openDialog() {
        const hasLink = isPresent(this.currentRange?.link());
        const dialogSettings = {
            appendTo: this.spreadsheetService.dialogContainer,
            title: this.localization.get(this.command),
            content: InsertLinkDialogComponent,
            actions: [{
                    text: this.localization.get('dialogInsert'),
                    themeColor: 'primary'
                }, {
                    text: this.localization.get('dialogCancel')
                },
                'spacer', {
                    text: this.localization.get('dialogRemoveLink'),
                    themeColor: 'primary',
                    fillMode: 'clear',
                    cssClass: hasLink ? '' : 'k-disabled'
                }],
            actionsLayout: 'start',
            width: 400,
            autoFocusedElement: '.k-textbox > .k-input-inner'
        };
        const dialog = this.dialogService.open(dialogSettings);
        const dialogInstance = dialog.dialog.instance;
        const dialogContent = dialog.content.instance;
        if (hasLink) {
            dialogContent.setData({ link: this.currentRange?.link() });
        }
        dialogInstance.action.pipe(take(1)).subscribe((event) => {
            if (event.text === this.localization.get('dialogCancel')) {
                return;
            }
            let link = null;
            if (event.text === this.localization.get('dialogInsert')) {
                link = dialogContent.urlLink || null;
            }
            this.spreadsheetService.spreadsheet.executeCommand({
                command: 'HyperlinkCommand',
                options: { link }
            });
        });
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetInsertLinkDirective, deps: [{ token: i1$3.ToolBarButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }, { token: i1$2.DialogService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetInsertLinkDirective, isStandalone: true, selector: "kendo-toolbar-button[kendoSpreadsheetInsertLink]", usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetInsertLinkDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'kendo-toolbar-button[kendoSpreadsheetInsertLink]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }, { type: i1$2.DialogService }]; } });

/**
 * @hidden
 */
class SpreadsheetFormatDirective {
    host;
    spreadsheetService;
    toolsService;
    data = FORMATS;
    commandName = 'format';
    subs = new Subscription();
    constructor(host, localization, spreadsheetService, toolsService) {
        this.host = host;
        this.spreadsheetService = spreadsheetService;
        this.toolsService = toolsService;
        host.svgIcon = commandSVGIcons[this.commandName];
        host.icon = commandIcons[this.commandName];
        host.arrowIcon = true;
        host.fillMode = 'flat';
        host.data = this.data;
        this.subs.add(host.itemClick.subscribe((e) => this.onItemClick(e)));
        host.title = localization.get(this.commandName);
    }
    ngOnInit() {
        this.subs.add(this.toolsService.stateChange.subscribe(state => this.host.data.forEach(i => i.cssClass = i.value === state[this.commandName] ? 'k-selected' : '')));
    }
    ngOnDestroy() {
        this.subs.unsubscribe();
    }
    /**
     * @hidden
     */
    onItemClick = (item) => {
        const value = item.value || null;
        const options = {
            command: 'PropertyChangeCommand', options: { property: this.commandName, value }
        };
        this.spreadsheetService.spreadsheet.executeCommand(options);
    };
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetFormatDirective, deps: [{ token: i1$3.ToolBarDropDownButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetFormatDirective, isStandalone: true, selector: "[kendoSpreadsheetFormat]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetFormatDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoSpreadsheetFormat]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarDropDownButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
 * @hidden
 */
class SpreadsheetTextWrapDirective extends SpreadsheetCommandButton {
    constructor(button, localization, spreadsheetService, toolsService) {
        super('wrap', button, localization, spreadsheetService, toolsService, {
            command: 'TextWrapCommand',
            options: { property: 'wrap',
                value: !button.selected
            }
        });
    }
    clickHandler() {
        const sheet = this.spreadsheetService.spreadsheet.activeSheet();
        if (sheet) {
            const range = sheet.range(sheet.activeCell());
            const value = !range.wrap();
            const options = {
                command: 'TextWrapCommand', options: { property: 'wrap', value }
            };
            this.spreadsheetService.spreadsheet.executeCommand(options);
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetTextWrapDirective, deps: [{ token: i1$3.ToolBarButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetTextWrapDirective, isStandalone: true, selector: "kendo-toolbar-button[kendoSpreadsheetTextWrap]", usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetTextWrapDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'kendo-toolbar-button[kendoSpreadsheetTextWrap]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
 * @hidden
 */
class SpreadsheetVerticalTextAlignDirective {
    host;
    spreadsheetService;
    toolsService;
    commandName = 'alignVertical';
    subs = new Subscription();
    constructor(host, localization, spreadsheetService, toolsService) {
        this.host = host;
        this.spreadsheetService = spreadsheetService;
        this.toolsService = toolsService;
        host.svgIcon = commandSVGIcons[this.commandName];
        host.icon = commandIcons[this.commandName];
        host.arrowIcon = true;
        host.fillMode = 'flat';
        host.data = ALIGNS.flatMap(item => item.commandName === 'verticalAlign' ? [{ ...item, textKey: localization.get(item.commandId) }] : []);
        this.subs.add(host.itemClick.subscribe((e) => this.onItemClick(e)));
        host.title = localization.get(this.commandName);
        host.textField = 'textKey';
    }
    ngOnInit() {
        this.subs.add(this.toolsService.stateChange.subscribe(state => this.host.data.forEach(i => i.cssClass = i.value === state[i.commandName] ? 'k-selected' : '')));
    }
    ngOnDestroy() {
        this.subs.unsubscribe();
    }
    onItemClick(item) {
        const value = item.value || null;
        const options = {
            command: 'PropertyChangeCommand', options: { property: item.commandName, value }
        };
        this.spreadsheetService.spreadsheet.executeCommand(options);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetVerticalTextAlignDirective, deps: [{ token: i1$3.ToolBarDropDownButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetVerticalTextAlignDirective, isStandalone: true, selector: "[kendoSpreadsheetVerticalTextAlign]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetVerticalTextAlignDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoSpreadsheetVerticalTextAlign]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarDropDownButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
 * @hidden
 */
class SpreadsheetHorizontalTextAlignDirective {
    host;
    spreadsheetService;
    toolsService;
    commandName = 'alignHorizontal';
    subs = new Subscription();
    constructor(host, localization, spreadsheetService, toolsService) {
        this.host = host;
        this.spreadsheetService = spreadsheetService;
        this.toolsService = toolsService;
        host.svgIcon = commandSVGIcons[this.commandName];
        host.icon = commandIcons[this.commandName];
        host.arrowIcon = true;
        host.fillMode = 'flat';
        host.data = ALIGNS.flatMap(item => item.commandName === 'textAlign' ? [{ ...item, textKey: localization.get(item.commandId) }] : []);
        this.subs.add(host.itemClick.subscribe((e) => this.onItemClick(e)));
        host.title = localization.get(this.commandName);
        host.textField = 'textKey';
    }
    ngOnInit() {
        this.subs.add(this.toolsService.stateChange.subscribe(state => this.host.data.forEach(i => i.cssClass = i.value === state[i.commandName] ? 'k-selected' : '')));
    }
    ngOnDestroy() {
        this.subs.unsubscribe();
    }
    onItemClick(item) {
        const value = item.value || null;
        const options = {
            command: 'PropertyChangeCommand', options: { property: item.commandName, value }
        };
        this.spreadsheetService.spreadsheet.executeCommand(options);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetHorizontalTextAlignDirective, deps: [{ token: i1$3.ToolBarDropDownButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetHorizontalTextAlignDirective, isStandalone: true, selector: "[kendoSpreadsheetHorizontalTextAlign]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetHorizontalTextAlignDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoSpreadsheetHorizontalTextAlign]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarDropDownButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
 * @hidden
 */
function outerWidth(element) {
    let width = element.offsetWidth;
    const style = getComputedStyle(element);
    width += parseFloat(style.marginLeft) || 0 + parseFloat(style.marginRight) || 0;
    return width;
}
/**
 * @hidden
 */
const rangeValidator = (directive) => {
    return (control) => {
        const err = {
            rangeError: {
                message: 'Incorrect range format',
                value: control.value
            }
        };
        let range;
        try {
            range = directive.spreadsheetService.spreadsheet.activeSheet().range(control.value);
        }
        catch (e) { /** noop */ }
        if (!isPresent(range)) {
            return err;
        }
    };
};

/**
 * @hidden
 */
class DropDownListBase {
    display = 'inline-flex';
    data;
    value;
    title;
    tabindex;
    fillMode = 'flat';
    valueChange = new EventEmitter();
    element;
    dropDownList;
    onValueChange(value) {
        this.valueChange.emit(value);
    }
    focus() {
        this.dropDownList.focus();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DropDownListBase, deps: [], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: DropDownListBase, selector: "kendo-spreadsheet-dropdownlist-base", inputs: { data: "data", value: "value", title: "title", tabindex: "tabindex" }, outputs: { valueChange: "valueChange" }, host: { properties: { "style.display": "this.display" } }, viewQueries: [{ propertyName: "element", first: true, predicate: ["element"], descendants: true, static: true }, { propertyName: "dropDownList", first: true, predicate: ["element"], descendants: true, read: DropDownListComponent, static: true }], ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DropDownListBase, decorators: [{
            type: Directive,
            args: [{
                    selector: 'kendo-spreadsheet-dropdownlist-base'
                }]
        }], propDecorators: { display: [{
                type: HostBinding,
                args: ['style.display']
            }], data: [{
                type: Input
            }], value: [{
                type: Input
            }], title: [{
                type: Input
            }], tabindex: [{
                type: Input
            }], valueChange: [{
                type: Output
            }], element: [{
                type: ViewChild,
                args: ['element', { static: true }]
            }], dropDownList: [{
                type: ViewChild,
                args: ['element', { read: DropDownListComponent, static: true }]
            }] } });

/**
 * @hidden
 */
class FontSizeDropDownListComponent extends DropDownListBase {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FontSizeDropDownListComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: FontSizeDropDownListComponent, isStandalone: true, selector: "kendo-spreadsheet-fontsize-dropdownlist", usesInheritance: true, ngImport: i0, template: `
        <kendo-dropdownlist
            #element
            class="k-toolbar-dropdownlist"
            [data]="data"
            [(value)]="value"
            [attr.title]="title"
            [tabindex]="tabindex"
            (valueChange)="onValueChange($event)"
            [leftRightArrowsNavigation]="false"
            [fillMode]="fillMode"></kendo-dropdownlist>
    `, isInline: true, dependencies: [{ kind: "component", type: DropDownListComponent, selector: "kendo-dropdownlist", inputs: ["customIconClass", "showStickyHeader", "icon", "svgIcon", "loading", "data", "value", "textField", "valueField", "adaptiveMode", "adaptiveTitle", "adaptiveSubtitle", "popupSettings", "listHeight", "defaultItem", "disabled", "itemDisabled", "readonly", "filterable", "virtual", "ignoreCase", "delay", "valuePrimitive", "tabindex", "tabIndex", "size", "rounded", "fillMode", "leftRightArrowsNavigation", "id"], outputs: ["valueChange", "filterChange", "selectionChange", "open", "opened", "close", "closed", "focus", "blur"], exportAs: ["kendoDropDownList"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FontSizeDropDownListComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-spreadsheet-fontsize-dropdownlist',
                    template: `
        <kendo-dropdownlist
            #element
            class="k-toolbar-dropdownlist"
            [data]="data"
            [(value)]="value"
            [attr.title]="title"
            [tabindex]="tabindex"
            (valueChange)="onValueChange($event)"
            [leftRightArrowsNavigation]="false"
            [fillMode]="fillMode"></kendo-dropdownlist>
    `,
                    standalone: true,
                    imports: [DropDownListComponent]
                }]
        }] });

/**
 * @hidden
 */
class FontFamilyDropDownListComponent extends DropDownListBase {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FontFamilyDropDownListComponent, deps: null, target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: FontFamilyDropDownListComponent, isStandalone: true, selector: "kendo-spreadsheet-fontfamily-dropdownlist", usesInheritance: true, ngImport: i0, template: `
        <kendo-dropdownlist
            #element
            class="k-toolbar-dropdownlist"
            [data]="data"
            [(value)]="value"
            [tabindex]="tabindex"
            (valueChange)="onValueChange($event)"
            [leftRightArrowsNavigation]="false"
            [fillMode]="fillMode"
            [attr.title]="title">
            <ng-template kendoDropDownListItemTemplate let-dataItem>
                <span [ngStyle]="{ 'font-family': dataItem }">
                    {{ dataItem }}
                </span>
            </ng-template>
        </kendo-dropdownlist>
    `, isInline: true, dependencies: [{ kind: "component", type: DropDownListComponent, selector: "kendo-dropdownlist", inputs: ["customIconClass", "showStickyHeader", "icon", "svgIcon", "loading", "data", "value", "textField", "valueField", "adaptiveMode", "adaptiveTitle", "adaptiveSubtitle", "popupSettings", "listHeight", "defaultItem", "disabled", "itemDisabled", "readonly", "filterable", "virtual", "ignoreCase", "delay", "valuePrimitive", "tabindex", "tabIndex", "size", "rounded", "fillMode", "leftRightArrowsNavigation", "id"], outputs: ["valueChange", "filterChange", "selectionChange", "open", "opened", "close", "closed", "focus", "blur"], exportAs: ["kendoDropDownList"] }, { kind: "directive", type: ItemTemplateDirective, selector: "[kendoDropDownListItemTemplate],[kendoComboBoxItemTemplate],[kendoAutoCompleteItemTemplate],[kendoMultiSelectItemTemplate]" }, { kind: "directive", type: NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: FontFamilyDropDownListComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-spreadsheet-fontfamily-dropdownlist',
                    template: `
        <kendo-dropdownlist
            #element
            class="k-toolbar-dropdownlist"
            [data]="data"
            [(value)]="value"
            [tabindex]="tabindex"
            (valueChange)="onValueChange($event)"
            [leftRightArrowsNavigation]="false"
            [fillMode]="fillMode"
            [attr.title]="title">
            <ng-template kendoDropDownListItemTemplate let-dataItem>
                <span [ngStyle]="{ 'font-family': dataItem }">
                    {{ dataItem }}
                </span>
            </ng-template>
        </kendo-dropdownlist>
    `,
                    standalone: true,
                    imports: [DropDownListComponent, ItemTemplateDirective, NgStyle]
                }]
        }] });

/**
 * @hidden
 */
class DialogContentComponent extends DialogContentBase {
    dialog;
    data = [];
    value;
    tabindex;
    componentType;
    title;
    constructor(dialog) {
        super(dialog);
        this.dialog = dialog;
    }
    setData(args) {
        this.data = args.data;
        this.value = args.value;
        this.tabindex = args.tabindex;
        this.componentType = args.componentType;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DialogContentComponent, deps: [{ token: i1$2.DialogRef }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: DialogContentComponent, isStandalone: true, selector: "ng-component", usesInheritance: true, ngImport: i0, template: `
        <div 
            [ngSwitch]="componentType"
            class="k-d-flex k-align-items-center k-justify-content-center">
            <kendo-spreadsheet-fontfamily-dropdownlist
                *ngSwitchCase="'fontFamily'"
                [data]="data"
                [(value)]="value"
                [attr.title]="title"
                [tabindex]="tabindex"
                [style.width.em]="13"
                ></kendo-spreadsheet-fontfamily-dropdownlist>
            <kendo-spreadsheet-fontsize-dropdownlist
                *ngSwitchCase="'fontSize'"
                [data]="data"
                [(value)]="value"
                [attr.title]="title"
                [tabindex]="tabindex"
                [style.width.em]="13"
                ></kendo-spreadsheet-fontsize-dropdownlist>
            <kendo-colorpicker
                *ngSwitchCase="'color'"
                [attr.title]="title"
                [format]="'hex'"
                [(value)]="value"
                [tabindex]="tabindex"
                [clearButton]="false"
                fillMode="flat"
            ></kendo-colorpicker>
            <kendo-colorpicker
                *ngSwitchCase="'background'"
                [attr.title]="title"
                [format]="'hex'"
                [(value)]="value"
                [tabindex]="tabindex"
                [clearButton]="false"
                fillMode="flat"
            ></kendo-colorpicker>
        </div>
    `, isInline: true, dependencies: [{ kind: "directive", type: NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }, { kind: "component", type: FontFamilyDropDownListComponent, selector: "kendo-spreadsheet-fontfamily-dropdownlist" }, { kind: "component", type: FontSizeDropDownListComponent, selector: "kendo-spreadsheet-fontsize-dropdownlist" }, { kind: "component", type: ColorPickerComponent, selector: "kendo-colorpicker", inputs: ["views", "view", "adaptiveMode", "activeView", "readonly", "disabled", "format", "value", "popupSettings", "paletteSettings", "gradientSettings", "icon", "iconClass", "svgIcon", "adaptiveTitle", "adaptiveSubtitle", "clearButton", "tabindex", "preview", "actionsLayout", "size", "rounded", "fillMode"], outputs: ["valueChange", "open", "close", "focus", "blur", "cancel", "activeColorClick", "clearButtonClick", "activeViewChange"], exportAs: ["kendoColorPicker"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DialogContentComponent, decorators: [{
            type: Component,
            args: [{
                    template: `
        <div 
            [ngSwitch]="componentType"
            class="k-d-flex k-align-items-center k-justify-content-center">
            <kendo-spreadsheet-fontfamily-dropdownlist
                *ngSwitchCase="'fontFamily'"
                [data]="data"
                [(value)]="value"
                [attr.title]="title"
                [tabindex]="tabindex"
                [style.width.em]="13"
                ></kendo-spreadsheet-fontfamily-dropdownlist>
            <kendo-spreadsheet-fontsize-dropdownlist
                *ngSwitchCase="'fontSize'"
                [data]="data"
                [(value)]="value"
                [attr.title]="title"
                [tabindex]="tabindex"
                [style.width.em]="13"
                ></kendo-spreadsheet-fontsize-dropdownlist>
            <kendo-colorpicker
                *ngSwitchCase="'color'"
                [attr.title]="title"
                [format]="'hex'"
                [(value)]="value"
                [tabindex]="tabindex"
                [clearButton]="false"
                fillMode="flat"
            ></kendo-colorpicker>
            <kendo-colorpicker
                *ngSwitchCase="'background'"
                [attr.title]="title"
                [format]="'hex'"
                [(value)]="value"
                [tabindex]="tabindex"
                [clearButton]="false"
                fillMode="flat"
            ></kendo-colorpicker>
        </div>
    `,
                    standalone: true,
                    imports: [NgSwitch, NgSwitchCase, FontFamilyDropDownListComponent, FontSizeDropDownListComponent, ColorPickerComponent]
                }]
        }], ctorParameters: function () { return [{ type: i1$2.DialogRef }]; } });

/**
 * @hidden
 */
class SpreadsheetDropDownToolBase extends ToolBarToolComponent {
    command;
    dialogService;
    localization;
    spreadsheetService;
    toolsService;
    toolbar;
    element;
    dropDownListRef;
    popupButton;
    data;
    constructor(command, dialogService, localization, spreadsheetService, toolsService, toolbar) {
        super();
        this.command = command;
        this.dialogService = dialogService;
        this.localization = localization;
        this.spreadsheetService = spreadsheetService;
        this.toolsService = toolsService;
        this.toolbar = toolbar;
        this.value = DEFAULT_FONT_VALUES[this.command];
        this.data = FONT_DATA[this.command];
        this.isBuiltInTool = true;
    }
    /**
     * Fires when the user updates the value of the drop-down list.
     */
    valueChange = new EventEmitter();
    value;
    tabindex = -1;
    itemDisabled;
    svgIcon;
    icon;
    subs;
    ngOnInit() {
        this.value = this.toolsService.toolsState[this.command];
        this.subs = this.toolsService.stateChange.subscribe(state => {
            this.value = state[this.command];
        });
        this.svgIcon = commandSVGIcons[this.command];
        this.icon = commandIcons[this.command];
    }
    ngOnDestroy() {
        if (this.subs) {
            this.subs.unsubscribe();
        }
    }
    /**
     * @hidden
     */
    messageFor(key) {
        return this.localization.get(key);
    }
    /**
     * @hidden
     */
    onValueChange(ev) {
        if (isPresent(ev)) {
            if (hasObservers(this.valueChange)) {
                this.valueChange.emit(ev);
            }
            const options = {
                command: 'PropertyChangeCommand',
                options: { property: this.command, value: ev || null }
            };
            this.spreadsheetService.spreadsheet.executeCommand(options);
        }
    }
    /**
     * @hidden
     */
    get outerWidth() {
        if (this.element) {
            return outerWidth(this.element.nativeElement);
        }
    }
    /**
     * @hidden
     */
    openDialog() {
        const dialogSettings = {
            appendTo: this.spreadsheetService.dialogContainer,
            title: this.messageFor(this.command),
            content: DialogContentComponent,
            actions: [{
                    text: this.messageFor('dialogApply'),
                    themeColor: 'primary'
                }, {
                    text: this.messageFor('dialogCancel')
                }],
            actionsLayout: 'start',
            width: 400,
            autoFocusedElement: '.k-picker'
        };
        this.toolbar.toggle(false);
        const dialog = this.dialogService.open(dialogSettings);
        const dialogInstance = dialog.dialog.instance;
        const dialogContent = dialog.content.instance;
        dialogInstance.action.pipe(take(1)).subscribe((event) => {
            if (event.text === this.messageFor('dialogApply')) {
                const options = {
                    command: 'PropertyChangeCommand',
                    options: { property: this.command, value: dialogContent.value || null }
                };
                this.spreadsheetService.spreadsheet.executeCommand(options);
            }
            this.toolbar.toggle();
        });
        dialogInstance.close.pipe(take(1)).subscribe(() => {
            this.toolbar.toggle();
        });
        dialogContent.setData({
            data: this.data,
            value: this.value,
            tabindex: this.tabindex,
            componentType: this.command,
            title: this.localization.get(this.command)
        });
    }
    /**
     * @hidden
     */
    focus(e) {
        this.tabindex = 0;
        if (e instanceof PointerEvent) {
            return;
        }
        if (this.overflows) {
            this.popupButton.nativeElement.focus();
        }
        else {
            this.dropDownListRef.focus();
        }
    }
    /**
     * @hidden
     */
    canFocus() {
        return true;
    }
    /**
     * @hidden
     */
    handleKey() {
        this.tabindex = -1;
        return false;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetDropDownToolBase, deps: [{ token: MY_TOKEN }, { token: i1$2.DialogService }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }, { token: i1$3.ToolBarComponent }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetDropDownToolBase, selector: "ng-component", outputs: { valueChange: "valueChange" }, viewQueries: [{ propertyName: "element", first: true, predicate: ["element"], descendants: true, read: ElementRef }, { propertyName: "dropDownListRef", first: true, predicate: ["element"], descendants: true }, { propertyName: "popupButton", first: true, predicate: ["popupButton"], descendants: true, read: ElementRef }], usesInheritance: true, ngImport: i0, template: ``, isInline: true });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetDropDownToolBase, decorators: [{
            type: Component,
            args: [{
                    template: ``
                }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [MY_TOKEN]
                }] }, { type: i1$2.DialogService }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }, { type: i1$3.ToolBarComponent }]; }, propDecorators: { element: [{
                type: ViewChild,
                args: ['element', { read: ElementRef }]
            }], dropDownListRef: [{
                type: ViewChild,
                args: ['element']
            }], popupButton: [{
                type: ViewChild,
                args: ['popupButton', { read: ElementRef }]
            }], valueChange: [{
                type: Output
            }] } });

/**
 * A component which changes the background color of the text ([more information](ToDo).
 * @hidden
 */
class SpreadsheetBackColorComponent extends SpreadsheetDropDownToolBase {
    constructor(dialogService, localization, spreadsheetService, toolsService, toolbar) {
        super('background', dialogService, localization, spreadsheetService, toolsService, toolbar);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetBackColorComponent, deps: [{ token: i1$2.DialogService }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }, { token: ToolBarComponent }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetBackColorComponent, isStandalone: true, selector: "kendo-spreadsheet-backcolor-tool", providers: [{ provide: ToolBarToolComponent, useExisting: forwardRef(() => SpreadsheetBackColorComponent) }], usesInheritance: true, ngImport: i0, template: `
        <ng-template #toolbarTemplate>
            <div class="k-toolbar-item">
                <kendo-colorpicker
                    #element
                    [attr.title]="messageFor(command)"
                    [format]="'hex'"
                    [(value)]="value"
                    [tabindex]="tabindex"
                    (valueChange)="onValueChange($event)"
                    [clearButton]="false"
                    fillMode="flat"
                    [icon]="icon"
                    [preview]="true"
                    [svgIcon]="svgIcon"></kendo-colorpicker>
            </div>
        </ng-template>
        <ng-template #popupTemplate>
            <div #popupButton
                [tabindex]="tabindex"
                role="menuitem"
                class="k-item k-menu-item"
                (click)="openDialog()">
                <span
                    class="k-link k-menu-link">
                    <kendo-icon-wrapper [name]="icon" [svgIcon]="svgIcon"></kendo-icon-wrapper>
                    <span *ngIf="messageFor(command)" class="k-menu-link-text">{{messageFor(command)}}</span>
                </span>
            </div>
        </ng-template>
        <ng-template #sectionTemplate>
            <div class="k-toolbar-item">
                <kendo-colorpicker
                    #element
                    [attr.title]="messageFor(command)"
                    [format]="'hex'"
                    [(value)]="value"
                    [tabindex]="tabindex"
                    (valueChange)="onValueChange($event)"
                    [clearButton]="false"
                    fillMode="flat"
                    [icon]="icon"
                    [preview]="true"
                    [svgIcon]="svgIcon"></kendo-colorpicker>
            </div>
        </ng-template>
    `, isInline: true, dependencies: [{ kind: "component", type: ColorPickerComponent, selector: "kendo-colorpicker", inputs: ["views", "view", "adaptiveMode", "activeView", "readonly", "disabled", "format", "value", "popupSettings", "paletteSettings", "gradientSettings", "icon", "iconClass", "svgIcon", "adaptiveTitle", "adaptiveSubtitle", "clearButton", "tabindex", "preview", "actionsLayout", "size", "rounded", "fillMode"], outputs: ["valueChange", "open", "close", "focus", "blur", "cancel", "activeColorClick", "clearButtonClick", "activeViewChange"], exportAs: ["kendoColorPicker"] }, { kind: "component", type: IconWrapperComponent, selector: "kendo-icon-wrapper", inputs: ["name", "svgIcon", "innerCssClass", "customFontClass", "size"], exportAs: ["kendoIconWrapper"] }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetBackColorComponent, decorators: [{
            type: Component,
            args: [{
                    providers: [{ provide: ToolBarToolComponent, useExisting: forwardRef(() => SpreadsheetBackColorComponent) }],
                    selector: 'kendo-spreadsheet-backcolor-tool',
                    template: `
        <ng-template #toolbarTemplate>
            <div class="k-toolbar-item">
                <kendo-colorpicker
                    #element
                    [attr.title]="messageFor(command)"
                    [format]="'hex'"
                    [(value)]="value"
                    [tabindex]="tabindex"
                    (valueChange)="onValueChange($event)"
                    [clearButton]="false"
                    fillMode="flat"
                    [icon]="icon"
                    [preview]="true"
                    [svgIcon]="svgIcon"></kendo-colorpicker>
            </div>
        </ng-template>
        <ng-template #popupTemplate>
            <div #popupButton
                [tabindex]="tabindex"
                role="menuitem"
                class="k-item k-menu-item"
                (click)="openDialog()">
                <span
                    class="k-link k-menu-link">
                    <kendo-icon-wrapper [name]="icon" [svgIcon]="svgIcon"></kendo-icon-wrapper>
                    <span *ngIf="messageFor(command)" class="k-menu-link-text">{{messageFor(command)}}</span>
                </span>
            </div>
        </ng-template>
        <ng-template #sectionTemplate>
            <div class="k-toolbar-item">
                <kendo-colorpicker
                    #element
                    [attr.title]="messageFor(command)"
                    [format]="'hex'"
                    [(value)]="value"
                    [tabindex]="tabindex"
                    (valueChange)="onValueChange($event)"
                    [clearButton]="false"
                    fillMode="flat"
                    [icon]="icon"
                    [preview]="true"
                    [svgIcon]="svgIcon"></kendo-colorpicker>
            </div>
        </ng-template>
    `,
                    standalone: true,
                    imports: [ColorPickerComponent, IconWrapperComponent, NgIf]
                }]
        }], ctorParameters: function () { return [{ type: i1$2.DialogService }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }, { type: i1$3.ToolBarComponent, decorators: [{
                    type: Inject,
                    args: [ToolBarComponent]
                }] }]; } });

/**
 * A component which changes the color of the text ([more information](ToDo).
 * @hidden
 */
class SpreadsheetForeColorComponent extends SpreadsheetDropDownToolBase {
    constructor(dialogService, localization, spreadsheetService, toolsService, toolbar) {
        super('color', dialogService, localization, spreadsheetService, toolsService, toolbar);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetForeColorComponent, deps: [{ token: i1$2.DialogService }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }, { token: ToolBarComponent }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetForeColorComponent, isStandalone: true, selector: "kendo-spreadsheet-forecolor-tool", providers: [{ provide: ToolBarToolComponent, useExisting: forwardRef(() => SpreadsheetForeColorComponent) }], usesInheritance: true, ngImport: i0, template: `
        <ng-template #toolbarTemplate>
            <div class="k-toolbar-item">
                <kendo-colorpicker
                    #element
                    [attr.title]="messageFor(command)"
                    [format]="'hex'"
                    [(value)]="value"
                    [tabindex]="tabindex"
                    (valueChange)="onValueChange($event)"
                    [clearButton]="false"
                    fillMode="flat"
                    [icon]="icon"
                    [svgIcon]="svgIcon"
                    [preview]="true"></kendo-colorpicker>
            </div>
        </ng-template>
        <ng-template #popupTemplate>
            <div #popupButton
                [tabindex]="tabindex"
                role="menuitem"
                class="k-item k-menu-item"
                (click)="openDialog()">
                <span
                    class="k-link k-menu-link">
                    <kendo-icon-wrapper [name]="icon" [svgIcon]="svgIcon"></kendo-icon-wrapper>
                    <span *ngIf="messageFor(command)" class="k-menu-link-text">{{messageFor(command)}}</span>
                </span>
            </div>
        </ng-template>
        <ng-template #sectionTemplate>
            <div class="k-toolbar-item">
                <kendo-colorpicker
                    #element
                    [attr.title]="messageFor(command)"
                    [format]="'hex'"
                    [(value)]="value"
                    [tabindex]="tabindex"
                    (valueChange)="onValueChange($event)"
                    [clearButton]="false"
                    fillMode="flat"
                    [icon]="icon"
                    [svgIcon]="svgIcon"
                    [preview]="true"></kendo-colorpicker>
            </div>
        </ng-template>
    `, isInline: true, dependencies: [{ kind: "component", type: ColorPickerComponent, selector: "kendo-colorpicker", inputs: ["views", "view", "adaptiveMode", "activeView", "readonly", "disabled", "format", "value", "popupSettings", "paletteSettings", "gradientSettings", "icon", "iconClass", "svgIcon", "adaptiveTitle", "adaptiveSubtitle", "clearButton", "tabindex", "preview", "actionsLayout", "size", "rounded", "fillMode"], outputs: ["valueChange", "open", "close", "focus", "blur", "cancel", "activeColorClick", "clearButtonClick", "activeViewChange"], exportAs: ["kendoColorPicker"] }, { kind: "component", type: IconWrapperComponent, selector: "kendo-icon-wrapper", inputs: ["name", "svgIcon", "innerCssClass", "customFontClass", "size"], exportAs: ["kendoIconWrapper"] }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetForeColorComponent, decorators: [{
            type: Component,
            args: [{
                    providers: [{ provide: ToolBarToolComponent, useExisting: forwardRef(() => SpreadsheetForeColorComponent) }],
                    selector: 'kendo-spreadsheet-forecolor-tool',
                    template: `
        <ng-template #toolbarTemplate>
            <div class="k-toolbar-item">
                <kendo-colorpicker
                    #element
                    [attr.title]="messageFor(command)"
                    [format]="'hex'"
                    [(value)]="value"
                    [tabindex]="tabindex"
                    (valueChange)="onValueChange($event)"
                    [clearButton]="false"
                    fillMode="flat"
                    [icon]="icon"
                    [svgIcon]="svgIcon"
                    [preview]="true"></kendo-colorpicker>
            </div>
        </ng-template>
        <ng-template #popupTemplate>
            <div #popupButton
                [tabindex]="tabindex"
                role="menuitem"
                class="k-item k-menu-item"
                (click)="openDialog()">
                <span
                    class="k-link k-menu-link">
                    <kendo-icon-wrapper [name]="icon" [svgIcon]="svgIcon"></kendo-icon-wrapper>
                    <span *ngIf="messageFor(command)" class="k-menu-link-text">{{messageFor(command)}}</span>
                </span>
            </div>
        </ng-template>
        <ng-template #sectionTemplate>
            <div class="k-toolbar-item">
                <kendo-colorpicker
                    #element
                    [attr.title]="messageFor(command)"
                    [format]="'hex'"
                    [(value)]="value"
                    [tabindex]="tabindex"
                    (valueChange)="onValueChange($event)"
                    [clearButton]="false"
                    fillMode="flat"
                    [icon]="icon"
                    [svgIcon]="svgIcon"
                    [preview]="true"></kendo-colorpicker>
            </div>
        </ng-template>
    `,
                    standalone: true,
                    imports: [ColorPickerComponent, IconWrapperComponent, NgIf]
                }]
        }], ctorParameters: function () { return [{ type: i1$2.DialogService }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }, { type: i1$3.ToolBarComponent, decorators: [{
                    type: Inject,
                    args: [ToolBarComponent]
                }] }]; } });

/**
 * @hidden
 */
class SpreadsheetUnderlineDirective extends SpreadsheetCommandButton {
    constructor(button, localization, spreadsheetService, toolsService) {
        super('underline', button, localization, spreadsheetService, toolsService, {
            command: 'PropertyChangeCommand',
            options: { property: 'underline',
                value: !button.selected
            }
        });
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetUnderlineDirective, deps: [{ token: i1$3.ToolBarButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetUnderlineDirective, isStandalone: true, selector: "kendo-toolbar-button[kendoSpreadsheetUnderline]", usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetUnderlineDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'kendo-toolbar-button[kendoSpreadsheetUnderline]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
 * @hidden
 */
class SpreadsheetItalicDirective extends SpreadsheetCommandButton {
    constructor(button, localization, spreadsheetService, toolsService) {
        super('italic', button, localization, spreadsheetService, toolsService, {
            command: 'PropertyChangeCommand',
            options: { property: 'italic',
                value: !button.selected
            }
        });
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetItalicDirective, deps: [{ token: i1$3.ToolBarButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetItalicDirective, isStandalone: true, selector: "kendo-toolbar-button[kendoSpreadsheetItalic]", usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetItalicDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'kendo-toolbar-button[kendoSpreadsheetItalic]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
 * @hidden
 */
class SpreadsheetBoldDirective extends SpreadsheetCommandButton {
    constructor(button, localization, spreadsheetService, toolsService) {
        super('bold', button, localization, spreadsheetService, toolsService, {
            command: 'PropertyChangeCommand',
            options: { property: 'bold',
                value: !button.selected
            }
        });
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetBoldDirective, deps: [{ token: i1$3.ToolBarButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetBoldDirective, isStandalone: true, selector: "kendo-toolbar-button[kendoSpreadsheetBold]", usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetBoldDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'kendo-toolbar-button[kendoSpreadsheetBold]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
 * @hidden
 */
class SpreadsheetDecreaseFontSizeDirective extends SpreadsheetCommandButton {
    value;
    constructor(button, localization, spreadsheetService, toolsService) {
        super('decreaseFontSize', button, localization, spreadsheetService, toolsService, {
            command: 'PropertyChangeCommand',
            options: { property: 'fontSize' }
        });
        this.value = DEFAULT_FONT_VALUES.fontSize;
    }
    clickHandler() {
        const newValue = this.value - 1;
        const options = {
            command: 'PropertyChangeCommand',
            options: { property: 'fontSize', value: newValue || null }
        };
        this.spreadsheetService.spreadsheet.executeCommand(options);
    }
    ngAfterViewInit() {
        this.value = this.toolsService.toolsState['fontSize'];
        this.subs.add(this.toolsService.stateChange.subscribe(state => {
            this.value = state['fontSize'];
        }));
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetDecreaseFontSizeDirective, deps: [{ token: i1$3.ToolBarButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetDecreaseFontSizeDirective, isStandalone: true, selector: "kendo-toolbar-button[kendoSpreadsheetDecreaseFontSize]", usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetDecreaseFontSizeDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'kendo-toolbar-button[kendoSpreadsheetDecreaseFontSize]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
 * @hidden
 */
class SpreadsheetIncreaseFontSizeDirective extends SpreadsheetCommandButton {
    value;
    constructor(button, localization, spreadsheetService, toolsService) {
        super('increaseFontSize', button, localization, spreadsheetService, toolsService, {
            command: 'PropertyChangeCommand',
            options: { property: 'fontSize' }
        });
        this.value = DEFAULT_FONT_VALUES.fontSize;
    }
    clickHandler() {
        const newValue = this.value + 1;
        const options = {
            command: 'PropertyChangeCommand',
            options: { property: 'fontSize', value: newValue || null }
        };
        this.spreadsheetService.spreadsheet.executeCommand(options);
    }
    ngAfterViewInit() {
        this.value = this.toolsService.toolsState['fontSize'];
        this.subs.add(this.toolsService.stateChange.subscribe(state => {
            this.value = state['fontSize'];
        }));
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetIncreaseFontSizeDirective, deps: [{ token: i1$3.ToolBarButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetIncreaseFontSizeDirective, isStandalone: true, selector: "kendo-toolbar-button[kendoSpreadsheetIncreaseFontSize]", usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetIncreaseFontSizeDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'kendo-toolbar-button[kendoSpreadsheetIncreaseFontSize]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
 * A component which configures an existing `DropDownListComponent` as a Spreadsheet tool
 * ([see example](ToDo).
 * The component associates a `kendo-toolbar-dropdownlist` with a Spreadsheet command that changes the font size of a content block and
 * automatically defines the options of the drop-down list and sets its values ([see example](ToDo).
 *
 * @hidden
 */
class SpreadsheetFontSizeComponent extends SpreadsheetDropDownToolBase {
    constructor(dialogService, localization, spreadsheetService, toolsService, toolbar) {
        super('fontSize', dialogService, localization, spreadsheetService, toolsService, toolbar);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetFontSizeComponent, deps: [{ token: i1$2.DialogService }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }, { token: ToolBarComponent }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetFontSizeComponent, isStandalone: true, selector: "kendo-toolbar-dropdownlist[kendoSpreadsheetFontSize]", providers: [{ provide: ToolBarToolComponent, useExisting: forwardRef(() => SpreadsheetFontSizeComponent) }], usesInheritance: true, ngImport: i0, template: `
        <ng-template #toolbarTemplate>
            <kendo-spreadsheet-fontsize-dropdownlist
                #element
                [data]="data"
                [(value)]="value"
                [title]="messageFor(command)"
                [tabindex]="tabindex"
                (valueChange)="onValueChange($event)"></kendo-spreadsheet-fontsize-dropdownlist>
        </ng-template>
        <ng-template #popupTemplate>
            <div #popupButton
                [tabindex]="tabindex"
                role="menuitem"
                class="k-item k-menu-item"
                (click)="openDialog()">
                <span
                    class="k-link k-menu-link">
                    <kendo-icon-wrapper [name]="icon" [svgIcon]="svgIcon"></kendo-icon-wrapper>
                    <span *ngIf="messageFor(command)" class="k-menu-link-text">{{messageFor(command)}}</span>
                </span>
            </div>
        </ng-template>
        <ng-template #sectionTemplate>
            <kendo-spreadsheet-fontsize-dropdownlist
                #element
                [data]="data"
                [(value)]="value"
                [title]="messageFor(command)"
                [tabindex]="tabindex"
                (valueChange)="onValueChange($event)"></kendo-spreadsheet-fontsize-dropdownlist>
        </ng-template>
    `, isInline: true, dependencies: [{ kind: "component", type: FontSizeDropDownListComponent, selector: "kendo-spreadsheet-fontsize-dropdownlist" }, { kind: "component", type: IconWrapperComponent, selector: "kendo-icon-wrapper", inputs: ["name", "svgIcon", "innerCssClass", "customFontClass", "size"], exportAs: ["kendoIconWrapper"] }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetFontSizeComponent, decorators: [{
            type: Component,
            args: [{
                    providers: [{ provide: ToolBarToolComponent, useExisting: forwardRef(() => SpreadsheetFontSizeComponent) }],
                    selector: 'kendo-toolbar-dropdownlist[kendoSpreadsheetFontSize]',
                    template: `
        <ng-template #toolbarTemplate>
            <kendo-spreadsheet-fontsize-dropdownlist
                #element
                [data]="data"
                [(value)]="value"
                [title]="messageFor(command)"
                [tabindex]="tabindex"
                (valueChange)="onValueChange($event)"></kendo-spreadsheet-fontsize-dropdownlist>
        </ng-template>
        <ng-template #popupTemplate>
            <div #popupButton
                [tabindex]="tabindex"
                role="menuitem"
                class="k-item k-menu-item"
                (click)="openDialog()">
                <span
                    class="k-link k-menu-link">
                    <kendo-icon-wrapper [name]="icon" [svgIcon]="svgIcon"></kendo-icon-wrapper>
                    <span *ngIf="messageFor(command)" class="k-menu-link-text">{{messageFor(command)}}</span>
                </span>
            </div>
        </ng-template>
        <ng-template #sectionTemplate>
            <kendo-spreadsheet-fontsize-dropdownlist
                #element
                [data]="data"
                [(value)]="value"
                [title]="messageFor(command)"
                [tabindex]="tabindex"
                (valueChange)="onValueChange($event)"></kendo-spreadsheet-fontsize-dropdownlist>
        </ng-template>
    `,
                    standalone: true,
                    imports: [FontSizeDropDownListComponent, IconWrapperComponent, NgIf]
                }]
        }], ctorParameters: function () { return [{ type: i1$2.DialogService }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }, { type: i1$3.ToolBarComponent, decorators: [{
                    type: Inject,
                    args: [ToolBarComponent]
                }] }]; } });

/**
 * A component which configures an existing `DropDownListComponent` as a Spreadsheet tool
 * ([see example](ToDo).
 * The component associates a `kendo-toolbar-dropdownlist` with a Spreadsheet command that changes the font family of a content block and
 * automatically defines the options of the drop-down list and sets its values ([see example](ToDo).
 *
 * @hidden
 */
class SpreadsheetFontFamilyComponent extends SpreadsheetDropDownToolBase {
    constructor(dialogService, localization, spreadsheetService, toolsService, toolbar) {
        super('fontFamily', dialogService, localization, spreadsheetService, toolsService, toolbar);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetFontFamilyComponent, deps: [{ token: i1$2.DialogService }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }, { token: ToolBarComponent }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetFontFamilyComponent, isStandalone: true, selector: "kendo-toolbar-dropdownlist[kendoSpreadsheetFontFamily]", providers: [{ provide: ToolBarToolComponent, useExisting: forwardRef(() => SpreadsheetFontFamilyComponent) }], usesInheritance: true, ngImport: i0, template: `
        <ng-template #toolbarTemplate>
            <kendo-spreadsheet-fontfamily-dropdownlist
                #element
                [data]="data"
                [(value)]="value"
                [title]="messageFor(command)"
                [tabindex]="tabindex"
                (valueChange)="onValueChange($event)"></kendo-spreadsheet-fontfamily-dropdownlist>
        </ng-template>
        <ng-template #popupTemplate>
            <div #popupButton
                [tabindex]="tabindex"
                role="menuitem"
                class="k-item k-menu-item"
                (click)="openDialog()">
                <span
                    class="k-link k-menu-link">
                    <kendo-icon-wrapper [name]="icon" [svgIcon]="svgIcon"></kendo-icon-wrapper>
                    <span *ngIf="messageFor(command)" class="k-menu-link-text">{{messageFor(command)}}</span>
                </span>
            </div>
        </ng-template>
        <ng-template #sectionTemplate>
            <kendo-spreadsheet-fontfamily-dropdownlist
                #element
                [data]="data"
                [(value)]="value"
                [title]="messageFor(command)"
                [tabindex]="tabindex"
                (valueChange)="onValueChange($event)"></kendo-spreadsheet-fontfamily-dropdownlist>
        </ng-template>
    `, isInline: true, dependencies: [{ kind: "component", type: FontFamilyDropDownListComponent, selector: "kendo-spreadsheet-fontfamily-dropdownlist" }, { kind: "component", type: IconWrapperComponent, selector: "kendo-icon-wrapper", inputs: ["name", "svgIcon", "innerCssClass", "customFontClass", "size"], exportAs: ["kendoIconWrapper"] }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetFontFamilyComponent, decorators: [{
            type: Component,
            args: [{
                    providers: [{ provide: ToolBarToolComponent, useExisting: forwardRef(() => SpreadsheetFontFamilyComponent) }],
                    selector: 'kendo-toolbar-dropdownlist[kendoSpreadsheetFontFamily]',
                    template: `
        <ng-template #toolbarTemplate>
            <kendo-spreadsheet-fontfamily-dropdownlist
                #element
                [data]="data"
                [(value)]="value"
                [title]="messageFor(command)"
                [tabindex]="tabindex"
                (valueChange)="onValueChange($event)"></kendo-spreadsheet-fontfamily-dropdownlist>
        </ng-template>
        <ng-template #popupTemplate>
            <div #popupButton
                [tabindex]="tabindex"
                role="menuitem"
                class="k-item k-menu-item"
                (click)="openDialog()">
                <span
                    class="k-link k-menu-link">
                    <kendo-icon-wrapper [name]="icon" [svgIcon]="svgIcon"></kendo-icon-wrapper>
                    <span *ngIf="messageFor(command)" class="k-menu-link-text">{{messageFor(command)}}</span>
                </span>
            </div>
        </ng-template>
        <ng-template #sectionTemplate>
            <kendo-spreadsheet-fontfamily-dropdownlist
                #element
                [data]="data"
                [(value)]="value"
                [title]="messageFor(command)"
                [tabindex]="tabindex"
                (valueChange)="onValueChange($event)"></kendo-spreadsheet-fontfamily-dropdownlist>
        </ng-template>
    `,
                    standalone: true,
                    imports: [FontFamilyDropDownListComponent, IconWrapperComponent, NgIf]
                }]
        }], ctorParameters: function () { return [{ type: i1$2.DialogService }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }, { type: i1$3.ToolBarComponent, decorators: [{
                    type: Inject,
                    args: [ToolBarComponent]
                }] }]; } });

/**
 * @hidden
 */
class SpreadsheetRedoDirective extends SpreadsheetCommandButton {
    constructor(button, localization, spreadsheetService, toolsService) {
        super('redo', button, localization, spreadsheetService, toolsService, {
            options: { property: 'redo' }
        });
    }
    clickHandler() {
        this.spreadsheetService.spreadsheet.workbook.undoRedoStack['redo']();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetRedoDirective, deps: [{ token: i1$3.ToolBarButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetRedoDirective, isStandalone: true, selector: "kendo-toolbar-button[kendoSpreadsheetRedo]", usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetRedoDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'kendo-toolbar-button[kendoSpreadsheetRedo]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
 * @hidden
 */
class SpreadsheetUndoDirective extends SpreadsheetCommandButton {
    constructor(button, localization, spreadsheetService, toolsService) {
        super('undo', button, localization, spreadsheetService, toolsService, {
            options: { property: 'undo' }
        });
    }
    clickHandler() {
        this.spreadsheetService.spreadsheet.workbook.undoRedoStack['undo']();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetUndoDirective, deps: [{ token: i1$3.ToolBarButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetUndoDirective, isStandalone: true, selector: "kendo-toolbar-button[kendoSpreadsheetUndo]", usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetUndoDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'kendo-toolbar-button[kendoSpreadsheetUndo]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
 * @hidden
 */
class SpreadsheetSaveFileDirective {
    button;
    localization;
    spreadsheetService;
    subs = new Subscription();
    constructor(button, localization, spreadsheetService) {
        this.button = button;
        this.localization = localization;
        this.spreadsheetService = spreadsheetService;
    }
    ngOnInit() {
        this.button.title = this.localization.get('saveFile');
        this.button.icon = commandIcons['download'];
        this.button.svgIcon = commandSVGIcons['download'];
        this.button.fillMode = 'flat';
        this.subs.add(this.button.click.subscribe(() => {
            const spreadsheet = this.spreadsheetService.spreadsheet;
            if (spreadsheet) {
                spreadsheet.saveAsExcel({
                    ...spreadsheet.options.excel,
                    saveAs,
                    Workbook
                });
            }
        }));
    }
    ngOnDestroy() {
        this.subs.unsubscribe();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetSaveFileDirective, deps: [{ token: i1$3.ToolBarButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetSaveFileDirective, isStandalone: true, selector: "[kendoSpreadsheetSaveFile]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetSaveFileDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoSpreadsheetSaveFile]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }]; } });

/**
 * @hidden
 */
class SpreadsheetLoadFileComponent extends ToolBarToolComponent {
    localization;
    spreadsheetService;
    toolbar;
    overflowButtonElement;
    button;
    icon = commandIcons['folderOpen'];
    svgIcon = commandSVGIcons['folderOpen'];
    tabindex = -1;
    constructor(localization, spreadsheetService, toolbar) {
        super();
        this.localization = localization;
        this.spreadsheetService = spreadsheetService;
        this.toolbar = toolbar;
        this.isBuiltInTool = true;
    }
    /**
     * @hidden
     */
    messageFor(key) {
        return this.localization.get(key);
    }
    onFileSelect = (e) => {
        const file = e.target.files[0];
        if (file) {
            this.spreadsheetService.spreadsheet.executeCommand({ command: 'OpenCommand', options: { file } });
            e.target.value = null;
        }
    };
    /**
     * @hidden
     */
    canFocus() {
        return true;
    }
    /**
     * @hidden
     */
    focus() {
        this.tabindex = 0;
        if (this.overflows) {
            this.overflowButtonElement.nativeElement.focus();
        }
        else {
            this.button.focus();
        }
    }
    /**
     * @hidden
     */
    handleKey() {
        this.tabindex = -1;
        return false;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetLoadFileComponent, deps: [{ token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: ToolBarComponent }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetLoadFileComponent, isStandalone: true, selector: "kendo-spreadsheet-load-file-tool", providers: [
            {
                provide: ToolBarToolComponent,
                useExisting: forwardRef(() => SpreadsheetLoadFileComponent),
            },
        ], viewQueries: [{ propertyName: "overflowButtonElement", first: true, predicate: ["overflowButton"], descendants: true, read: ElementRef }, { propertyName: "button", first: true, predicate: ["button"], descendants: true }], usesInheritance: true, ngImport: i0, template: `
        <ng-template #toolbarTemplate>
            <button
                #button
                type="button"
                kendoButton
                [title]="messageFor('loadFile')"
                fillMode="flat"
                [icon]="icon"
                [svgIcon]="svgIcon"
                (click)="fileSelectEl.click()"></button>
            <input
                #fileSelectEl
                type="file"
                (change)="onFileSelect($event)"
                [style.display]="'none'"
                aria-hidden="true"
                accept=".xlsx,.XLSX" />
        </ng-template>
        <ng-template #popupTemplate>
            <div
                #overflowButton
                tabindex="-1"
                role="menuitem"
                class="k-item k-menu-item"
                (click)="toolbar.toggle(false); popupFileSelectEl.click()">
                <span
                    class="k-link k-menu-link">
                    <kendo-icon-wrapper
                        [name]="icon"
                        [svgIcon]="svgIcon"
                    ></kendo-icon-wrapper>
                    <span class="k-menu-link-text">{{messageFor('loadFile')}}</span>
                </span>
                <input
                    #popupFileSelectEl
                    type="file"
                    (change)="onFileSelect($event)"
                    [style.display]="'none'"
                    aria-hidden="true"
                    accept=".xlsx,.XLSX" />
            </div>
        </ng-template>
        <ng-template #sectionTemplate>
            <button
                #button
                type="button"
                kendoButton
                [title]="messageFor('loadFile')"
                fillMode="flat"
                [icon]="icon"
                [svgIcon]="svgIcon"
                (click)="fileSelectEl.click()"></button>
            <input
                #fileSelectEl
                type="file"
                (change)="onFileSelect($event)"
                [style.display]="'none'"
                aria-hidden="true"
                accept=".xlsx,.XLSX" />
        </ng-template>
    `, isInline: true, dependencies: [{ kind: "component", type: ButtonComponent, selector: "button[kendoButton]", inputs: ["arrowIcon", "toggleable", "togglable", "selected", "tabIndex", "imageUrl", "iconClass", "icon", "disabled", "size", "rounded", "fillMode", "themeColor", "svgIcon", "primary", "look"], outputs: ["selectedChange", "click"], exportAs: ["kendoButton"] }, { kind: "component", type: IconWrapperComponent, selector: "kendo-icon-wrapper", inputs: ["name", "svgIcon", "innerCssClass", "customFontClass", "size"], exportAs: ["kendoIconWrapper"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetLoadFileComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-spreadsheet-load-file-tool',
                    providers: [
                        {
                            provide: ToolBarToolComponent,
                            useExisting: forwardRef(() => SpreadsheetLoadFileComponent),
                        },
                    ],
                    template: `
        <ng-template #toolbarTemplate>
            <button
                #button
                type="button"
                kendoButton
                [title]="messageFor('loadFile')"
                fillMode="flat"
                [icon]="icon"
                [svgIcon]="svgIcon"
                (click)="fileSelectEl.click()"></button>
            <input
                #fileSelectEl
                type="file"
                (change)="onFileSelect($event)"
                [style.display]="'none'"
                aria-hidden="true"
                accept=".xlsx,.XLSX" />
        </ng-template>
        <ng-template #popupTemplate>
            <div
                #overflowButton
                tabindex="-1"
                role="menuitem"
                class="k-item k-menu-item"
                (click)="toolbar.toggle(false); popupFileSelectEl.click()">
                <span
                    class="k-link k-menu-link">
                    <kendo-icon-wrapper
                        [name]="icon"
                        [svgIcon]="svgIcon"
                    ></kendo-icon-wrapper>
                    <span class="k-menu-link-text">{{messageFor('loadFile')}}</span>
                </span>
                <input
                    #popupFileSelectEl
                    type="file"
                    (change)="onFileSelect($event)"
                    [style.display]="'none'"
                    aria-hidden="true"
                    accept=".xlsx,.XLSX" />
            </div>
        </ng-template>
        <ng-template #sectionTemplate>
            <button
                #button
                type="button"
                kendoButton
                [title]="messageFor('loadFile')"
                fillMode="flat"
                [icon]="icon"
                [svgIcon]="svgIcon"
                (click)="fileSelectEl.click()"></button>
            <input
                #fileSelectEl
                type="file"
                (change)="onFileSelect($event)"
                [style.display]="'none'"
                aria-hidden="true"
                accept=".xlsx,.XLSX" />
        </ng-template>
    `,
                    standalone: true,
                    imports: [ButtonComponent, IconWrapperComponent]
                }]
        }], ctorParameters: function () { return [{ type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: i1$3.ToolBarComponent, decorators: [{
                    type: Inject,
                    args: [ToolBarComponent]
                }] }]; }, propDecorators: { overflowButtonElement: [{
                type: ViewChild,
                args: ['overflowButton', { read: ElementRef, static: false }]
            }], button: [{
                type: ViewChild,
                args: ['button']
            }] } });

/**
 * @hidden
 */
class MainMenuDirective {
    host;
    renderer;
    constructor(host, renderer) {
        this.host = host;
        this.renderer = renderer;
    }
    ngAfterViewInit() {
        isDocumentAvailable() && this.renderer.addClass(this.host.nativeElement.firstElementChild, 'k-spreadsheet-menu');
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MainMenuDirective, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: MainMenuDirective, isStandalone: true, selector: "[kendoSpreadsheetMenu]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MainMenuDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoSpreadsheetMenu]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }]; } });

/**
 * @hidden
 */
class MessagesDirective extends ComponentMessages {
    /* Tabs */
    /**
     * The name of the "Home" toolbar tab
     */
    home;
    /**
     * The name of the "File" toolbar tab
     */
    file;
    /**
     * The name of the "Insert" toolbar tab
     */
    insert;
    /**
     * The name of the "Format" toolbar tab
     */
    formatTab;
    /**
     * The name of the "Data" toolbar tab
     */
    dataTab;
    /* Section of Tools Messages */
    /**
     * The title of the Save File tool
     */
    saveFile;
    /**
     * The title of the Load File tool
     */
    loadFile;
    /**
     * The title of the Bold tool
     */
    bold;
    /**
     * The title of the Data Validation tool
     */
    dataValidation;
    /**
     * The text of the Cell Range input label in the data validation dialog
     */
    validationCellRange;
    /**
     * The text of the Criteria dropdown list label in the data validation dialog.
     */
    validationCriteria;
    /**
     * The text of the Comparer dropdown list label in the data validation dialog.
     */
    validationComparer;
    /**
     * The text of the Min value label in the data validation dialog.
     */
    validationMinValue;
    /**
     * The text of the Max value label in the data validation dialog.
     */
    validationMaxValue;
    /**
     * The text of the Start value label in the data validation dialog.
     */
    validationStartValue;
    /**
     * The text of the End value label in the data validation dialog.
     */
    validationEndValue;
    /**
     * The text of the Value label in the data validation dialog.
     */
    validationValue;
    /**
     * The text for the Show list button checkbox label in the data validation dialog.
     */
    validationShowListButtonCheckbox;
    /**
     * The text for the Show date button checkbox label in the data validation dialog.
     */
    validationShowDateButtonCheckbox;
    /**
     * The text for the Ignore blank checkbox label in the data validation dialog.
     */
    validationIgnoreBlankCheckbox;
    /**
     * The text for the On invalid data label in the data validation dialog.
     */
    validationOnInvalidData;
    /**
     * The text for the Reject input radio button label in the data validation dialog.
     */
    validationRejectInput;
    /**
     * The text for the Show warning radio button label in the data validation dialog.
     */
    validationShowWarning;
    /**
     * The text for the Show hint checkbox label in the data validation dialog.
     */
    validationShowHint;
    /**
     * The text of the Any value validation criteria.
     */
    anyValueValidationCriteria;
    /**
     * The text of the Number validation criteria.
     */
    numberValidationCriteria;
    /**
     * The text of the Text validation criteria.
     */
    textValidationCriteria;
    /**
     * The text of the Date validation criteria.
     */
    dateValidationCriteria;
    /**
     * The text of the Custom Formula validation criteria.
     */
    customFormulaValidationCriteria;
    /**
     * The text of the List validation criteria.
     */
    listValidationCriteria;
    /**
     * The text of the greater than validation comparer.
     */
    greaterThanValidationComparer;
    /**
     * The text of the less than validation comparer.
     */
    lessThanValidationComparer;
    /**
     * The text of the between validation comparer.
     */
    betweenValidationComparer;
    /**
     * The text of the not between validation comparer.
     */
    notBetweenValidationComparer;
    /**
     * The text of the equal to validation comparer.
     */
    equalToValidationComparer;
    /**
     * The text of the not equal to validation comparer.
     */
    notEqualToValidationComparer;
    /**
     * The text of the greater than or equal to validation comparer.
     */
    greaterThanOrEqualToValidationComparer;
    /**
     * The text of the less than or equal to validation comparer.
     */
    lessThanOrEqualToValidationComparer;
    /**
     * The text for the Custom hint input label in the data validation dialog.
     */
    validationHintMessage;
    /**
     * The text for the Custom hint title input label in the data validation dialog.
     */
    validationHintTitle;
    /**
     * The title of the Italic tool
     */
    italic;
    /**
     * The title of the Underline tool
     */
    underline;
    /**
     * The title of the Format tool
     */
    format;
    /**
     * The title of the Font Family tool
     */
    fontFamily;
    /**
     * The title of the Font Size tool
     */
    fontSize;
    /**
     * The title of the Undo tool
     */
    undo;
    /**
     * The title of the Redo tool
     */
    redo;
    /**
     * The title of the tool that changes the text background color
     */
    background;
    /**
     * The title of the tool that changes the text font color
     */
    color;
    /**
     * The title of the Grid Lines tool
     */
    gridLines;
    /**
     * The title of the tool that adds new column before currently selected column
     */
    addColumnLeft;
    /**
     * The title of the tool that adds new column after currently selected column
     */
    addColumnRight;
    /**
     * The title of the tool that adds new row below currently selected row
     */
    addRowBelow;
    /**
     * The title of the tool that adds new row above currently selected row
     */
    addRowAbove;
    /**
     * The title of the tool that deletes a column
     */
    deleteColumn;
    /**
     * The title of the tool that deletes a row
     */
    deleteRow;
    /**
     * The title of the Text Wrap tool
     */
    wrap;
    /**
     * The title of the Text Align tool
     */
    align;
    /**
     * The title of the Text Align Horizontal tool
     */
    alignHorizontal;
    /**
     * The title of the Text Align Vertical tool
     */
    alignVertical;
    /**
     * The title of the Text Align Left tool
     */
    alignLeft;
    /**
     * The title of the Text Align Center tool
     */
    alignCenter;
    /**
     * The title of the Text Align Right tool
     */
    alignRight;
    /**
     * The title of the Text Align Justify tool
     */
    alignJustify;
    /**
     * The title of the Text Align Top tool
     */
    alignTop;
    /**
     * The title of the Text Align Middle tool
     */
    alignMiddle;
    /**
     * The title of the Text Align Bottom tool
     */
    alignBottom;
    /* Dialogs */
    /**
     * The text of the Apply button in all Spreadsheet dialogs
     */
    dialogApply;
    /* Dialogs */
    /**
     * The text of the Cancel button in all Spreadsheet dialogs
     */
    dialogCancel;
    /**
     * The text of the Delete button in the Delete sheet dialog
     */
    dialogDelete;
    /**
     * The text of the Rename button in the Rename sheet dialog
     */
    dialogRename;
    /**
     * The text of the **Insert** button in all Spreadsheet dialogs
     */
    dialogInsert;
    /**
     * The text of the **Remove** button in all Spreadsheet dialogs
     */
    dialogRemove;
    /**
     * The text of the **Remove link** button in the Link tool dialog
     */
    dialogRemoveLink;
    /**
     * The title of the Delete sheet dialog
     */
    delete;
    /**
     * The title of the Rename sheet dialog
     */
    rename;
    /**
     * The title of the Name Box input
     */
    nameBox;
    /**
     * The title of the Formula input
     */
    formulaInput;
    /**
     * The title of the Add new sheet button
     */
    addSheet;
    /**
     * The title of the Sheets menu button
     */
    sheetsMenu;
    /**
     * The text of the View toolbar tab
     */
    view;
    /**
     * The title of the Cells Merge tool
     */
    merge;
    /**
     * The title of the Merge horizontally tool
     */
    mergeHorizontally;
    /**
     * The title of the Merge vertically tool
     */
    mergeVertically;
    /**
     * The title of the Merge all tool
     */
    mergeAll;
    /**
     * The title of the Unmerge tool
     */
    unmerge;
    /**
     * The title of the tool that inserts a link
     */
    insertLink;
    /**
     * The title of the tool that inserts a link
     */
    increaseDecimal;
    /**
     * The title of the tool that inserts a link
     */
    decreaseDecimal;
    /**
     * The title of the tool that increases the cell font size
     */
    increaseFontSize;
    /**
     * The title of the tool that decreases the cell font size
     */
    decreaseFontSize;
    /**
     * The content of the dialog that warns about an unsupported file type
     */
    openUnsupported;
    /**
     * The content of the dialog that warns about modifying a merged cell
     */
    modifyMerged;
    /**
     * The content of the dialog that warns about modifying a disabled cell
     */
    cannotModifyDisabled;
    /**
     * The text of the **OK** dialog button
     */
    dialogOk;
    /**
     * The title of an error dialog
     */
    dialogError;
    /**
     * The content of the dialog that warns about duplicated sheet name
     */
    duplicateSheetName;
    /**
     * The Copy command text
     */
    copy;
    /**
     * The Cut command text
     */
    cut;
    /**
     * The Paste command text
     */
    paste;
    /**
     * The Hide row command text
     */
    hideRow;
    /**
     * The Unhide row command text
     */
    unhideRow;
    /**
     * The Hide column command text
     */
    hideColumn;
    /**
     * The Unhide column command text
     */
    unhideColumn;
    /**
     * The text of the Sheet menu Delete option
     */
    sheetDelete;
    /**
     * The text of the Sheet menu Rename option
     */
    sheetRename;
    /**
     * The text of the Sheet menu Hide option
     */
    sheetHide;
    /**
     * The text of the Sheet menu Duplicate option
     */
    sheetDuplicate;
    /**
     * The text of the Sheet menu Move Left option
     */
    sheetMoveLeft;
    /**
     * The text of the Sheet menu Move Right option
     */
    sheetMoveRight;
    /**
     * The content of the dialog that warns about invalid name input.
     *
     * The content consists of a two-part message - the input value and a localizable string.
     * For user value input **A1%**, the default dialog content will be **Invalid name: A1%**.
     *
     * To allow reordering the input value and the localizable part, the `invalidNameError` accepts a string with a
     * placeholder for the input value, for example, **{inputValue} is invalid**. The `{inputValue}` placeholder will be replaced
     * internally with the current value, and the resulting label will be rendered as **A1% is invalid**.
     */
    invalidNameError;
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MessagesDirective, deps: null, target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: MessagesDirective, isStandalone: true, selector: "[kendoSpreadsheetMessages]", inputs: { home: "home", file: "file", insert: "insert", formatTab: "formatTab", dataTab: "dataTab", saveFile: "saveFile", loadFile: "loadFile", bold: "bold", dataValidation: "dataValidation", validationCellRange: "validationCellRange", validationCriteria: "validationCriteria", validationComparer: "validationComparer", validationMinValue: "validationMinValue", validationMaxValue: "validationMaxValue", validationStartValue: "validationStartValue", validationEndValue: "validationEndValue", validationValue: "validationValue", validationShowListButtonCheckbox: "validationShowListButtonCheckbox", validationShowDateButtonCheckbox: "validationShowDateButtonCheckbox", validationIgnoreBlankCheckbox: "validationIgnoreBlankCheckbox", validationOnInvalidData: "validationOnInvalidData", validationRejectInput: "validationRejectInput", validationShowWarning: "validationShowWarning", validationShowHint: "validationShowHint", anyValueValidationCriteria: "anyValueValidationCriteria", numberValidationCriteria: "numberValidationCriteria", textValidationCriteria: "textValidationCriteria", dateValidationCriteria: "dateValidationCriteria", customFormulaValidationCriteria: "customFormulaValidationCriteria", listValidationCriteria: "listValidationCriteria", greaterThanValidationComparer: "greaterThanValidationComparer", lessThanValidationComparer: "lessThanValidationComparer", betweenValidationComparer: "betweenValidationComparer", notBetweenValidationComparer: "notBetweenValidationComparer", equalToValidationComparer: "equalToValidationComparer", notEqualToValidationComparer: "notEqualToValidationComparer", greaterThanOrEqualToValidationComparer: "greaterThanOrEqualToValidationComparer", lessThanOrEqualToValidationComparer: "lessThanOrEqualToValidationComparer", validationHintMessage: "validationHintMessage", validationHintTitle: "validationHintTitle", italic: "italic", underline: "underline", format: "format", fontFamily: "fontFamily", fontSize: "fontSize", undo: "undo", redo: "redo", background: "background", color: "color", gridLines: "gridLines", addColumnLeft: "addColumnLeft", addColumnRight: "addColumnRight", addRowBelow: "addRowBelow", addRowAbove: "addRowAbove", deleteColumn: "deleteColumn", deleteRow: "deleteRow", wrap: "wrap", align: "align", alignHorizontal: "alignHorizontal", alignVertical: "alignVertical", alignLeft: "alignLeft", alignCenter: "alignCenter", alignRight: "alignRight", alignJustify: "alignJustify", alignTop: "alignTop", alignMiddle: "alignMiddle", alignBottom: "alignBottom", dialogApply: "dialogApply", dialogCancel: "dialogCancel", dialogDelete: "dialogDelete", dialogRename: "dialogRename", dialogInsert: "dialogInsert", dialogRemove: "dialogRemove", dialogRemoveLink: "dialogRemoveLink", delete: "delete", rename: "rename", nameBox: "nameBox", formulaInput: "formulaInput", addSheet: "addSheet", sheetsMenu: "sheetsMenu", view: "view", merge: "merge", mergeHorizontally: "mergeHorizontally", mergeVertically: "mergeVertically", mergeAll: "mergeAll", unmerge: "unmerge", insertLink: "insertLink", increaseDecimal: "increaseDecimal", decreaseDecimal: "decreaseDecimal", increaseFontSize: "increaseFontSize", decreaseFontSize: "decreaseFontSize", openUnsupported: "openUnsupported", modifyMerged: "modifyMerged", cannotModifyDisabled: "cannotModifyDisabled", dialogOk: "dialogOk", dialogError: "dialogError", duplicateSheetName: "duplicateSheetName", copy: "copy", cut: "cut", paste: "paste", hideRow: "hideRow", unhideRow: "unhideRow", hideColumn: "hideColumn", unhideColumn: "unhideColumn", sheetDelete: "sheetDelete", sheetRename: "sheetRename", sheetHide: "sheetHide", sheetDuplicate: "sheetDuplicate", sheetMoveLeft: "sheetMoveLeft", sheetMoveRight: "sheetMoveRight", invalidNameError: "invalidNameError" }, usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: MessagesDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoSpreadsheetMessages]',
                    standalone: true
                }]
        }], propDecorators: { home: [{
                type: Input
            }], file: [{
                type: Input
            }], insert: [{
                type: Input
            }], formatTab: [{
                type: Input
            }], dataTab: [{
                type: Input
            }], saveFile: [{
                type: Input
            }], loadFile: [{
                type: Input
            }], bold: [{
                type: Input
            }], dataValidation: [{
                type: Input
            }], validationCellRange: [{
                type: Input
            }], validationCriteria: [{
                type: Input
            }], validationComparer: [{
                type: Input
            }], validationMinValue: [{
                type: Input
            }], validationMaxValue: [{
                type: Input
            }], validationStartValue: [{
                type: Input
            }], validationEndValue: [{
                type: Input
            }], validationValue: [{
                type: Input
            }], validationShowListButtonCheckbox: [{
                type: Input
            }], validationShowDateButtonCheckbox: [{
                type: Input
            }], validationIgnoreBlankCheckbox: [{
                type: Input
            }], validationOnInvalidData: [{
                type: Input
            }], validationRejectInput: [{
                type: Input
            }], validationShowWarning: [{
                type: Input
            }], validationShowHint: [{
                type: Input
            }], anyValueValidationCriteria: [{
                type: Input
            }], numberValidationCriteria: [{
                type: Input
            }], textValidationCriteria: [{
                type: Input
            }], dateValidationCriteria: [{
                type: Input
            }], customFormulaValidationCriteria: [{
                type: Input
            }], listValidationCriteria: [{
                type: Input
            }], greaterThanValidationComparer: [{
                type: Input
            }], lessThanValidationComparer: [{
                type: Input
            }], betweenValidationComparer: [{
                type: Input
            }], notBetweenValidationComparer: [{
                type: Input
            }], equalToValidationComparer: [{
                type: Input
            }], notEqualToValidationComparer: [{
                type: Input
            }], greaterThanOrEqualToValidationComparer: [{
                type: Input
            }], lessThanOrEqualToValidationComparer: [{
                type: Input
            }], validationHintMessage: [{
                type: Input
            }], validationHintTitle: [{
                type: Input
            }], italic: [{
                type: Input
            }], underline: [{
                type: Input
            }], format: [{
                type: Input
            }], fontFamily: [{
                type: Input
            }], fontSize: [{
                type: Input
            }], undo: [{
                type: Input
            }], redo: [{
                type: Input
            }], background: [{
                type: Input
            }], color: [{
                type: Input
            }], gridLines: [{
                type: Input
            }], addColumnLeft: [{
                type: Input
            }], addColumnRight: [{
                type: Input
            }], addRowBelow: [{
                type: Input
            }], addRowAbove: [{
                type: Input
            }], deleteColumn: [{
                type: Input
            }], deleteRow: [{
                type: Input
            }], wrap: [{
                type: Input
            }], align: [{
                type: Input
            }], alignHorizontal: [{
                type: Input
            }], alignVertical: [{
                type: Input
            }], alignLeft: [{
                type: Input
            }], alignCenter: [{
                type: Input
            }], alignRight: [{
                type: Input
            }], alignJustify: [{
                type: Input
            }], alignTop: [{
                type: Input
            }], alignMiddle: [{
                type: Input
            }], alignBottom: [{
                type: Input
            }], dialogApply: [{
                type: Input
            }], dialogCancel: [{
                type: Input
            }], dialogDelete: [{
                type: Input
            }], dialogRename: [{
                type: Input
            }], dialogInsert: [{
                type: Input
            }], dialogRemove: [{
                type: Input
            }], dialogRemoveLink: [{
                type: Input
            }], delete: [{
                type: Input
            }], rename: [{
                type: Input
            }], nameBox: [{
                type: Input
            }], formulaInput: [{
                type: Input
            }], addSheet: [{
                type: Input
            }], sheetsMenu: [{
                type: Input
            }], view: [{
                type: Input
            }], merge: [{
                type: Input
            }], mergeHorizontally: [{
                type: Input
            }], mergeVertically: [{
                type: Input
            }], mergeAll: [{
                type: Input
            }], unmerge: [{
                type: Input
            }], insertLink: [{
                type: Input
            }], increaseDecimal: [{
                type: Input
            }], decreaseDecimal: [{
                type: Input
            }], increaseFontSize: [{
                type: Input
            }], decreaseFontSize: [{
                type: Input
            }], openUnsupported: [{
                type: Input
            }], modifyMerged: [{
                type: Input
            }], cannotModifyDisabled: [{
                type: Input
            }], dialogOk: [{
                type: Input
            }], dialogError: [{
                type: Input
            }], duplicateSheetName: [{
                type: Input
            }], copy: [{
                type: Input
            }], cut: [{
                type: Input
            }], paste: [{
                type: Input
            }], hideRow: [{
                type: Input
            }], unhideRow: [{
                type: Input
            }], hideColumn: [{
                type: Input
            }], unhideColumn: [{
                type: Input
            }], sheetDelete: [{
                type: Input
            }], sheetRename: [{
                type: Input
            }], sheetHide: [{
                type: Input
            }], sheetDuplicate: [{
                type: Input
            }], sheetMoveLeft: [{
                type: Input
            }], sheetMoveRight: [{
                type: Input
            }], invalidNameError: [{
                type: Input
            }] } });

/**
 * @hidden
 */
class LocalizedMessagesDirective extends MessagesDirective {
    service;
    constructor(service) {
        super();
        this.service = service;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LocalizedMessagesDirective, deps: [{ token: i1.LocalizationService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: LocalizedMessagesDirective, isStandalone: true, selector: "[kendoSpreadsheetLocalizedMessages]", providers: [{
                provide: MessagesDirective,
                useExisting: forwardRef(() => LocalizedMessagesDirective)
            }], usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LocalizedMessagesDirective, decorators: [{
            type: Directive,
            args: [{
                    providers: [{
                            provide: MessagesDirective,
                            useExisting: forwardRef(() => LocalizedMessagesDirective)
                        }],
                    selector: '[kendoSpreadsheetLocalizedMessages]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1.LocalizationService }]; } });

const COMPARER_VALUE_NUMBER = {
    greaterThan: 'validationMinValue',
    lessThan: 'validationMaxValue',
    greaterThanOrEqualTo: 'validationMinValue',
    lessThanOrEqualTo: 'validationMaxValue'
};
const COMPARER_VALUE_DATE = {
    greaterThan: 'validationStartValue',
    lessThan: 'validationEndValue'
};
/**
 * @hidden
 */
class DataValidationDialogComponent extends DialogContentBase {
    localization;
    spreadsheetService;
    zone;
    cellRange;
    criteriaList;
    ignoreBlank = true;
    showButton = true;
    showHint;
    from = null;
    to = null;
    validationFormGroup;
    hintTitle = 'Validation Error';
    hintMessage = 'The value that you entered violates the validation rules set on the cell.';
    _comparer;
    _criteria;
    _onInvalidData;
    onInvalidDataSub;
    allComparers = [];
    textComparers = [];
    dialogAction = new EventEmitter();
    constructor(localization, spreadsheetService, zone, dialog) {
        super(dialog);
        this.localization = localization;
        this.spreadsheetService = spreadsheetService;
        this.zone = zone;
    }
    ngOnInit() {
        if (this.criteria.type === 'any') {
            this.validationFormGroup = new FormGroup({
                range: new FormControl(this.cellRange, [Validators.required, rangeValidator(this)])
            });
        }
        else if (this.comparer?.type === 'between' || this.comparer?.type === 'notBetween') {
            this.validationFormGroup = new FormGroup({
                range: new FormControl(this.cellRange, [Validators.required, rangeValidator(this)]),
                min: new FormControl(this.from, [Validators.required]),
                max: new FormControl(this.to, [Validators.required]),
                onInvalidData: new FormControl(this.onInvalidData)
            });
        }
        else {
            this.validationFormGroup = new FormGroup({
                range: new FormControl(this.cellRange, [Validators.required, rangeValidator(this)]),
                min: new FormControl(this.from, [Validators.required]),
                onInvalidData: new FormControl(this.onInvalidData)
            });
        }
        this.addInvalidDataSub();
        this.criteriaList = [
            { type: 'any', name: this.getLocalizationMessage('anyValueValidationCriteria') },
            { type: 'number', name: this.getLocalizationMessage('numberValidationCriteria') },
            { type: 'text', name: this.getLocalizationMessage('textValidationCriteria') },
            { type: 'date', name: this.getLocalizationMessage('dateValidationCriteria') },
            { type: 'custom', name: this.getLocalizationMessage('customFormulaValidationCriteria') },
            { type: 'list', name: this.getLocalizationMessage('listValidationCriteria') }
        ];
        this.allComparers = [
            { type: 'greaterThan', name: this.getLocalizationMessage('greaterThanValidationComparer') },
            { type: 'lessThan', name: this.getLocalizationMessage('lessThanValidationComparer') },
            { type: 'between', name: this.getLocalizationMessage('betweenValidationComparer') },
            { type: 'notBetween', name: this.getLocalizationMessage('notBetweenValidationComparer') },
            { type: 'equalTo', name: this.getLocalizationMessage('equalToValidationComparer') },
            { type: 'notEqualTo', name: this.getLocalizationMessage('notEqualToValidationComparer') },
            { type: 'greaterThanOrEqualTo', name: this.getLocalizationMessage('greaterThanOrEqualToValidationComparer') },
            { type: 'lessThanOrEqualTo', name: this.getLocalizationMessage('lessThanOrEqualToValidationComparer') }
        ];
        this.textComparers = [
            { type: 'equalTo', name: this.getLocalizationMessage('equalToValidationComparer') },
            { type: 'notEqualTo', name: this.getLocalizationMessage('notEqualToValidationComparer') }
        ];
    }
    ngOnDestroy() {
        this.onInvalidDataSub?.unsubscribe();
        this.onInvalidDataSub = null;
    }
    getLocalizationMessage(key) {
        return this.localization.get(key);
    }
    onRangeChange(value, input) {
        let range;
        try {
            range = this.spreadsheetService.spreadsheet.activeSheet().range(value);
        }
        catch (e) { /** noop */ }
        if (isPresent(range)) {
            range.select();
            this.cellRange = value;
        }
        this.zone.runOutsideAngular(() => {
            setTimeout(() => {
                input.focus();
            });
        });
    }
    onSelectionChange(item, field) {
        if (field === 'criteria') {
            this.from = this.to = null;
            this.comparer = null;
            this.showButton = this.ignoreBlank = true;
            if (item.type === 'any') {
                this.validationFormGroup = new FormGroup({
                    range: new FormControl(this.cellRange, [Validators.required, rangeValidator(this)])
                });
            }
            else {
                this.validationFormGroup = new FormGroup({
                    range: new FormControl(this.cellRange, [Validators.required, rangeValidator(this)]),
                    min: new FormControl(this.from, [Validators.required]),
                    onInvalidData: new FormControl(this.onInvalidData)
                });
            }
        }
        else {
            this.showButton = this.ignoreBlank = true;
            switch (item.type) {
                case 'between':
                case 'notBetween':
                    this.validationFormGroup = new FormGroup({
                        range: new FormControl(this.cellRange, [Validators.required, rangeValidator(this)]),
                        min: new FormControl(this.from, [Validators.required]),
                        max: new FormControl(this.to, [Validators.required]),
                        onInvalidData: new FormControl(this.onInvalidData)
                    });
                    break;
                default:
                    this.validationFormGroup = new FormGroup({
                        range: new FormControl(this.cellRange, [Validators.required, rangeValidator(this)]),
                        min: new FormControl(this.from, [Validators.required]),
                        onInvalidData: new FormControl(this.onInvalidData)
                    });
                    break;
            }
        }
        this.addInvalidDataSub();
        this[field] = item;
    }
    get criteria() {
        return this._criteria || { type: 'any', name: 'Any value' };
    }
    set criteria(value) {
        this._criteria = value;
    }
    get comparer() {
        return this._comparer || this.comparerList[0];
    }
    set comparer(value) {
        this._comparer = value;
    }
    get onInvalidData() {
        return this._onInvalidData || 'reject';
    }
    set onInvalidData(value) {
        this._onInvalidData = value;
    }
    get comparerList() {
        return this.criteria.type === 'text' ? this.textComparers : this.allComparers;
    }
    get singleValue() {
        return !this.comparer.name.includes('between');
    }
    get showComparer() {
        return this.criteria.type === 'number' || this.criteria.type === 'text' || this.criteria.type === 'date';
    }
    setData(args) {
        for (const key in args) {
            this[key] = args[key];
        }
    }
    getValueLabel() {
        const valueLabel = this.localization.get('validationValue');
        if (this.criteria.type === 'custom' || this.criteria.type === 'list') {
            return valueLabel;
        }
        const labelKey = this.criteria.type === 'date' ? COMPARER_VALUE_DATE[this.comparer.type] : COMPARER_VALUE_NUMBER[this.comparer.type];
        return this.localization.get(labelKey) || valueLabel;
    }
    getShowButtonLabel() {
        const labelKey = this.criteria.type === 'list' ? 'validationShowListButtonCheckbox' : 'validationShowDateButtonCheckbox';
        return this.getLocalizationMessage(labelKey);
    }
    get validationPresent() {
        const currentSheet = this.spreadsheetService.spreadsheet.activeSheet();
        return !!currentSheet.range(currentSheet.activeCell()).validation();
    }
    addInvalidDataSub() {
        this.onInvalidDataSub?.unsubscribe();
        if (this.validationFormGroup.get('onInvalidData')) {
            this.onInvalidDataSub = this.validationFormGroup.get('onInvalidData').valueChanges.subscribe((value) => {
                this.onInvalidData = value;
            });
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DataValidationDialogComponent, deps: [{ token: i1.LocalizationService }, { token: SpreadsheetService }, { token: i0.NgZone }, { token: i1$2.DialogRef }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: DataValidationDialogComponent, isStandalone: true, selector: "ng-component", outputs: { dialogAction: "dialogAction" }, usesInheritance: true, ngImport: i0, template: `
        <form class="k-form k-form-md" [formGroup]="validationFormGroup">
            <div class="k-form-field">
                <kendo-label class="k-form-label" [text]="getLocalizationMessage('validationCellRange')" [for]="rangeInput"></kendo-label>
                <div class="k-form-field-wrap">
                    <kendo-textbox #rangeInput
                        [clearButton]="true"
                        [value]="cellRange"
                        (valueChange)="onRangeChange($event, rangeInput)"
                        formControlName="range">
                    </kendo-textbox>
                </div>
            </div>
            <div class="k-form-field">
                <kendo-label class="k-form-label" [text]="getLocalizationMessage('validationCriteria')" [for]="criteriaInput"></kendo-label>
                <div class="k-form-field-wrap">
                    <kendo-dropdownlist #criteriaInput
                        [data]="criteriaList"
                        [value]="criteria"
                        (selectionChange)="onSelectionChange($event, 'criteria')"
                        textField="name"
                        valueField="type">
                    </kendo-dropdownlist>
                </div>
            </div>
            <ng-container *ngIf="criteria.type !== 'any'">
                <div class="k-form-field" *ngIf="showComparer">
                    <kendo-label class="k-form-label" [text]="getLocalizationMessage('validationComparer')" [for]="comparerInput"></kendo-label>
                    <div class="k-form-field-wrap">
                        <kendo-dropdownlist #comparerInput
                            [data]="comparerList"
                            [value]="comparer"
                            (selectionChange)="onSelectionChange($event, 'comparer')"
                            textField="name"
                            valueField="type">
                        </kendo-dropdownlist>
                    </div>
                </div>
                <div class="k-form-field" *ngIf="singleValue; else betweenValues">
                    <kendo-label class="k-label k-form-label" [text]="getValueLabel()" [for]="minInput"></kendo-label>
                    <div class="k-form-field-wrap">
                        <kendo-textbox #minInput [(value)]="from" formControlName="min"></kendo-textbox>
                    </div>
                </div>
                <ng-template #betweenValues>
                    <div class="k-form-field">
                        <kendo-label class="k-form-label" [text]="getLocalizationMessage(criteria.type === 'date' ? 'validationStartValue' : 'validationMinValue')" [for]="betweenMinInput"></kendo-label>
                        <div class="k-form-field-wrap">
                            <kendo-textbox #betweenMinInput [(value)]="from" formControlName="min"></kendo-textbox>
                        </div>
                    </div>
                    <div class="k-form-field">
                        <kendo-label class="k-form-label" [text]="getLocalizationMessage(criteria.type === 'date' ? 'validationEndValue' : 'validationMaxValue')" [for]="betweenMaxInput"></kendo-label>
                        <div class="k-form-field-wrap">
                            <kendo-textbox #betweenMaxInput [(value)]="to" formControlName="max"></kendo-textbox>
                        </div>
                    </div>
                </ng-template>
                <div class="k-form-field" *ngIf="criteria.type === 'list'">
                    <div class="k-form-field-wrap">
                        <kendo-checkbox #showBtnCheckBox [(checkedState)]="showButton"></kendo-checkbox>
                        <kendo-label class="k-checkbox-label" [for]="showBtnCheckBox" [text]="getLocalizationMessage('validationShowListButtonCheckbox')"></kendo-label>
                    </div>
                </div>
                <div class="k-form-field">
                    <div class="k-form-field-wrap">
                        <kendo-checkbox #ignoreBlankCheckBox [(checkedState)]="ignoreBlank"></kendo-checkbox>
                        <kendo-label class="k-checkbox-label" [for]="ignoreBlankCheckBox" [text]="getLocalizationMessage('validationIgnoreBlankCheckbox')"></kendo-label>
                    </div>
                </div>
                <div class="k-form-field">
                    <kendo-label class="k-form-label" [text]="getLocalizationMessage('validationOnInvalidData')"></kendo-label>
                    <div class="k-form-field-wrap">
                        <ul class="k-radio-list k-list-vertical">
                            <li class="k-radio-list-item">
                                <kendo-radiobutton #rejectRadioBtn formControlName="onInvalidData" value="reject"></kendo-radiobutton>
                                <kendo-label class="k-radio-label" [for]="rejectRadioBtn" [text]="getLocalizationMessage('validationRejectInput')"></kendo-label>
                            </li>
                            <li class="k-radio-list-item">
                                <kendo-radiobutton #warningRadioBtn formControlName="onInvalidData" value="warning"></kendo-radiobutton>
                                <kendo-label class="k-radio-label" [for]="warningRadioBtn" [text]="getLocalizationMessage('validationShowWarning')"></kendo-label>
                            </li>
                        </ul>
                    </div>
                </div>
                <div class="k-form-field">
                    <div class="k-form-field-wrap">
                        <kendo-checkbox #showHintCheckBox [(checkedState)]="showHint"></kendo-checkbox>
                        <kendo-label class="k-checkbox-label" [for]="showHintCheckBox" [text]="getLocalizationMessage('validationShowHint')"></kendo-label>
                    </div>
                </div>
                <div class="k-form-field">
                    <kendo-label class="k-form-label" [text]="getLocalizationMessage('validationHintTitle')" [for]="hintTitleInput"></kendo-label>
                    <div class="k-form-field-wrap">
                        <kendo-textbox #hintTitleInput [(value)]="hintTitle"></kendo-textbox>
                    </div>
                </div>
                <div class="k-form-field">
                    <kendo-label class="k-form-label" [text]="getLocalizationMessage('validationHintMessage')" [for]="hintMessageInput"></kendo-label>
                    <div class="k-form-field-wrap">
                        <kendo-textbox #hintMessageInput [(value)]="hintMessage"></kendo-textbox>
                    </div>
                </div>
            </ng-container>
        </form>
        <kendo-dialog-actions layout="start" #dialogActions>
            <button kendoButton themeColor="primary" [disabled]="validationFormGroup?.invalid" (click)="dialogAction.emit(getLocalizationMessage('dialogApply'))">
                {{getLocalizationMessage('dialogApply')}}
            </button>
            <button kendoButton (click)="dialogAction.emit(getLocalizationMessage('dialogCancel'))">{{getLocalizationMessage('dialogCancel')}}</button>
            <button kendoButton themeColor="error" fillMode="flat" *ngIf="validationPresent" (click)="dialogAction.emit(getLocalizationMessage('dialogRemove'))">
                {{getLocalizationMessage('dialogRemove')}}
            </button>
        </kendo-dialog-actions>
    `, isInline: true, dependencies: [{ kind: "component", type: TextBoxComponent, selector: "kendo-textbox", inputs: ["focusableId", "title", "type", "disabled", "readonly", "tabindex", "value", "selectOnFocus", "showSuccessIcon", "showErrorIcon", "clearButton", "successIcon", "successSvgIcon", "errorIcon", "errorSvgIcon", "clearButtonIcon", "clearButtonSvgIcon", "size", "rounded", "fillMode", "tabIndex", "placeholder", "maxlength", "inputAttributes"], outputs: ["valueChange", "inputFocus", "inputBlur", "focus", "blur"], exportAs: ["kendoTextBox"] }, { kind: "component", type: DropDownListComponent, selector: "kendo-dropdownlist", inputs: ["customIconClass", "showStickyHeader", "icon", "svgIcon", "loading", "data", "value", "textField", "valueField", "adaptiveMode", "adaptiveTitle", "adaptiveSubtitle", "popupSettings", "listHeight", "defaultItem", "disabled", "itemDisabled", "readonly", "filterable", "virtual", "ignoreCase", "delay", "valuePrimitive", "tabindex", "tabIndex", "size", "rounded", "fillMode", "leftRightArrowsNavigation", "id"], outputs: ["valueChange", "filterChange", "selectionChange", "open", "opened", "close", "closed", "focus", "blur"], exportAs: ["kendoDropDownList"] }, { kind: "component", type: CheckBoxComponent, selector: "kendo-checkbox", inputs: ["checkedState", "rounded"], outputs: ["checkedStateChange"], exportAs: ["kendoCheckBox"] }, { kind: "component", type: RadioButtonComponent, selector: "kendo-radiobutton", inputs: ["checked"], outputs: ["checkedChange"], exportAs: ["kendoRadioButton"] }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "ngmodule", type: ReactiveFormsModule }, { kind: "directive", type: i4.ɵNgNoValidate, selector: "form:not([ngNoForm]):not([ngNativeValidate])" }, { kind: "directive", type: i4.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i4.NgControlStatusGroup, selector: "[formGroupName],[formArrayName],[ngModelGroup],[formGroup],form:not([ngNoForm]),[ngForm]" }, { kind: "directive", type: i4.FormGroupDirective, selector: "[formGroup]", inputs: ["formGroup"], outputs: ["ngSubmit"], exportAs: ["ngForm"] }, { kind: "directive", type: i4.FormControlName, selector: "[formControlName]", inputs: ["formControlName", "disabled", "ngModel"], outputs: ["ngModelChange"] }, { kind: "component", type: LabelComponent, selector: "kendo-label", inputs: ["text", "for", "optional", "labelCssStyle", "labelCssClass"], exportAs: ["kendoLabel"] }, { kind: "component", type: DialogActionsComponent, selector: "kendo-dialog-actions", inputs: ["actions", "layout"], outputs: ["action"] }, { kind: "component", type: ButtonComponent, selector: "button[kendoButton]", inputs: ["arrowIcon", "toggleable", "togglable", "selected", "tabIndex", "imageUrl", "iconClass", "icon", "disabled", "size", "rounded", "fillMode", "themeColor", "svgIcon", "primary", "look"], outputs: ["selectedChange", "click"], exportAs: ["kendoButton"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: DataValidationDialogComponent, decorators: [{
            type: Component,
            args: [{
                    template: `
        <form class="k-form k-form-md" [formGroup]="validationFormGroup">
            <div class="k-form-field">
                <kendo-label class="k-form-label" [text]="getLocalizationMessage('validationCellRange')" [for]="rangeInput"></kendo-label>
                <div class="k-form-field-wrap">
                    <kendo-textbox #rangeInput
                        [clearButton]="true"
                        [value]="cellRange"
                        (valueChange)="onRangeChange($event, rangeInput)"
                        formControlName="range">
                    </kendo-textbox>
                </div>
            </div>
            <div class="k-form-field">
                <kendo-label class="k-form-label" [text]="getLocalizationMessage('validationCriteria')" [for]="criteriaInput"></kendo-label>
                <div class="k-form-field-wrap">
                    <kendo-dropdownlist #criteriaInput
                        [data]="criteriaList"
                        [value]="criteria"
                        (selectionChange)="onSelectionChange($event, 'criteria')"
                        textField="name"
                        valueField="type">
                    </kendo-dropdownlist>
                </div>
            </div>
            <ng-container *ngIf="criteria.type !== 'any'">
                <div class="k-form-field" *ngIf="showComparer">
                    <kendo-label class="k-form-label" [text]="getLocalizationMessage('validationComparer')" [for]="comparerInput"></kendo-label>
                    <div class="k-form-field-wrap">
                        <kendo-dropdownlist #comparerInput
                            [data]="comparerList"
                            [value]="comparer"
                            (selectionChange)="onSelectionChange($event, 'comparer')"
                            textField="name"
                            valueField="type">
                        </kendo-dropdownlist>
                    </div>
                </div>
                <div class="k-form-field" *ngIf="singleValue; else betweenValues">
                    <kendo-label class="k-label k-form-label" [text]="getValueLabel()" [for]="minInput"></kendo-label>
                    <div class="k-form-field-wrap">
                        <kendo-textbox #minInput [(value)]="from" formControlName="min"></kendo-textbox>
                    </div>
                </div>
                <ng-template #betweenValues>
                    <div class="k-form-field">
                        <kendo-label class="k-form-label" [text]="getLocalizationMessage(criteria.type === 'date' ? 'validationStartValue' : 'validationMinValue')" [for]="betweenMinInput"></kendo-label>
                        <div class="k-form-field-wrap">
                            <kendo-textbox #betweenMinInput [(value)]="from" formControlName="min"></kendo-textbox>
                        </div>
                    </div>
                    <div class="k-form-field">
                        <kendo-label class="k-form-label" [text]="getLocalizationMessage(criteria.type === 'date' ? 'validationEndValue' : 'validationMaxValue')" [for]="betweenMaxInput"></kendo-label>
                        <div class="k-form-field-wrap">
                            <kendo-textbox #betweenMaxInput [(value)]="to" formControlName="max"></kendo-textbox>
                        </div>
                    </div>
                </ng-template>
                <div class="k-form-field" *ngIf="criteria.type === 'list'">
                    <div class="k-form-field-wrap">
                        <kendo-checkbox #showBtnCheckBox [(checkedState)]="showButton"></kendo-checkbox>
                        <kendo-label class="k-checkbox-label" [for]="showBtnCheckBox" [text]="getLocalizationMessage('validationShowListButtonCheckbox')"></kendo-label>
                    </div>
                </div>
                <div class="k-form-field">
                    <div class="k-form-field-wrap">
                        <kendo-checkbox #ignoreBlankCheckBox [(checkedState)]="ignoreBlank"></kendo-checkbox>
                        <kendo-label class="k-checkbox-label" [for]="ignoreBlankCheckBox" [text]="getLocalizationMessage('validationIgnoreBlankCheckbox')"></kendo-label>
                    </div>
                </div>
                <div class="k-form-field">
                    <kendo-label class="k-form-label" [text]="getLocalizationMessage('validationOnInvalidData')"></kendo-label>
                    <div class="k-form-field-wrap">
                        <ul class="k-radio-list k-list-vertical">
                            <li class="k-radio-list-item">
                                <kendo-radiobutton #rejectRadioBtn formControlName="onInvalidData" value="reject"></kendo-radiobutton>
                                <kendo-label class="k-radio-label" [for]="rejectRadioBtn" [text]="getLocalizationMessage('validationRejectInput')"></kendo-label>
                            </li>
                            <li class="k-radio-list-item">
                                <kendo-radiobutton #warningRadioBtn formControlName="onInvalidData" value="warning"></kendo-radiobutton>
                                <kendo-label class="k-radio-label" [for]="warningRadioBtn" [text]="getLocalizationMessage('validationShowWarning')"></kendo-label>
                            </li>
                        </ul>
                    </div>
                </div>
                <div class="k-form-field">
                    <div class="k-form-field-wrap">
                        <kendo-checkbox #showHintCheckBox [(checkedState)]="showHint"></kendo-checkbox>
                        <kendo-label class="k-checkbox-label" [for]="showHintCheckBox" [text]="getLocalizationMessage('validationShowHint')"></kendo-label>
                    </div>
                </div>
                <div class="k-form-field">
                    <kendo-label class="k-form-label" [text]="getLocalizationMessage('validationHintTitle')" [for]="hintTitleInput"></kendo-label>
                    <div class="k-form-field-wrap">
                        <kendo-textbox #hintTitleInput [(value)]="hintTitle"></kendo-textbox>
                    </div>
                </div>
                <div class="k-form-field">
                    <kendo-label class="k-form-label" [text]="getLocalizationMessage('validationHintMessage')" [for]="hintMessageInput"></kendo-label>
                    <div class="k-form-field-wrap">
                        <kendo-textbox #hintMessageInput [(value)]="hintMessage"></kendo-textbox>
                    </div>
                </div>
            </ng-container>
        </form>
        <kendo-dialog-actions layout="start" #dialogActions>
            <button kendoButton themeColor="primary" [disabled]="validationFormGroup?.invalid" (click)="dialogAction.emit(getLocalizationMessage('dialogApply'))">
                {{getLocalizationMessage('dialogApply')}}
            </button>
            <button kendoButton (click)="dialogAction.emit(getLocalizationMessage('dialogCancel'))">{{getLocalizationMessage('dialogCancel')}}</button>
            <button kendoButton themeColor="error" fillMode="flat" *ngIf="validationPresent" (click)="dialogAction.emit(getLocalizationMessage('dialogRemove'))">
                {{getLocalizationMessage('dialogRemove')}}
            </button>
        </kendo-dialog-actions>
    `,
                    standalone: true,
                    imports: [TextBoxComponent, DropDownListComponent, CheckBoxComponent, RadioButtonComponent, NgIf, ReactiveFormsModule, LabelComponent, DialogActionsComponent, ButtonComponent]
                }]
        }], ctorParameters: function () { return [{ type: i1.LocalizationService }, { type: SpreadsheetService }, { type: i0.NgZone }, { type: i1$2.DialogRef }]; }, propDecorators: { dialogAction: [{
                type: Output
            }] } });

const COMPARERS_LIST = [
    { type: 'greaterThan', name: 'greater than' },
    { type: 'lessThan', name: 'less than' },
    { type: 'between', name: 'between' },
    { type: 'notBetween', name: 'not between' },
    { type: 'equalTo', name: 'equal to' },
    { type: 'notEqualTo', name: 'not equal to' },
    { type: 'greaterThanOrEqualTo', name: 'greater than or equal to' },
    { type: 'lessThanOrEqualTo', name: 'less than or equal to' }
];
const CRITERIA_LIST = [
    { type: 'any', name: 'Any value' },
    { type: 'number', name: 'Number' },
    { type: 'text', name: 'Text' },
    { type: 'date', name: 'Date' },
    { type: 'custom', name: 'Custom Formula' },
    { type: 'list', name: 'List' }
];
/**
 * @hidden
 */
class SpreadsheetDataValidationDirective extends SpreadsheetCommandButton {
    dialogService;
    renderer;
    constructor(button, localization, spreadsheetService, toolsService, dialogService, renderer) {
        super('dataValidation', button, localization, spreadsheetService, toolsService, {
            command: 'EditValidationCommand', options: { value: '' }
        });
        this.dialogService = dialogService;
        this.renderer = renderer;
        button.showText = 'always';
    }
    get currentRange() {
        return this.spreadsheetService.spreadsheet.options.nameBoxRef.current.value();
    }
    ngAfterViewInit() {
        this.renderer.setAttribute(this.button.toolbarButtonElement.nativeElement, 'aria-haspopup', 'dialog');
        this.renderer.setAttribute(this.button.toolbarButtonElement.nativeElement, 'aria-expanded', 'false');
    }
    clickHandler() {
        this.openDialog();
    }
    /**
     * @hidden
     */
    openDialog() {
        const currentSheet = this.spreadsheetService.spreadsheet.activeSheet();
        const currentRangeValidation = currentSheet.range(currentSheet.activeCell()).validation();
        const dialogSettings = {
            appendTo: this.spreadsheetService.dialogContainer,
            title: this.localization.get(this.command),
            content: DataValidationDialogComponent,
            minWidth: 400,
            maxHeight: '90%',
        };
        const dialog = this.dialogService.open(dialogSettings);
        const dialogContent = dialog.content.instance;
        this.renderer.setAttribute(this.button.toolbarButtonElement.nativeElement, 'aria-expanded', 'true');
        let contentData;
        if (currentRangeValidation) {
            contentData = {
                cellRange: this.currentRange,
                to: currentRangeValidation.to,
                from: currentRangeValidation.from,
                criteria: { type: currentRangeValidation.dataType, name: CRITERIA_LIST.find(i => i.type === currentRangeValidation.dataType).name },
                comparer: currentRangeValidation.dataType === 'custom' || currentRangeValidation.dataType === 'list' ? null : { type: currentRangeValidation.comparerType, name: COMPARERS_LIST.find(i => i.type === currentRangeValidation.comparerType).name },
                ignoreBlank: currentRangeValidation.allowNulls,
                showButton: currentRangeValidation.showButton,
                onInvalidData: currentRangeValidation.type
            };
            if (currentRangeValidation.messageTemplate || currentRangeValidation.titleTemplate) {
                contentData = Object.assign(contentData, {
                    hintMessage: currentRangeValidation.messageTemplate,
                    hintTitle: currentRangeValidation.titleTemplate,
                    showHint: true
                });
            }
        }
        else {
            contentData = { cellRange: this.currentRange };
        }
        dialogContent.setData(contentData);
        dialogContent.dialogAction.pipe(take(1)).subscribe((actionType) => {
            if (actionType === this.localization.get('dialogCancel')) {
                dialog.close();
                this.renderer.setAttribute(this.button.toolbarButtonElement.nativeElement, 'aria-expanded', 'false');
            }
            else {
                let options = {
                    type: dialogContent.onInvalidData,
                    dataType: dialogContent.criteria.type,
                    comparerType: dialogContent.comparer.type,
                    from: dialogContent.from,
                    to: dialogContent.to,
                    allowNulls: dialogContent.ignoreBlank,
                    showButton: dialogContent.showButton,
                    messageTemplate: dialogContent.showHint ? dialogContent.hintMessage : null,
                    titleTemplate: dialogContent.showHint ? dialogContent.hintTitle : null
                };
                if (dialogContent.criteria.type === 'list' || dialogContent.criteria.type === 'text') {
                    const isWrappedInQuotes = options.from.startsWith('"') && options.from.endsWith('"');
                    let isRangeValue = true;
                    try {
                        isRangeValue = Boolean(this.spreadsheetService.spreadsheet.activeSheet().range(dialogContent.from));
                    }
                    catch (e) {
                        isRangeValue = false;
                    }
                    if (!isWrappedInQuotes && !isRangeValue) {
                        options = Object.assign(options, { from: `"${options.from}"` });
                    }
                }
                if (actionType === this.localization.get('dialogRemove') || dialogContent.criteria.type === 'any') {
                    options = null;
                }
                this.spreadsheetService.spreadsheet.executeCommand({
                    command: 'EditValidationCommand',
                    options: { value: options }
                });
                dialog.close();
                this.renderer.setAttribute(this.button.toolbarButtonElement.nativeElement, 'aria-expanded', 'false');
            }
        });
        dialog.dialog.instance.close.pipe(take(1)).subscribe(() => {
            this.renderer.setAttribute(this.button.toolbarButtonElement.nativeElement, 'aria-expanded', 'false');
        });
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetDataValidationDirective, deps: [{ token: i1$3.ToolBarButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }, { token: i1$2.DialogService }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetDataValidationDirective, isStandalone: true, selector: "kendo-toolbar-button[kendoSpreadsheetDataValidation]", usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetDataValidationDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: 'kendo-toolbar-button[kendoSpreadsheetDataValidation]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }, { type: i1$2.DialogService }, { type: i0.Renderer2 }]; } });

/**
 * @hidden
 */
class ListEditorComponent {
    ngZone;
    spreadsheetService;
    data = [];
    focusedIndex = 0;
    itemSelect = new EventEmitter();
    close = new EventEmitter();
    listItems;
    constructor(ngZone, spreadsheetService) {
        this.ngZone = ngZone;
        this.spreadsheetService = spreadsheetService;
    }
    ngAfterViewInit() {
        this.ngZone.onStable.pipe(take(1)).subscribe(() => {
            this.spreadsheetService.spreadsheet.view.clipboard.blur();
            this.focusItem(0);
        });
    }
    onItemClick(item) {
        this.itemSelect.emit(item);
    }
    onKeyDown(event, index) {
        const altKey = event.altKey;
        switch (event.keyCode) {
            case Keys.ArrowDown:
            case Keys.ArrowRight:
                event.preventDefault();
                this.focusNext();
                break;
            case Keys.ArrowUp:
                if (altKey) {
                    this.closeList();
                }
                else {
                    this.focusPrev();
                }
                break;
            case Keys.ArrowLeft:
                event.preventDefault();
                this.focusPrev();
                break;
            case Keys.Enter:
            case Keys.Space:
                event.preventDefault();
                this.onItemClick(this.data[index]);
                break;
            case Keys.Escape:
                event.preventDefault();
                this.closeList();
                break;
        }
    }
    focusNext() {
        if (this.focusedIndex + 1 === this.data.length) {
            this.focusItem(0);
        }
        else {
            this.focusItem(this.focusedIndex + 1);
        }
    }
    focusPrev() {
        if (this.focusedIndex - 1 < 0) {
            this.focusItem(this.data.length - 1);
        }
        else {
            this.focusItem(this.focusedIndex - 1);
        }
    }
    closeList() {
        this.close.emit();
        this.spreadsheetService.spreadsheet.view.clipboard.focus();
    }
    focusItem(index) {
        if (this.data.length === 0) {
            return;
        }
        this.focusedIndex = index;
        const items = this.listItems.toArray();
        if (items[index]) {
            items[index].nativeElement.focus();
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ListEditorComponent, deps: [{ token: i0.NgZone }, { token: SpreadsheetService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: ListEditorComponent, isStandalone: true, selector: "ng-component", outputs: { itemSelect: "itemSelect", close: "close" }, viewQueries: [{ propertyName: "listItems", predicate: ["listItem"], descendants: true, read: ElementRef }], ngImport: i0, template: `
        <ul class="k-list k-reset k-list-ul" role="listbox">
            <li *ngFor="let item of data; let i = index"
                role="option"
                class="k-list-item"
                [class.k-focus]="i === focusedIndex"
                [attr.aria-selected]="i === focusedIndex"
                [attr.tabindex]="i === focusedIndex ? 0 : -1"
                (click)="onItemClick(item)"
                (keydown)="onKeyDown($event, i)"
                #listItem>
                <span class="k-list-item-text">{{item.value}}</span>
            </li>
        </ul>
    `, isInline: true, dependencies: [{ kind: "directive", type: NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ListEditorComponent, decorators: [{
            type: Component,
            args: [{
                    template: `
        <ul class="k-list k-reset k-list-ul" role="listbox">
            <li *ngFor="let item of data; let i = index"
                role="option"
                class="k-list-item"
                [class.k-focus]="i === focusedIndex"
                [attr.aria-selected]="i === focusedIndex"
                [attr.tabindex]="i === focusedIndex ? 0 : -1"
                (click)="onItemClick(item)"
                (keydown)="onKeyDown($event, i)"
                #listItem>
                <span class="k-list-item-text">{{item.value}}</span>
            </li>
        </ul>
    `,
                    standalone: true,
                    imports: [NgForOf]
                }]
        }], ctorParameters: function () { return [{ type: i0.NgZone }, { type: SpreadsheetService }]; }, propDecorators: { itemSelect: [{
                type: Output
            }], close: [{
                type: Output
            }], listItems: [{
                type: ViewChildren,
                args: ['listItem', { read: ElementRef }]
            }] } });

/**
 * @hidden
 */
class CalendarComponent {
    value;
    type = 'classic';
    min;
    max;
    disabledDates;
    valueChange = new EventEmitter();
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CalendarComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: CalendarComponent, isStandalone: true, selector: "ng-component", outputs: { valueChange: "valueChange" }, ngImport: i0, template: `
        <kendo-calendar
            [type]="type"
            [min]="min"
            [max]="max"
            [value]="value"
            [disabledDates]="disabledDates"
            (valueChange)="valueChange.emit($event)">
        </kendo-calendar>
    `, isInline: true, dependencies: [{ kind: "component", type: CalendarComponent$1, selector: "kendo-calendar", inputs: ["showOtherMonthDays", "id", "focusedDate", "min", "max", "rangeValidation", "weekDaysFormat", "footer", "selection", "allowReverse", "value", "disabled", "tabindex", "tabIndex", "disabledDates", "navigation", "activeView", "bottomView", "topView", "type", "animateNavigation", "weekNumber", "cellTemplate", "monthCellTemplate", "yearCellTemplate", "decadeCellTemplate", "centuryCellTemplate", "weekNumberTemplate", "headerTitleTemplate", "headerTemplate", "footerTemplate", "navigationItemTemplate", "size", "activeRangeEnd"], outputs: ["closePopup", "activeViewChange", "navigate", "activeViewDateChange", "blur", "focus", "valueChange"], exportAs: ["kendo-calendar"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CalendarComponent, decorators: [{
            type: Component,
            args: [{
                    template: `
        <kendo-calendar
            [type]="type"
            [min]="min"
            [max]="max"
            [value]="value"
            [disabledDates]="disabledDates"
            (valueChange)="valueChange.emit($event)">
        </kendo-calendar>
    `,
                    standalone: true,
                    imports: [CalendarComponent$1]
                }]
        }], propDecorators: { valueChange: [{
                type: Output
            }] } });

/**
 * Represents the [Kendo UI Spreadsheet component for Angular]({% slug overview_spreadsheet %}).
 */
class SpreadsheetComponent {
    ngZone;
    intl;
    host;
    localization;
    spreadsheetService;
    toolsService;
    errorService;
    dialogService;
    popupService;
    container;
    formulaBarInputRef;
    formulaCellInputRef;
    nameBoxRef;
    dialogContainer;
    contextMenu;
    hostClass = true;
    role = 'application';
    /**
     * The menu items configuration.
     */
    set menuItems(items) {
        this._menuItems = [];
        this.ngZone.onStable.pipe(take(1)).subscribe(() => {
            const normalizedItems = items.map(item => ({
                active: item.active,
                text: item.id === 'format' || item.id === 'data' ? this.messageFor(`${item.id}Tab`) : this.messageFor(item.id),
                cssClass: item.active ? 'k-active' : null,
                id: item.id
            }));
            this._menuItems = normalizedItems;
            const activeItemIndex = this.menuItems.findIndex(item => item.active);
            this.selectedMenuItem = this.menuItems[activeItemIndex > -1 ? activeItemIndex : 0];
        });
    }
    get menuItems() {
        return this._menuItems;
    }
    /**
     * Sets the overflow option of the built-in Toolbar components.
     * @default false
     */
    overflow = false;
    /**
     * Sets the height of the formula list container.
     * Accepts same values as the CSS [`style.height`](https://developer.mozilla.org/en-US/docs/Web/CSS/height) property.
     *
     * @default '300px'
     */
    formulaListMaxHeight = '300px';
    /**
     * The name of the currently active sheet. Must match one of the sheet names.
     */
    set activeSheet(value) {
        this._activeSheet = value;
        this.spreadsheetService.spreadsheet?.view?.sheetsbar.onSheetSelect(this.activeSheet);
    }
    get activeSheet() {
        return this._activeSheet || this.spreadsheetService.spreadsheet?.activeSheet()?.name();
    }
    /**
     * An array which defines the document sheets and their content.
     */
    set sheets(value) {
        const items = value.map((item, index, items) => ({
            ...item,
            state: item.state || 'visible',
            inEdit: false,
            first: index === 0,
            last: index === items.length - 1,
            text: item.name,
            active: (item.name === this.activeSheet) || items.length === 1,
            index
        }));
        this._sheetsInfo = items;
    }
    get sheetsInfo() {
        return this._sheetsInfo;
    }
    /**
     * The number of columns in the document.
     *
     * @default 50
     */
    columns = 50;
    /**
     * The initial column width in pixels.
     *
     * @default 100
     */
    columnWidth = 100;
    /**
     * The initial styles applies to the sheet cells.
     */
    defaultCellStyle;
    /**
     * The height of the header row in pixels.
     *
     * @default 30
     */
    headerHeight = 30;
    /**
     * The width of the header column in pixels.
     *
     * @default 32
     */
    headerWidth = 32;
    /**
     * The initial row height in pixels.
     *
     * @default 30
     */
    rowHeight = 30;
    /**
     * The number of rows in the document.
     *
     * @default 200
     */
    rows = 200;
    /**
     * An object containing any images used in the Spreadsheet. The keys should be image IDs (they are referenced by this ID in `sheets.drawings`),
     * and the values should be image URLs. The image URLs can be either [`data URLs`](https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/Data_URLs)
     * (in which case the images are fully contained by the JSON), or external URLs.
     */
    images;
    /**
     * Configures the Excel export settings of the Spreadsheet.
     */
    excel;
    /**
     * Fired when a value in the Spreadsheet is changed. Exposes the `SpreadsheetWidget` instance and the selected `Range` as event data.
     */
    change = new EventEmitter();
    /**
     * Fired when the selected range format is changed from the UI. Exposes the `SpreadsheetWidget` instance and the selected `Range` as event data.
     */
    formatChange = new EventEmitter();
    /**
     * Fired when the selection is changed by the end user. Exposes the `SpreadsheetWidget` instance and the selected `Range` as event data.
     */
    selectionChange = new EventEmitter();
    /**
     * Fired when the end user clicks the Export to Excel toolbar button.
     * The event is preventable and exposes the `Workbook` object, a `preventDefault` method
     * (if invoked, the generated file will not be saved), and the SpreadsheetWidget instance.
     */
    excelExport = new EventEmitter();
    /**
     * Fired when the end user clicks the Open toolbar button.
     * The event is preventable and exposes the selected `File` or `Blob`, a `preventDefault` method
     * (if invoked, the selected file will not be loaded), and the SpreadsheetWidget instance.
     */
    excelImport = new EventEmitter();
    /**
     * Fired when the active sheet is about to change.
     * The event exposes the new active `Sheet` and the SpreadsheetWidget instance.
     */
    activeSheetChange = new EventEmitter();
    formulaFxIcon = formulaFxIcon;
    folderOpenIcon = folderOpenIcon;
    downloadIcon = downloadIcon;
    selectedMenuItem;
    get spreadsheetWidget() {
        return this.spreadsheetService.spreadsheet;
    }
    showLicenseWatermark = false;
    contextMenuItems = [];
    _sheetsInfo;
    _activeSheet;
    _menuItems;
    currentRange;
    subs = new Subscription();
    popupRef;
    constructor(ngZone, intl, host, localization, spreadsheetService, toolsService, errorService, dialogService, popupService, container) {
        this.ngZone = ngZone;
        this.intl = intl;
        this.host = host;
        this.localization = localization;
        this.spreadsheetService = spreadsheetService;
        this.toolsService = toolsService;
        this.errorService = errorService;
        this.dialogService = dialogService;
        this.popupService = popupService;
        this.container = container;
        const isValid = validatePackage(packageMetadata);
        this.showLicenseWatermark = shouldShowValidationUI(isValid);
        ngZone.onStable.pipe(take(1)).subscribe(() => {
            if (!this.menuItems) {
                this._menuItems = [{
                        id: 'file',
                        text: this.messageFor('file')
                    }, {
                        id: 'home',
                        text: this.messageFor('home'),
                        active: true,
                        cssClass: 'k-active'
                    }, {
                        id: 'insert',
                        text: this.messageFor('insert')
                    }, {
                        id: 'format',
                        text: this.messageFor('formatTab')
                    }, {
                        id: 'data',
                        text: this.messageFor('dataTab')
                    }, {
                        id: 'view',
                        text: this.messageFor('view')
                    }];
            }
            this.selectedMenuItem = this.menuItems[1];
        });
    }
    ngAfterViewInit() {
        if (!isDocumentAvailable()) {
            return;
        }
        this.ngZone.runOutsideAngular(() => {
            setTimeout(() => {
                const spreadsheet = this.spreadsheetService.spreadsheet = new SpreadsheetWidget(this.host.nativeElement, this.options);
                spreadsheet.bind('select', this.onSelectionChange);
                spreadsheet.bind('change', this.onChange);
                spreadsheet.bind('changeFormat', this.onChangeFormat);
                spreadsheet.bind('excelImport', this.onExcelImport);
                spreadsheet.bind('excelExport', this.onExcelExport);
                spreadsheet.bind('keydown', this.onKeyDown);
                spreadsheet.view.bind('update', this.updateState);
                spreadsheet.view.bind('message', this.onMessage);
                spreadsheet.bind('contextmenu', this.onContextMenu.bind(this));
                const sheet = spreadsheet.activeSheet();
                if (sheet) {
                    this.updateState({ range: sheet.range(sheet.activeCell()) });
                }
                this.updateActiveSheet(this.activeSheet || spreadsheet?.activeSheet()?.name());
                this.configureSheets(spreadsheet);
            });
            this.subs.add(this.spreadsheetService.sheetsChanged.subscribe(this.onSheetsChanged.bind(this)));
            this.subs.add(this.spreadsheetService.activeSheetChanged.subscribe(this.onActiveSheetChanged.bind(this)));
            this.subs.add(this.spreadsheetService.selectionChanged.subscribe(range => {
                this.currentRange = range;
                if (this.popupRef) {
                    this.popupRef.close();
                    this.popupRef = null;
                }
            }));
            this.spreadsheetService.dialogContainer = this.dialogContainer;
        });
        this.registerEditors();
    }
    ngOnChanges(changes) {
        const dynamicOptions = [
            'columns',
            'columnWidth',
            'defaultCellStyle',
            'excel',
            'headerHeight',
            'headerWidth',
            'images',
            'names',
            'rowHeight',
            'rows',
            'sheets'
        ];
        const changedDynamicOptions = dynamicOptions.filter(o => isPresent(changes[o] && !changes[o].firstChange));
        if (this.spreadsheetWidget && changedDynamicOptions.length) {
            const newOptions = this.spreadsheetWidget.toJSON();
            changedDynamicOptions.forEach(o => newOptions[o] = changes[o].currentValue);
            this.spreadsheetWidget.fromJSON(newOptions);
        }
    }
    ngOnDestroy() {
        this.subs.unsubscribe();
    }
    /**
     * @hidden
     */
    onContextMenu(e) {
        if (e.targetType === 'topcorner') {
            return;
        }
        const selection = this.spreadsheetWidget.activeSheet().select();
        const { topLeft, bottomRight } = selection;
        const isRange = e.targetType === 'cell' && (topLeft.row !== bottomRight.row || topLeft.col !== bottomRight.col);
        const targetType = isRange ? 'range' : e.targetType;
        this.contextMenuItems = this.contextMenuItemsForTarget(targetType, e.showUnhide, e.showUnmerge);
        this.contextMenu.show({ top: e.originalEvent.pageY, left: e.originalEvent.pageX });
    }
    /**
     * @hidden
     */
    onContextMenuSelect(e) {
        let command;
        switch (e.item.id) {
            case 'cut':
                command = { command: 'ToolbarCutCommand', options: { workbook: this.spreadsheetWidget.workbook } };
                break;
            case 'copy':
                command = { command: 'ToolbarCopyCommand', options: { workbook: this.spreadsheetWidget.workbook } };
                break;
            case 'unmerge':
                command = { command: 'MergeCellCommand', options: { value: 'unmerge' } };
                break;
            case 'mergeAll':
                command = { command: 'MergeCellCommand', options: { value: 'cells' } };
                break;
            case 'mergeHorizontally':
                command = { command: 'MergeCellCommand', options: { value: 'horizontally' } };
                break;
            case 'mergeVertically':
                command = { command: 'MergeCellCommand', options: { value: 'vertically' } };
                break;
            case 'hideRow':
                command = { command: 'HideLineCommand', options: { axis: 'row' } };
                break;
            case 'hideColumn':
                command = { command: 'HideLineCommand', options: { axis: 'column' } };
                break;
            case 'unhideRow':
                command = { command: 'UnHideLineCommand', options: { axis: 'row' } };
                break;
            case 'unhideColumn':
                command = { command: 'UnHideLineCommand', options: { axis: 'column' } };
                break;
            case 'deleteRow':
                command = { command: 'DeleteRowCommand' };
                break;
            case 'deleteColumn':
                command = { command: 'DeleteColumnCommand' };
                break;
            case 'insertLink':
                this.openLinkDialog();
                break;
            case 'addRowAbove':
                command = { command: 'AddRowCommand', options: { value: 'above' } };
                break;
            case 'addRowBelow':
                command = { command: 'AddRowCommand', options: { value: 'below' } };
                break;
            case 'addColumnLeft':
                command = { command: 'AddColumnCommand', options: { value: 'left' } };
                break;
            case 'addColumnRight':
                command = { command: 'AddColumnCommand', options: { value: 'right' } };
                break;
        }
        if (command) {
            this.spreadsheetWidget.executeCommand(command);
        }
    }
    /**
     * @hidden
     */
    onKeyDown = (e) => {
        const isCtrl = e.ctrlKey || e.metaKey;
        const shift = e.shiftKey;
        const altKey = e.altKey;
        if (isCtrl && shift && e.keyCode === Keys.KeyS) {
            this.spreadsheetService.onSheetsBarFocus.next();
        }
        if (altKey) {
            const currentSheet = e.sender.activeSheet();
            const validation = currentSheet.range(currentSheet.activeCell()).validation();
            if (isPresent(validation) && validation.dataType === 'list') {
                if (e.keyCode === Keys.ArrowDown) {
                    this.spreadsheetWidget.view.openCustomEditor();
                }
            }
        }
    };
    /**
     * @hidden
     */
    messageFor(key) {
        return this.localization.get(key);
    }
    /**
     * @hidden
     */
    onMenuItemSelect(e) {
        const selectedMenuItem = this.menuItems.find(item => item.text === e.item.text);
        const previousSelectedItem = this.menuItems.find(item => item.active);
        if (selectedMenuItem !== previousSelectedItem) {
            this._menuItems.forEach((item, idx) => {
                item.active = idx === +e.index;
                item.cssClass = idx === +e.index ? 'k-active' : null;
            });
            this.selectedMenuItem = this.menuItems.find(item => item.active);
        }
    }
    onChange = (e) => {
        hasObservers(this.change) && this.change.emit(e);
        this.spreadsheetService.selectionChanged.next(e.range);
    };
    onSelectionChange = (e) => {
        hasObservers(this.selectionChange) && this.selectionChange.emit(e);
        this.spreadsheetService.selectionChanged.next(e.range);
    };
    onChangeFormat = (e) => {
        hasObservers(this.formatChange) && this.formatChange.emit(e);
        this.spreadsheetService.selectionChanged.next(e.range);
    };
    onExcelExport = (e) => hasObservers(this.excelExport) && this.excelExport.emit(e);
    onExcelImport = (e) => hasObservers(this.excelImport) && this.excelImport.emit(e);
    onActiveSheetChanged = (sheet) => {
        const eventArgs = { sender: this.spreadsheetService.spreadsheet, sheet };
        hasObservers(this.activeSheetChange) && this.activeSheetChange.emit(eventArgs);
        const range = sheet.range(sheet.activeCell());
        this.spreadsheetService.selectionChanged.next(range);
    };
    updateState = (e) => {
        this.toolsService.updateTools(e);
        if (e.reason?.sheetSelection) {
            this.sheets = mapToSheetDescriptor(this.spreadsheetService.spreadsheet.sheets());
        }
    };
    onMessage = (e) => {
        this.ngZone.run(() => {
            this.errorService.handleErrorMessage(e);
        });
    };
    updateActiveSheet(name) {
        this.ngZone.run(() => this.spreadsheetService.currentActiveSheet = name);
    }
    onSheetsChanged(e) {
        this.ngZone.run(() => {
            this.sheets = mapToSheetDescriptor(e.sheets);
            this.updateActiveSheet(this.spreadsheetService.activeSheet);
        });
    }
    get options() {
        return {
            activeSheet: this.activeSheet,
            ...{
                sheets: this.sheetsInfo && structuredClone(this.sheetsInfo),
                intl: {
                    localeInfo: () => localeData(this.intl.localeId),
                    parseDate: (value, fmt) => this.intl.parseDate(value, fmt),
                    toString: (value, fmt) => this.intl.toString(value, fmt),
                    format: (fmt, ...values) => this.intl.format(fmt, ...values)
                }
            },
            columns: this.columns,
            columnWidth: this.columnWidth,
            defaultCellStyle: this.defaultCellStyle,
            excel: this.excel,
            headerHeight: this.headerHeight,
            headerWidth: this.headerWidth,
            images: this.images,
            rowHeight: this.rowHeight,
            rows: this.rows,
            formulaBarInputRef: { current: this.formulaBarInputRef.current },
            formulaCellInputRef: { current: this.formulaCellInputRef.current },
            nameBoxRef: { current: this.nameBoxRef.current },
            getIconHTMLString: (options) => {
                const iconWrapper = this.container.createComponent(IconWrapperComponent);
                iconWrapper.instance.name = options.iconName;
                iconWrapper.instance.svgIcon = options.svgIcon;
                iconWrapper.changeDetectorRef.detectChanges();
                return iconWrapper.instance.element.nativeElement;
            }
        };
    }
    contextMenuItemsForTarget(target, unhide, unmerge) {
        const commonItems = [{
                text: this.messageFor('copy'),
                icon: commandIcons.copy,
                svgIcon: commandSVGIcons.copy,
                id: 'copy'
            }, {
                text: this.messageFor('cut'),
                icon: commandIcons.cut,
                svgIcon: commandSVGIcons.cut,
                id: 'cut'
            }, {
                text: this.messageFor('paste'),
                icon: commandIcons.paste,
                svgIcon: commandSVGIcons.paste,
                id: 'paste',
                disabled: true
            }, {
                separator: true
            }, {
                text: this.messageFor('mergeAll'),
                icon: commandIcons.mergeAll,
                svgIcon: commandSVGIcons.mergeAll,
                id: 'mergeAll',
            }, {
                text: this.messageFor('mergeHorizontally'),
                icon: commandIcons.mergeHorizontally,
                svgIcon: commandSVGIcons.mergeHorizontally,
                id: 'mergeHorizontally',
            }, {
                text: this.messageFor('mergeVertically'),
                icon: commandIcons.mergeVertically,
                svgIcon: commandSVGIcons.mergeVertically,
                id: 'mergeVertically',
            }, {
                text: this.messageFor('unmerge'),
                icon: commandIcons.unmerge,
                svgIcon: commandSVGIcons.unmerge,
                id: 'unmerge',
                disabled: !unmerge
            }, {
                separator: true
            }, {
                text: this.messageFor('insertLink'),
                icon: commandIcons.insertLink,
                svgIcon: commandSVGIcons.insertLink,
                id: 'insertLink'
            }];
        if (target === 'rowheader') {
            commonItems.push({
                separator: true
            }, {
                text: this.messageFor('addRowAbove'),
                icon: commandIcons.addRowAbove,
                svgIcon: commandSVGIcons.addRowAbove,
                id: 'addRowAbove',
            }, {
                text: this.messageFor('addRowBelow'),
                icon: commandIcons.addRowBelow,
                svgIcon: commandSVGIcons.addRowBelow,
                id: 'addRowBelow',
            }, {
                text: this.messageFor('deleteRow'),
                icon: commandIcons.deleteRow,
                svgIcon: commandSVGIcons.deleteRow,
                id: 'deleteRow',
            }, {
                text: this.messageFor('hideRow'),
                icon: commandIcons.hideRow,
                svgIcon: commandSVGIcons.hideRow,
                id: 'hideRow',
            }, {
                text: this.messageFor('unhideRow'),
                icon: commandIcons.unhideRow,
                svgIcon: commandSVGIcons.unhideRow,
                id: 'unhideRow',
                disabled: !unhide
            });
        }
        if (target === 'columnheader') {
            commonItems.push({
                separator: true
            }, {
                text: this.messageFor('addColumnLeft'),
                icon: commandIcons.addColumnLeft,
                svgIcon: commandSVGIcons.addColumnLeft,
                id: 'addColumnLeft',
            }, {
                text: this.messageFor('addColumnRight'),
                icon: commandIcons.addColumnRight,
                svgIcon: commandSVGIcons.addColumnRight,
                id: 'addColumnRight',
            }, {
                text: this.messageFor('deleteColumn'),
                icon: commandIcons.deleteColumn,
                svgIcon: commandSVGIcons.deleteColumn,
                id: 'deleteColumn',
            }, {
                text: this.messageFor('hideColumn'),
                icon: commandIcons.hideColumn,
                svgIcon: commandSVGIcons.hideColumn,
                id: 'hideColumn',
            }, {
                text: this.messageFor('unhideColumn'),
                icon: commandIcons.unhideColumn,
                svgIcon: commandSVGIcons.unhideColumn,
                id: 'unhideColumn',
                disabled: !unhide
            });
        }
        return commonItems;
    }
    openLinkDialog() {
        const hasLink = isPresent(this.currentRange?.link());
        const dialogSettings = {
            appendTo: this.spreadsheetService.dialogContainer,
            title: this.localization.get('insertLink'),
            content: InsertLinkDialogComponent,
            actions: [{
                    text: this.localization.get('dialogInsert'),
                    themeColor: 'primary'
                }, {
                    text: this.localization.get('dialogCancel')
                },
                'spacer', {
                    text: this.localization.get('dialogRemoveLink'),
                    themeColor: 'primary',
                    fillMode: 'clear',
                    cssClass: hasLink ? '' : 'k-disabled'
                }],
            actionsLayout: 'start',
            width: 400,
            autoFocusedElement: '.k-textbox > .k-input-inner'
        };
        const dialog = this.dialogService.open(dialogSettings);
        const dialogInstance = dialog.dialog.instance;
        const dialogContent = dialog.content.instance;
        if (hasLink) {
            dialogContent.setData({ link: this.currentRange?.link() });
        }
        dialogInstance.action.pipe(take(1)).subscribe((event) => {
            if (event.text === this.localization.get('dialogCancel')) {
                return;
            }
            let link = null;
            if (event.text === this.localization.get('dialogInsert')) {
                link = dialogContent.urlLink || null;
            }
            this.spreadsheetService.spreadsheet.executeCommand({
                command: 'HyperlinkCommand',
                options: { link }
            });
        });
    }
    configureSheets = (spreadsheet) => {
        if (!this.sheetsInfo) {
            this.ngZone.run(() => {
                const defaultSheetDescriptors = mapToSheetDescriptor([spreadsheet?.activeSheet()]);
                this._sheetsInfo = [{
                        text: this.spreadsheetService.currentActiveSheet,
                        first: true, last: true,
                        state: 'visible',
                        ...defaultSheetDescriptors,
                        sheetActions: getSheetActions(defaultSheetDescriptors).map(item => ({ ...item, text: this.messageFor(item.messageKey) }))
                    }];
            });
        }
    };
    registerEditors() {
        registerEditor('_validation_list', () => {
            return {
                edit: (options) => {
                    this.popupRef?.close();
                    this.popupRef = null;
                    this.popupRef = this.popupService.open({
                        anchor: options.view.element.querySelector('.k-spreadsheet-editor-button'),
                        content: ListEditorComponent,
                        popupAlign: options.alignLeft ? { horizontal: 'right', vertical: 'top' } : { horizontal: 'left', vertical: 'top' },
                        anchorAlign: options.alignLeft ? { horizontal: 'right', vertical: 'bottom' } : { horizontal: 'left', vertical: 'bottom' },
                        popupClass: 'k-spreadsheet-list-popup'
                    });
                    const list = this.popupRef.content.instance;
                    list.itemSelect.subscribe((item) => {
                        this.popupRef.close();
                        this.popupRef = null;
                        const itemValue = item.value;
                        if (isPresent(itemValue)) {
                            options.callback(itemValue);
                        }
                    });
                    list.close.subscribe(() => {
                        this.popupRef.close();
                        this.popupRef = null;
                    });
                    const items = options.validation.from.value;
                    const data = [];
                    const add = (el) => { data.push({ value: el }); };
                    if (items instanceof Matrix) {
                        items.each(add, false);
                    }
                    else {
                        (items + "").split(/\s*,\s*/).forEach(add);
                    }
                    list.data = data;
                },
                icon: { iconName: 'caret-alt-down', svgIcon: caretAltDownIcon }
            };
        });
        registerEditor('_validation_date', () => {
            return {
                edit: (options) => {
                    this.popupRef?.close();
                    this.popupRef = null;
                    this.popupRef = this.popupService.open({
                        anchor: options.view.element.querySelector('.k-spreadsheet-editor-button'),
                        content: CalendarComponent,
                        popupAlign: options.alignLeft ? { horizontal: 'right', vertical: 'top' } : { horizontal: 'left', vertical: 'top' },
                        anchorAlign: options.alignLeft ? { horizontal: 'right', vertical: 'bottom' } : { horizontal: 'left', vertical: 'bottom' }
                    });
                    const calendar = this.popupRef.content.instance;
                    calendar.valueChange.subscribe((value) => {
                        this.popupRef.close();
                        this.popupRef = null;
                        if (!options.range.format()) {
                            options.range.format('yyyy-mm-dd');
                        }
                        options.callback(dateToSerial(value));
                    });
                    const date = options.range.value();
                    calendar.value = this.createDate(date);
                    const sheet = options.range.sheet();
                    const currenValidation = options.validation;
                    if (currenValidation) {
                        let min = calendar.min;
                        let max = calendar.max;
                        const fromValidation = currenValidation.from;
                        const toValidation = currenValidation.to;
                        if (/^(?:greaterThan|between)/.test(currenValidation.comparerType)) {
                            if (this.isValidFormula(fromValidation)) {
                                min = this.createDate(fromValidation, sheet);
                            }
                            else {
                                min = this.createDate(fromValidation.value);
                            }
                        }
                        if (currenValidation.comparerType === 'between') {
                            if (this.isValidFormula(toValidation)) {
                                max = this.createDate(toValidation, sheet);
                            }
                            else {
                                max = this.createDate(currenValidation.to.value);
                            }
                        }
                        if (currenValidation.comparerType === 'lessThan' || currenValidation.comparerType === 'lessThanOrEqualTo') {
                            if (this.isValidFormula(fromValidation)) {
                                max = this.createDate(fromValidation, sheet);
                            }
                            else {
                                max = this.createDate(currenValidation.from.value);
                            }
                        }
                        calendar.disabledDates = (date) => {
                            let from;
                            let to;
                            if (fromValidation && this.isValidFormula(fromValidation)) {
                                from = sheet.range(fromValidation.value.row, fromValidation.value.col).value();
                            }
                            else {
                                from = fromValidation ? fromValidation.value | 0 : 0;
                            }
                            if (toValidation && this.isValidFormula(toValidation)) {
                                to = sheet.range(toValidation.value.row, toValidation.value.col).value();
                            }
                            else {
                                to = toValidation ? toValidation.value | 0 : 0;
                            }
                            date = dateToSerial(date) || 0;
                            return !validation.validationComparers[currenValidation.comparerType](date, from, to);
                        };
                        calendar.min = min;
                        calendar.max = max;
                    }
                    else {
                        calendar.disabledDates = null;
                        calendar.min = calendar.max = null;
                    }
                },
                icon: { iconName: 'calendar', svgIcon: calendarIcon }
            };
        });
    }
    isValidFormula(validation) {
        const formula = calc.runtime.Formula;
        return validation instanceof formula && rowAndColPresent(validation.value);
    }
    createDate(validation, sheet) {
        return new Date(serialToDate(isPresent(sheet) ? sheet.range(validation.value.row, validation.value.col).value() : validation));
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetComponent, deps: [{ token: i0.NgZone }, { token: i1$4.IntlService }, { token: i0.ElementRef }, { token: i1.LocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }, { token: ErrorHandlingService }, { token: i1$2.DialogService }, { token: i1$1.PopupService }, { token: i0.ViewContainerRef }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetComponent, isStandalone: true, selector: "kendo-spreadsheet", inputs: { menuItems: "menuItems", overflow: "overflow", formulaListMaxHeight: "formulaListMaxHeight", activeSheet: "activeSheet", sheets: "sheets", columns: "columns", columnWidth: "columnWidth", defaultCellStyle: "defaultCellStyle", headerHeight: "headerHeight", headerWidth: "headerWidth", rowHeight: "rowHeight", rows: "rows", images: "images", excel: "excel" }, outputs: { change: "change", formatChange: "formatChange", selectionChange: "selectionChange", excelExport: "excelExport", excelImport: "excelImport", activeSheetChange: "activeSheetChange" }, host: { properties: { "class.k-spreadsheet": "this.hostClass", "attr.role": "this.role" } }, providers: [
            SpreadsheetLocalizationService,
            SpreadsheetService,
            {
                provide: LocalizationService,
                useExisting: SpreadsheetLocalizationService
            },
            {
                provide: L10N_PREFIX,
                useValue: 'kendo.spreadsheet'
            },
            SpreadsheetToolsService,
            PopupService,
            ErrorHandlingService
        ], viewQueries: [{ propertyName: "formulaBarInputRef", first: true, predicate: ["formulaBar"], descendants: true, read: FormulaInputDirective }, { propertyName: "formulaCellInputRef", first: true, predicate: ["formulaCell"], descendants: true, read: FormulaInputDirective }, { propertyName: "nameBoxRef", first: true, predicate: ["nameBox"], descendants: true }, { propertyName: "dialogContainer", first: true, predicate: ["dialogContainer"], descendants: true, read: ViewContainerRef }, { propertyName: "contextMenu", first: true, predicate: ["contextMenu"], descendants: true }], exportAs: ["kendo-spreadsheet"], usesOnChanges: true, ngImport: i0, template: `
        <ng-container
            kendoSpreadsheetLocalizedMessages
            i18n-background="kendo.spreadsheet.background|The title of the tool that changes the text background color."
            background="Background color"
            i18n-color="kendo.spreadsheet.color|The title of the tool that changes the text font color."
            color="Font color"
            i18n-bold="kendo.spreadsheet.bold|The title of the Bold tool."
            bold="Bold"
            i18n-dataValidation="kendo.spreadsheet.dataValidation|The title of the Data Validation tool."
            dataValidation="Data Validation"
            i18n-validationCellRange="kendo.spreadsheet.validationCellRange|The text of the Cell Range label in the data validation dialog."
            validationCellRange="Cell Range"
            i18n-validationCriteria="kendo.spreadsheet.validationCriteria|The text of the Criteria dropdown list label in the data validation dialog."
            validationCriteria="Criteria"
            i18n-validationMinValue="kendo.spreadsheet.validationMinValue|The text of the Min value label in the data validation dialog."
            validationMinValue="Min"
            i18n-validationMaxValue="kendo.spreadsheet.validationMaxValue|The text of the Max value label in the data validation dialog."
            validationMaxValue="Max"
            i18n-validationStartValue="kendo.spreadsheet.validationStartValue|The text of the Start value label in the data validation dialog."
            validationStartValue="Start"
            i18n-validationEndValue="kendo.spreadsheet.validationEndValue|The text of the End value label in the data validation dialog."
            validationEndValue="End"
            i18n-validationValue="kendo.spreadsheet.validationValue|The text of the Value label in the data validation dialog."
            validationValue="Text"
            i18n-validationShowListButtonCheckbox="kendo.spreadsheet.validationShowListButtonCheckbox|The text for the Show list button checkbox label in the data validation dialog."
            validationShowListButtonCheckbox="Display button to show list"
            i18n-validationOnInvalidData="kendo.spreadsheet.validationOnInvalidData|The text for the On invalid data label in the data validation dialog."
            validationOnInvalidData="On invalid data"
            i18n-validationShowDateButtonCheckbox="kendo.spreadsheet.validationShowDateButtonCheckbox|The text for the Show date button checkbox label in the data validation dialog."
            validationShowDateButtonCheckbox="Display button to show Calendar"
            i18n-validationRejectInput="kendo.spreadsheet.validationRejectInput|The text for the Reject input radio button label in the data validation dialog."
            validationRejectInput="Reject input"
            i18n-validationShowWarning="kendo.spreadsheet.validationShowWarning|The text for the Show warning radio button label in the data validation dialog."
            validationShowWarning="Show warning"
            i18n-validationHintTitle="kendo.spreadsheet.validationHintTitle|The text for the Custom hint title input label in the data validation dialog."
            validationHintTitle="Custom hint title"
            i18n-validationHintMessage="kendo.spreadsheet.validationHintMessage|The text for the Custom hint input label in the data validation dialog."
            validationHintMessage="Custom hint"
            i18n-validationShowHint="kendo.spreadsheet.validationShowHint|The text for the Show hint radio button label in the data validation dialog."
            validationShowHint="Show hint"
            i18n-validationIgnoreBlankCheckbox="kendo.spreadsheet.validationIgnoreBlankCheckbox|The text for the Ignore blank checkbox label in the data validation dialog."
            validationIgnoreBlankCheckbox="Ignore blank"
            i18n-validationComparer="kendo.spreadsheet.validationComparer|The text of the Comparer dropdown list label in the data validation dialog."
            validationComparer="Comparer"
            i18n-anyValueValidationCriteria="kendo.spreadsheet.anyValueValidationCriteria|The text of the Any value validation criteria"
            anyValueValidationCriteria="Any value"
            i18n-numberValidationCriteria="kendo.spreadsheet.numberValidationCriteria|The text of the Number validation criteria"
            numberValidationCriteria="Number"
            i18n-textValidationCriteria="kendo.spreadsheet.textValidationCriteria|The text of the Text validation criteria"
            textValidationCriteria="Text"
            i18n-dateValidationCriteria="kendo.spreadsheet.dateValidationCriteria|The text of the Date validation criteria"
            dateValidationCriteria="Date"
            i18n-customFormulaValidationCriteria="kendo.spreadsheet.customFormulaValidationCriteria|The text of the Custom formula validation criteria"
            customFormulaValidationCriteria="Custom Formula"
            i18n-listValidationCriteria="kendo.spreadsheet.listValidationCriteria|The text of the List validation criteria"
            listValidationCriteria="List"
            i18n-greaterThanValidationComparer="kendo.spreadsheet.greaterThanValidationComparer|The text of the greater than validation comparer"
            greaterThanValidationComparer="greater than"
            i18n-lessThanValidationComparer="kendo.spreadsheet.lessThanValidationComparer|The text of the less than validation comparer"
            lessThanValidationComparer="less than"
            i18n-betweenValidationComparer="kendo.spreadsheet.betweenValidationComparer|The text of the between validation comparer"
            betweenValidationComparer="between"
            i18n-notBetweenValidationComparer="kendo.spreadsheet.notBetweenValidationComparer|The text of the not between validation comparer"
            notBetweenValidationComparer="not between"
            i18n-equalToValidationComparer="kendo.spreadsheet.equalToValidationComparer|The text of the equal to validation comparer"
            equalToValidationComparer="equal to"
            i18n-notEqualToValidationComparer="kendo.spreadsheet.notEqualToValidationComparer|The text of the not equal to validation comparer"
            notEqualToValidationComparer="not equal to"
            i18n-greaterThanOrEqualToValidationComparer="kendo.spreadsheet.greaterThanOrEqualToValidationComparer|The text of the greater than on equal to validation comparer"
            greaterThanOrEqualToValidationComparer="greater than or equal to"
            i18n-lessThanOrEqualToValidationComparer="kendo.spreadsheet.lessThanOrEqualToValidationComparer|The text of the less than on equal to validation comparer"
            lessThanOrEqualToValidationComparer="less than or equal to"
            i18n-italic="kendo.spreadsheet.italic|The title of the Italic tool."
            italic="Italic"
            i18n-underline="kendo.spreadsheet.underline|The title of the Underline tool."
            underline="Underline"
            i18n-loadFile="kendo.spreadsheet.loadFile|The title of the Load File tool."
            loadFile="Open..."
            i18n-saveFile="kendo.spreadsheet.saveFile|The title of the Save File tool."
            saveFile="Export..."
            i18n-format="kendo.spreadsheet.format|The text of the Format tool."
            format="Custom format..."
            i18n-fontFamily="kendo.spreadsheet.fontFamily|The text of the Font Family tool."
            fontFamily="Font"
            i18n-fontSize="kendo.spreadsheet.fontSize|The text of the Font Size tool."
            fontSize="Font size"
            i18n-home="kendo.spreadsheet.home|The text of the Home toolbar tab."
            home="Home"
            i18n-file="kendo.spreadsheet.file|The text of the File toolbar tab."
            file="File"
            i18n-insert="kendo.spreadsheet.insert|The text of the Insert toolbar tab."
            insert="Insert"
            i18n-formatTab="kendo.spreadsheet.formatTab|The text of the Format toolbar tab."
            formatTab="Format"
            i18n-dataTab="kendo.spreadsheet.dataTab|The text of the Data toolbar tab."
            dataTab="Data"
            i18n-view="kendo.spreadsheet.view|The text of the View toolbar tab."
            view="View"
            i18n-undo="kendo.spreadsheet.undo|The title of the Undo tool."
            undo="Undo"
            i18n-redo="kendo.spreadsheet.redo|The title of the Redo tool."
            redo="Redo"
            i18n-gridLines="kendo.spreadsheet.gridLines|The title of the Grid Lines tool."
            gridLines="Toggle grid lines"
            i18n-addColumnLeft="kendo.spreadsheet.addColumnLeft|The title of the tool that adds new column before currently selected column."
            addColumnLeft="Add column left"
            i18n-addColumnRight="kendo.spreadsheet.addColumnRight|The title of the tool that adds new column after currently selected column."
            addColumnRight="Add column right"
            i18n-addRowBelow="kendo.spreadsheet.addRowBelow|The title of the tool that adds new row below currently selected row."
            addRowBelow="Add row below"
            i18n-addRowAbove="kendo.spreadsheet.addRowAbove|The title of the tool that adds new row above currently selected row."
            addRowAbove="Add row above"
            i18n-deleteColumn="kendo.spreadsheet.deleteColumn|The title of the tool that deletes a column."
            deleteColumn="Delete column"
            i18n-deleteRow="kendo.spreadsheet.deleteRow|The title of the tool that deletes a row."
            deleteRow="Delete row"
            i18n-wrap="kendo.spreadsheet.wrap|The title of the Text Wrap tool."
            wrap="Text wrap"
            i18n-align="kendo.spreadsheet.align|The title of the Text Align tool."
            align="Align"
            i18n-alignHorizontal="kendo.spreadsheet.alignHorizontal|The title of the Text Align Horizontal tool."
            alignHorizontal="Align horizontally"
            i18n-alignVertical="kendo.spreadsheet.alignVertical|The title of the Text Align Vertical tool."
            alignVertical="Align vertically"
            i18n-alignLeft="kendo.spreadsheet.alignLeft|The title of the Text Align Left tool."
            alignLeft="Align Left"
            i18n-alignCenter="kendo.spreadsheet.alignCenter|The title of the Text Align Center tool."
            alignCenter="Align Center"
            i18n-alignRight="kendo.spreadsheet.alignRight|The title of the Text Align Right tool."
            alignRight="Align Right"
            i18n-alignJustify="kendo.spreadsheet.alignJustify|The title of the Text Align Justify tool."
            alignJustify="Align Justify"
            i18n-alignTop="kendo.spreadsheet.alignTop|The title of the Text Align Top tool."
            alignTop="Align Top"
            i18n-alignMiddle="kendo.spreadsheet.alignMiddle|The title of the Text Align Middle tool."
            alignMiddle="Align Middle"
            i18n-alignBottom="kendo.spreadsheet.alignBottom|The title of the Text Align Bottom tool."
            alignBottom="Align Bottom"
            i18n-merge="kendo.spreadsheet.merge|The title of the Cells Merge tool."
            merge="Merge"
            i18n-mergeAll="kendo.spreadsheet.mergeAll|The title of the Merge all tool."
            mergeAll="Merge all"
            i18n-mergeHorizontally="kendo.spreadsheet.mergeHorizontally|The title of the Merge horizontally tool."
            mergeHorizontally="Merge horizontally"
            i18n-mergeVertically="kendo.spreadsheet.mergeVertically|The title of the Merge vertically tool."
            mergeVertically="Merge vertically"
            i18n-unmerge="kendo.spreadsheet.unmerge|The title of the Unmerge tool."
            unmerge="Unmerge"
            i18n-insertLink="kendo.spreadsheet.insertLink|The title of the tool that inserts a link."
            insertLink="Insert link"
            i18n-decreaseDecimal="kendo.spreadsheet.decreaseDecimal|The title of the tool that decreases decimals."
            decreaseDecimal="Decrease decimal"
            i18n-increaseDecimal="kendo.spreadsheet.increaseDecimal|The title of the tool that increases decimals."
            increaseDecimal="Increase decimal"
            i18n-increaseFontSize="kendo.spreadsheet.increaseFontSize|The title of the tool that increases the cell font size."
            increaseFontSize="Increase font size"
            i18n-decreaseFontSize="kendo.spreadsheet.decreaseFontSize|The title of the tool that decreases the cell font size."
            decreaseFontSize="Decrease font size"
            i18n-dialogApply="kendo.spreadsheet.dialogApply|The text of the **Apply** button in all Spreadsheet dialogs."
            dialogApply="Apply"
            i18n-dialogCancel="kendo.spreadsheet.dialogCancel|The text of the **Cancel** button in all Spreadsheet dialogs."
            dialogCancel="Cancel"
            i18n-dialogDelete="kendo.spreadsheet.dialogDelete|The text of the **Delete** button in the Delete sheet dialog."
            dialogDelete="Delete"
            i18n-dialogRename="kendo.spreadsheet.dialogRename|The text of the **Rename** button in the Rename sheet dialog."
            dialogRename="Rename"
            i18n-dialogInsert="kendo.spreadsheet.dialogInsert|The text of the **Insert** button in all Spreadsheet dialogs."
            dialogInsert="Insert"
            i18n-dialogRemove="kendo.spreadsheet.dialogRemove|The text of the **Remove** button in all Spreadsheet dialogs."
            dialogRemove="Remove"
            i18n-dialogRemoveLink="kendo.spreadsheet.dialogRemoveLink|The text of the **Remove link** button in the Link tool dialog."
            dialogRemoveLink="Remove link"
            i18n-rename="kendo.spreadsheet.rename|The title of the Rename sheet dialog."
            rename="Rename Sheet"
            i18n-delete="kendo.spreadsheet.delete|The title of the Delete sheet dialog."
            delete="Delete Sheet"
            i18n-nameBox="kendo.spreadsheet.nameBox|The title of the Name Box input."
            nameBox="Name Box"
            i18n-formulaInput="kendo.spreadsheet.formulaInput|The title of the Formula input."
            formulaInput="Formula Input"
            i18n-addSheet="kendo.spreadsheet.addSheet|The title of the Add new sheet button."
            addSheet="Add New Sheet"
            i18n-sheetsMenu="kendo.spreadsheet.sheetsMenu|The title of the Sheets menu button."
            sheetsMenu="All Sheets"
            i18n-openUnsupported="kendo.spreadsheet.openUnsupported|The content of the dialog that warns about an unsupported file type."
            openUnsupported="Unsupported format. Please select an .xlsx file."
            i18n-modifyMerged="kendo.spreadsheet.modifyMerged|The content of the dialog that warns about modifying a merged cell."
            modifyMerged="Cannot change part of a merged cell."
            i18n-cannotModifyDisabled="kendo.spreadsheet.cannotModifyDisabled|The content of the dialog that warns about modifying a disabled cell."
            cannotModifyDisabled="Cannot modify disabled cells."
            i18n-dialogOk="kendo.spreadsheet.dialogOk|The text of the **OK** dialog button."
            dialogOk="OK"
            i18n-dialogError="kendo.spreadsheet.dialogError|The title of an error dialog."
            dialogError="Error"
            i18n-duplicateSheetName="kendo.spreadsheet.duplicateSheetName|The content of the dialog that warns about duplicated sheet name."
            duplicateSheetName="There is an existing sheet with this name. Please enter another name."
            i18n-copy="kendo.spreadsheet.copy|The Copy command text."
            copy="Copy"
            i18n-cut="kendo.spreadsheet.cut|The Cut command text."
            cut="Cut"
            i18n-paste="kendo.spreadsheet.paste|The Paste command text."
            paste="Paste (use Ctrl/⌘ + V)"
            i18n-hideRow="kendo.spreadsheet.hideRow|The Hide row command text."
            hideRow="Hide"
            i18n-unhideRow="kendo.spreadsheet.unhideRow|The Unhide row command text."
            unhideRow="Unhide"
            i18n-hideColumn="kendo.spreadsheet.hideColumn|The Hide column command text."
            hideColumn="Hide"
            i18n-unhideColumn="kendo.spreadsheet.unhideColumn|The Unhide column command text."
            unhideColumn="Unhide"
            i18n-sheetDelete="kendo.spreadsheet.sheetDelete|The text of the Sheet menu Delete option."
            sheetDelete="Delete"
            i18n-sheetRename="kendo.spreadsheet.sheetRename|The text of the Sheet menu Rename option."
            sheetRename="Rename"
            i18n-sheetDuplicate="kendo.spreadsheet.sheetDuplicate|The text of the Sheet menu Duplicate option."
            sheetDuplicate="Duplicate"
            i18n-sheetHide="kendo.spreadsheet.sheetHide|The text of the Sheet menu Hide option."
            sheetHide="Hide"
            i18n-sheetMoveLeft="kendo.spreadsheet.sheetMoveLeft|The text of the Sheet menu Move Left option."
            sheetMoveLeft="Move Left"
            i18n-sheetMoveRight="kendo.spreadsheet.sheetMoveRight|The text of the Sheet menu Move Right option."
            sheetMoveRight="Move Right"
            i18n-invalidNameError="kendo.spreadsheet.invalidNameError|The content of the dialog that warns about invalid name input."
            invalidNameError="{{ 'Invalid name: {inputValue}' }}">
        </ng-container>
        <div class="k-spreadsheet-header">
            <kendo-menu kendoSpreadsheetMenu (select)="onMenuItemSelect($event)">
                <kendo-menu-item *ngFor="let item of menuItems" [text]="item.text" [cssClass]="item.cssClass"></kendo-menu-item>
            </kendo-menu>
            <kendo-toolbar *ngIf="selectedMenuItem?.active && selectedMenuItem.id === 'file'"
                [attr.aria-label]="messageFor('file')"
                fillMode="flat"
                class="k-spreadsheet-toolbar"
                [overflow]="overflow">
                <kendo-spreadsheet-load-file-tool></kendo-spreadsheet-load-file-tool>
                <kendo-toolbar-button kendoSpreadsheetSaveFile></kendo-toolbar-button>
            </kendo-toolbar>
            <kendo-toolbar *ngIf="selectedMenuItem?.active && selectedMenuItem.id === 'home'"
                [attr.aria-label]="messageFor('home')"
                class="k-spreadsheet-toolbar"
                fillMode="flat"
                [overflow]="overflow">
                <kendo-toolbar-button kendoSpreadsheetUndo></kendo-toolbar-button>
                <kendo-toolbar-button kendoSpreadsheetRedo></kendo-toolbar-button>
                <kendo-toolbar-separator></kendo-toolbar-separator>
                <kendo-toolbar-dropdownlist kendoSpreadsheetFontFamily></kendo-toolbar-dropdownlist>
                <kendo-toolbar-dropdownlist kendoSpreadsheetFontSize></kendo-toolbar-dropdownlist>
                <kendo-toolbar-buttongroup fillMode="flat">
                    <kendo-toolbar-button kendoSpreadsheetIncreaseFontSize></kendo-toolbar-button>
                    <kendo-toolbar-button kendoSpreadsheetDecreaseFontSize></kendo-toolbar-button>
                </kendo-toolbar-buttongroup>
                <kendo-toolbar-separator></kendo-toolbar-separator>
                <kendo-toolbar-buttongroup fillMode="flat">
                    <kendo-toolbar-button kendoSpreadsheetBold></kendo-toolbar-button>
                    <kendo-toolbar-button kendoSpreadsheetItalic></kendo-toolbar-button>
                    <kendo-toolbar-button kendoSpreadsheetUnderline></kendo-toolbar-button>
                </kendo-toolbar-buttongroup>
                <kendo-spreadsheet-forecolor-tool></kendo-spreadsheet-forecolor-tool>
                <kendo-toolbar-separator></kendo-toolbar-separator>
                <kendo-spreadsheet-backcolor-tool></kendo-spreadsheet-backcolor-tool>
                <kendo-toolbar-separator></kendo-toolbar-separator>
                <kendo-toolbar-dropdownbutton kendoSpreadsheetHorizontalTextAlign></kendo-toolbar-dropdownbutton>
                <kendo-toolbar-dropdownbutton kendoSpreadsheetVerticalTextAlign></kendo-toolbar-dropdownbutton>
                <kendo-toolbar-button kendoSpreadsheetTextWrap></kendo-toolbar-button>
                <kendo-toolbar-separator></kendo-toolbar-separator>
                <kendo-toolbar-dropdownbutton kendoSpreadsheetFormat></kendo-toolbar-dropdownbutton>
            </kendo-toolbar>
            <kendo-toolbar *ngIf="selectedMenuItem?.active && selectedMenuItem.id === 'insert'"
                [attr.aria-label]="messageFor('insert')"
                fillMode="flat"
                class="k-spreadsheet-toolbar"
                [overflow]="overflow">
                <kendo-toolbar-button kendoSpreadsheetInsertLink></kendo-toolbar-button>
                <kendo-toolbar-separator></kendo-toolbar-separator>
                <kendo-toolbar-button kendoSpreadsheetAddColumnLeftButton></kendo-toolbar-button>
                <kendo-toolbar-button kendoSpreadsheetAddColumnRightButton></kendo-toolbar-button>
                <kendo-toolbar-button kendoSpreadsheetAddRowBelowButton></kendo-toolbar-button>
                <kendo-toolbar-button kendoSpreadsheetAddRowAboveButton></kendo-toolbar-button>
                <kendo-toolbar-separator></kendo-toolbar-separator>
                <kendo-toolbar-button kendoSpreadsheetDeleteColumnButton></kendo-toolbar-button>
                <kendo-toolbar-button kendoSpreadsheetDeleteRowButton></kendo-toolbar-button>
            </kendo-toolbar>
            <kendo-toolbar *ngIf="selectedMenuItem?.active && selectedMenuItem.id === 'format'"
                [attr.aria-label]="messageFor('formatTab')"
                fillMode="flat"
                class="k-spreadsheet-toolbar"
                [overflow]="overflow">
                <kendo-toolbar-button kendoSpreadsheetDecreaseDecimal></kendo-toolbar-button>
                <kendo-toolbar-button kendoSpreadsheetIncreaseDecimal></kendo-toolbar-button>
            </kendo-toolbar>
            <kendo-toolbar *ngIf="selectedMenuItem?.active && selectedMenuItem.id === 'view'"
                [attr.aria-label]="messageFor('view')"
                fillMode="flat"
                class="k-spreadsheet-toolbar"
                [overflow]="overflow">
                <kendo-toolbar-dropdownbutton kendoSpreadsheetMerge></kendo-toolbar-dropdownbutton>
                <kendo-toolbar-separator></kendo-toolbar-separator>
                <kendo-toolbar-button kendoSpreadsheetGridLines></kendo-toolbar-button>
            </kendo-toolbar>
            <kendo-toolbar *ngIf="selectedMenuItem?.active && selectedMenuItem.id === 'data'"
                [attr.aria-label]="messageFor('dataTab')"
                fillMode="flat"
                class="k-spreadsheet-toolbar"
                [overflow]="overflow">
                <kendo-toolbar-button kendoSpreadsheetDataValidation></kendo-toolbar-button>
            </kendo-toolbar>
        </div>
        <div class="k-spreadsheet-action-bar">
            <div #nameBox kendoSpreadsheetNameBox [spreadsheetWidget]="spreadsheetWidget"></div>
            <div class="k-spreadsheet-formula-bar">
                <span class="k-separator k-separator-vertical"></span>
                <kendo-icon-wrapper
                    name="formula-fx"
                    [svgIcon]="formulaFxIcon">
                </kendo-icon-wrapper>
                <span class="k-separator k-separator-vertical"></span>
                <div
                    #formulaBar
                    kendoSpreadsheetFormulaInput
                    [formulaListMaxHeight]="formulaListMaxHeight"
                    class="k-textbox k-input k-input-md k-input-flat k-rounded-md"></div>
            </div>
        </div>
        <div class="k-spreadsheet-view">
            <div class="k-spreadsheet-fixed-container"></div>
                <div class="k-spreadsheet-scroller">
                    <div class="k-spreadsheet-view-size"></div>
                </div>
            <div tabIndex="0" class="k-spreadsheet-clipboard" contentEditable="true"></div>
            <div #formulaCell kendoSpreadsheetFormulaInput class="k-spreadsheet-cell-editor" data-role="formulainput"></div>
        </div>
        <div class="k-spreadsheet-sheets-bar"
            kendoSpreadsheetSheetsBar
            [sheets]="sheetsInfo"
            [sheetDescriptors]="sheets">
        </div>
        <ng-container #dialogContainer></ng-container>

        <kendo-contextmenu
            #contextMenu
            [items]="contextMenuItems"
            (select)="onContextMenuSelect($event)"></kendo-contextmenu>

        <div kendoWatermarkOverlay *ngIf="showLicenseWatermark"></div>
    `, isInline: true, dependencies: [{ kind: "directive", type: LocalizedMessagesDirective, selector: "[kendoSpreadsheetLocalizedMessages]" }, { kind: "component", type: MenuComponent, selector: "kendo-menu", inputs: ["appendTo", "menuItemTemplate", "ariaRole", "menuItemLinkTemplate"], outputs: ["select", "open", "close"], exportAs: ["kendoMenu"] }, { kind: "directive", type: MainMenuDirective, selector: "[kendoSpreadsheetMenu]" }, { kind: "directive", type: NgFor, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "component", type: MenuItemComponent, selector: "kendo-menu-item", inputs: ["text", "url", "disabled", "cssClass", "cssStyle", "icon", "svgIcon", "data", "separator"] }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: ToolBarComponent, selector: "kendo-toolbar", inputs: ["overflow", "resizable", "popupSettings", "fillMode", "tabindex", "size", "tabIndex", "showIcon", "showText"], outputs: ["open", "close"], exportAs: ["kendoToolBar"] }, { kind: "component", type: SpreadsheetLoadFileComponent, selector: "kendo-spreadsheet-load-file-tool" }, { kind: "component", type: ToolBarButtonComponent, selector: "kendo-toolbar-button", inputs: ["showText", "showIcon", "text", "style", "className", "title", "disabled", "toggleable", "look", "togglable", "selected", "fillMode", "themeColor", "icon", "iconClass", "svgIcon", "imageUrl"], outputs: ["click", "pointerdown", "selectedChange"], exportAs: ["kendoToolBarButton"] }, { kind: "directive", type: SpreadsheetSaveFileDirective, selector: "[kendoSpreadsheetSaveFile]" }, { kind: "component", type: ToolBarButtonGroupComponent, selector: "kendo-toolbar-buttongroup", inputs: ["disabled", "fillMode", "selection", "width", "look"], exportAs: ["kendoToolBarButtonGroup"] }, { kind: "directive", type: SpreadsheetUndoDirective, selector: "kendo-toolbar-button[kendoSpreadsheetUndo]" }, { kind: "directive", type: SpreadsheetRedoDirective, selector: "kendo-toolbar-button[kendoSpreadsheetRedo]" }, { kind: "component", type: ToolBarSeparatorComponent, selector: "kendo-toolbar-separator", exportAs: ["kendoToolBarSeparator"] }, { kind: "component", type: SpreadsheetFontFamilyComponent, selector: "kendo-toolbar-dropdownlist[kendoSpreadsheetFontFamily]" }, { kind: "component", type: SpreadsheetFontSizeComponent, selector: "kendo-toolbar-dropdownlist[kendoSpreadsheetFontSize]" }, { kind: "directive", type: SpreadsheetIncreaseFontSizeDirective, selector: "kendo-toolbar-button[kendoSpreadsheetIncreaseFontSize]" }, { kind: "directive", type: SpreadsheetDecreaseFontSizeDirective, selector: "kendo-toolbar-button[kendoSpreadsheetDecreaseFontSize]" }, { kind: "directive", type: SpreadsheetBoldDirective, selector: "kendo-toolbar-button[kendoSpreadsheetBold]" }, { kind: "directive", type: SpreadsheetItalicDirective, selector: "kendo-toolbar-button[kendoSpreadsheetItalic]" }, { kind: "directive", type: SpreadsheetUnderlineDirective, selector: "kendo-toolbar-button[kendoSpreadsheetUnderline]" }, { kind: "component", type: SpreadsheetForeColorComponent, selector: "kendo-spreadsheet-forecolor-tool" }, { kind: "component", type: SpreadsheetBackColorComponent, selector: "kendo-spreadsheet-backcolor-tool" }, { kind: "component", type: ToolBarDropDownButtonComponent, selector: "kendo-toolbar-dropdownbutton", inputs: ["arrowIcon", "title", "showText", "showIcon", "text", "icon", "svgIcon", "iconClass", "imageUrl", "popupSettings", "look", "primary", "fillMode", "themeColor", "buttonClass", "textField", "disabled", "data"], outputs: ["itemClick", "open", "close"], exportAs: ["kendoToolBarDropDownButton"] }, { kind: "directive", type: SpreadsheetHorizontalTextAlignDirective, selector: "[kendoSpreadsheetHorizontalTextAlign]" }, { kind: "directive", type: SpreadsheetVerticalTextAlignDirective, selector: "[kendoSpreadsheetVerticalTextAlign]" }, { kind: "directive", type: SpreadsheetTextWrapDirective, selector: "kendo-toolbar-button[kendoSpreadsheetTextWrap]" }, { kind: "directive", type: SpreadsheetFormatDirective, selector: "[kendoSpreadsheetFormat]" }, { kind: "directive", type: SpreadsheetInsertLinkDirective, selector: "kendo-toolbar-button[kendoSpreadsheetInsertLink]" }, { kind: "directive", type: SpreadsheetAddColumnLeftButtonDirective, selector: "kendo-toolbar-button[kendoSpreadsheetAddColumnLeftButton]" }, { kind: "directive", type: SpreadsheetAddColumnRightButtonDirective, selector: "kendo-toolbar-button[kendoSpreadsheetAddColumnRightButton]" }, { kind: "directive", type: SpreadsheetAddRowBelowButtonDirective, selector: "kendo-toolbar-button[kendoSpreadsheetAddRowBelowButton]" }, { kind: "directive", type: SpreadsheetAddRowAboveButtonDirective, selector: "kendo-toolbar-button[kendoSpreadsheetAddRowAboveButton]" }, { kind: "directive", type: SpreadsheetDeleteColumnButtonDirective, selector: "kendo-toolbar-button[kendoSpreadsheetDeleteColumnButton]" }, { kind: "directive", type: SpreadsheetDeleteRowButtonDirective, selector: "kendo-toolbar-button[kendoSpreadsheetDeleteRowButton]" }, { kind: "directive", type: SpreadsheetDecreaseDecimalDirective, selector: "kendo-toolbar-button[kendoSpreadsheetDecreaseDecimal]" }, { kind: "directive", type: SpreadsheetIncreaseDecimalDirective, selector: "kendo-toolbar-button[kendoSpreadsheetIncreaseDecimal]" }, { kind: "directive", type: SpreadsheetMergeDirective, selector: "[kendoSpreadsheetMerge]" }, { kind: "directive", type: SpreadsheetGridLinesDirective, selector: "kendo-toolbar-button[kendoSpreadsheetGridLines]" }, { kind: "component", type: NameBoxComponent, selector: "[kendoSpreadsheetNameBox]", inputs: ["data", "spreadsheetWidget"] }, { kind: "component", type: IconWrapperComponent, selector: "kendo-icon-wrapper", inputs: ["name", "svgIcon", "innerCssClass", "customFontClass", "size"], exportAs: ["kendoIconWrapper"] }, { kind: "directive", type: FormulaInputDirective, selector: "[kendoSpreadsheetFormulaInput]", inputs: ["formulaListMaxHeight"] }, { kind: "component", type: SheetsBarComponent, selector: "[kendoSpreadsheetSheetsBar]", inputs: ["sheets", "sheetDescriptors"] }, { kind: "component", type: ContextMenuComponent, selector: "kendo-contextmenu", inputs: ["showOn", "target", "filter", "alignToAnchor", "vertical", "popupAnimate", "popupAlign", "anchorAlign", "collision", "appendTo", "ariaLabel"], outputs: ["popupOpen", "popupClose", "select", "open", "close"], exportAs: ["kendoContextMenu"] }, { kind: "component", type: WatermarkOverlayComponent, selector: "div[kendoWatermarkOverlay]" }, { kind: "directive", type: SpreadsheetDataValidationDirective, selector: "kendo-toolbar-button[kendoSpreadsheetDataValidation]" }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetComponent, decorators: [{
            type: Component,
            args: [{
                    exportAs: 'kendo-spreadsheet',
                    selector: 'kendo-spreadsheet',
                    providers: [
                        SpreadsheetLocalizationService,
                        SpreadsheetService,
                        {
                            provide: LocalizationService,
                            useExisting: SpreadsheetLocalizationService
                        },
                        {
                            provide: L10N_PREFIX,
                            useValue: 'kendo.spreadsheet'
                        },
                        SpreadsheetToolsService,
                        PopupService,
                        ErrorHandlingService
                    ],
                    template: `
        <ng-container
            kendoSpreadsheetLocalizedMessages
            i18n-background="kendo.spreadsheet.background|The title of the tool that changes the text background color."
            background="Background color"
            i18n-color="kendo.spreadsheet.color|The title of the tool that changes the text font color."
            color="Font color"
            i18n-bold="kendo.spreadsheet.bold|The title of the Bold tool."
            bold="Bold"
            i18n-dataValidation="kendo.spreadsheet.dataValidation|The title of the Data Validation tool."
            dataValidation="Data Validation"
            i18n-validationCellRange="kendo.spreadsheet.validationCellRange|The text of the Cell Range label in the data validation dialog."
            validationCellRange="Cell Range"
            i18n-validationCriteria="kendo.spreadsheet.validationCriteria|The text of the Criteria dropdown list label in the data validation dialog."
            validationCriteria="Criteria"
            i18n-validationMinValue="kendo.spreadsheet.validationMinValue|The text of the Min value label in the data validation dialog."
            validationMinValue="Min"
            i18n-validationMaxValue="kendo.spreadsheet.validationMaxValue|The text of the Max value label in the data validation dialog."
            validationMaxValue="Max"
            i18n-validationStartValue="kendo.spreadsheet.validationStartValue|The text of the Start value label in the data validation dialog."
            validationStartValue="Start"
            i18n-validationEndValue="kendo.spreadsheet.validationEndValue|The text of the End value label in the data validation dialog."
            validationEndValue="End"
            i18n-validationValue="kendo.spreadsheet.validationValue|The text of the Value label in the data validation dialog."
            validationValue="Text"
            i18n-validationShowListButtonCheckbox="kendo.spreadsheet.validationShowListButtonCheckbox|The text for the Show list button checkbox label in the data validation dialog."
            validationShowListButtonCheckbox="Display button to show list"
            i18n-validationOnInvalidData="kendo.spreadsheet.validationOnInvalidData|The text for the On invalid data label in the data validation dialog."
            validationOnInvalidData="On invalid data"
            i18n-validationShowDateButtonCheckbox="kendo.spreadsheet.validationShowDateButtonCheckbox|The text for the Show date button checkbox label in the data validation dialog."
            validationShowDateButtonCheckbox="Display button to show Calendar"
            i18n-validationRejectInput="kendo.spreadsheet.validationRejectInput|The text for the Reject input radio button label in the data validation dialog."
            validationRejectInput="Reject input"
            i18n-validationShowWarning="kendo.spreadsheet.validationShowWarning|The text for the Show warning radio button label in the data validation dialog."
            validationShowWarning="Show warning"
            i18n-validationHintTitle="kendo.spreadsheet.validationHintTitle|The text for the Custom hint title input label in the data validation dialog."
            validationHintTitle="Custom hint title"
            i18n-validationHintMessage="kendo.spreadsheet.validationHintMessage|The text for the Custom hint input label in the data validation dialog."
            validationHintMessage="Custom hint"
            i18n-validationShowHint="kendo.spreadsheet.validationShowHint|The text for the Show hint radio button label in the data validation dialog."
            validationShowHint="Show hint"
            i18n-validationIgnoreBlankCheckbox="kendo.spreadsheet.validationIgnoreBlankCheckbox|The text for the Ignore blank checkbox label in the data validation dialog."
            validationIgnoreBlankCheckbox="Ignore blank"
            i18n-validationComparer="kendo.spreadsheet.validationComparer|The text of the Comparer dropdown list label in the data validation dialog."
            validationComparer="Comparer"
            i18n-anyValueValidationCriteria="kendo.spreadsheet.anyValueValidationCriteria|The text of the Any value validation criteria"
            anyValueValidationCriteria="Any value"
            i18n-numberValidationCriteria="kendo.spreadsheet.numberValidationCriteria|The text of the Number validation criteria"
            numberValidationCriteria="Number"
            i18n-textValidationCriteria="kendo.spreadsheet.textValidationCriteria|The text of the Text validation criteria"
            textValidationCriteria="Text"
            i18n-dateValidationCriteria="kendo.spreadsheet.dateValidationCriteria|The text of the Date validation criteria"
            dateValidationCriteria="Date"
            i18n-customFormulaValidationCriteria="kendo.spreadsheet.customFormulaValidationCriteria|The text of the Custom formula validation criteria"
            customFormulaValidationCriteria="Custom Formula"
            i18n-listValidationCriteria="kendo.spreadsheet.listValidationCriteria|The text of the List validation criteria"
            listValidationCriteria="List"
            i18n-greaterThanValidationComparer="kendo.spreadsheet.greaterThanValidationComparer|The text of the greater than validation comparer"
            greaterThanValidationComparer="greater than"
            i18n-lessThanValidationComparer="kendo.spreadsheet.lessThanValidationComparer|The text of the less than validation comparer"
            lessThanValidationComparer="less than"
            i18n-betweenValidationComparer="kendo.spreadsheet.betweenValidationComparer|The text of the between validation comparer"
            betweenValidationComparer="between"
            i18n-notBetweenValidationComparer="kendo.spreadsheet.notBetweenValidationComparer|The text of the not between validation comparer"
            notBetweenValidationComparer="not between"
            i18n-equalToValidationComparer="kendo.spreadsheet.equalToValidationComparer|The text of the equal to validation comparer"
            equalToValidationComparer="equal to"
            i18n-notEqualToValidationComparer="kendo.spreadsheet.notEqualToValidationComparer|The text of the not equal to validation comparer"
            notEqualToValidationComparer="not equal to"
            i18n-greaterThanOrEqualToValidationComparer="kendo.spreadsheet.greaterThanOrEqualToValidationComparer|The text of the greater than on equal to validation comparer"
            greaterThanOrEqualToValidationComparer="greater than or equal to"
            i18n-lessThanOrEqualToValidationComparer="kendo.spreadsheet.lessThanOrEqualToValidationComparer|The text of the less than on equal to validation comparer"
            lessThanOrEqualToValidationComparer="less than or equal to"
            i18n-italic="kendo.spreadsheet.italic|The title of the Italic tool."
            italic="Italic"
            i18n-underline="kendo.spreadsheet.underline|The title of the Underline tool."
            underline="Underline"
            i18n-loadFile="kendo.spreadsheet.loadFile|The title of the Load File tool."
            loadFile="Open..."
            i18n-saveFile="kendo.spreadsheet.saveFile|The title of the Save File tool."
            saveFile="Export..."
            i18n-format="kendo.spreadsheet.format|The text of the Format tool."
            format="Custom format..."
            i18n-fontFamily="kendo.spreadsheet.fontFamily|The text of the Font Family tool."
            fontFamily="Font"
            i18n-fontSize="kendo.spreadsheet.fontSize|The text of the Font Size tool."
            fontSize="Font size"
            i18n-home="kendo.spreadsheet.home|The text of the Home toolbar tab."
            home="Home"
            i18n-file="kendo.spreadsheet.file|The text of the File toolbar tab."
            file="File"
            i18n-insert="kendo.spreadsheet.insert|The text of the Insert toolbar tab."
            insert="Insert"
            i18n-formatTab="kendo.spreadsheet.formatTab|The text of the Format toolbar tab."
            formatTab="Format"
            i18n-dataTab="kendo.spreadsheet.dataTab|The text of the Data toolbar tab."
            dataTab="Data"
            i18n-view="kendo.spreadsheet.view|The text of the View toolbar tab."
            view="View"
            i18n-undo="kendo.spreadsheet.undo|The title of the Undo tool."
            undo="Undo"
            i18n-redo="kendo.spreadsheet.redo|The title of the Redo tool."
            redo="Redo"
            i18n-gridLines="kendo.spreadsheet.gridLines|The title of the Grid Lines tool."
            gridLines="Toggle grid lines"
            i18n-addColumnLeft="kendo.spreadsheet.addColumnLeft|The title of the tool that adds new column before currently selected column."
            addColumnLeft="Add column left"
            i18n-addColumnRight="kendo.spreadsheet.addColumnRight|The title of the tool that adds new column after currently selected column."
            addColumnRight="Add column right"
            i18n-addRowBelow="kendo.spreadsheet.addRowBelow|The title of the tool that adds new row below currently selected row."
            addRowBelow="Add row below"
            i18n-addRowAbove="kendo.spreadsheet.addRowAbove|The title of the tool that adds new row above currently selected row."
            addRowAbove="Add row above"
            i18n-deleteColumn="kendo.spreadsheet.deleteColumn|The title of the tool that deletes a column."
            deleteColumn="Delete column"
            i18n-deleteRow="kendo.spreadsheet.deleteRow|The title of the tool that deletes a row."
            deleteRow="Delete row"
            i18n-wrap="kendo.spreadsheet.wrap|The title of the Text Wrap tool."
            wrap="Text wrap"
            i18n-align="kendo.spreadsheet.align|The title of the Text Align tool."
            align="Align"
            i18n-alignHorizontal="kendo.spreadsheet.alignHorizontal|The title of the Text Align Horizontal tool."
            alignHorizontal="Align horizontally"
            i18n-alignVertical="kendo.spreadsheet.alignVertical|The title of the Text Align Vertical tool."
            alignVertical="Align vertically"
            i18n-alignLeft="kendo.spreadsheet.alignLeft|The title of the Text Align Left tool."
            alignLeft="Align Left"
            i18n-alignCenter="kendo.spreadsheet.alignCenter|The title of the Text Align Center tool."
            alignCenter="Align Center"
            i18n-alignRight="kendo.spreadsheet.alignRight|The title of the Text Align Right tool."
            alignRight="Align Right"
            i18n-alignJustify="kendo.spreadsheet.alignJustify|The title of the Text Align Justify tool."
            alignJustify="Align Justify"
            i18n-alignTop="kendo.spreadsheet.alignTop|The title of the Text Align Top tool."
            alignTop="Align Top"
            i18n-alignMiddle="kendo.spreadsheet.alignMiddle|The title of the Text Align Middle tool."
            alignMiddle="Align Middle"
            i18n-alignBottom="kendo.spreadsheet.alignBottom|The title of the Text Align Bottom tool."
            alignBottom="Align Bottom"
            i18n-merge="kendo.spreadsheet.merge|The title of the Cells Merge tool."
            merge="Merge"
            i18n-mergeAll="kendo.spreadsheet.mergeAll|The title of the Merge all tool."
            mergeAll="Merge all"
            i18n-mergeHorizontally="kendo.spreadsheet.mergeHorizontally|The title of the Merge horizontally tool."
            mergeHorizontally="Merge horizontally"
            i18n-mergeVertically="kendo.spreadsheet.mergeVertically|The title of the Merge vertically tool."
            mergeVertically="Merge vertically"
            i18n-unmerge="kendo.spreadsheet.unmerge|The title of the Unmerge tool."
            unmerge="Unmerge"
            i18n-insertLink="kendo.spreadsheet.insertLink|The title of the tool that inserts a link."
            insertLink="Insert link"
            i18n-decreaseDecimal="kendo.spreadsheet.decreaseDecimal|The title of the tool that decreases decimals."
            decreaseDecimal="Decrease decimal"
            i18n-increaseDecimal="kendo.spreadsheet.increaseDecimal|The title of the tool that increases decimals."
            increaseDecimal="Increase decimal"
            i18n-increaseFontSize="kendo.spreadsheet.increaseFontSize|The title of the tool that increases the cell font size."
            increaseFontSize="Increase font size"
            i18n-decreaseFontSize="kendo.spreadsheet.decreaseFontSize|The title of the tool that decreases the cell font size."
            decreaseFontSize="Decrease font size"
            i18n-dialogApply="kendo.spreadsheet.dialogApply|The text of the **Apply** button in all Spreadsheet dialogs."
            dialogApply="Apply"
            i18n-dialogCancel="kendo.spreadsheet.dialogCancel|The text of the **Cancel** button in all Spreadsheet dialogs."
            dialogCancel="Cancel"
            i18n-dialogDelete="kendo.spreadsheet.dialogDelete|The text of the **Delete** button in the Delete sheet dialog."
            dialogDelete="Delete"
            i18n-dialogRename="kendo.spreadsheet.dialogRename|The text of the **Rename** button in the Rename sheet dialog."
            dialogRename="Rename"
            i18n-dialogInsert="kendo.spreadsheet.dialogInsert|The text of the **Insert** button in all Spreadsheet dialogs."
            dialogInsert="Insert"
            i18n-dialogRemove="kendo.spreadsheet.dialogRemove|The text of the **Remove** button in all Spreadsheet dialogs."
            dialogRemove="Remove"
            i18n-dialogRemoveLink="kendo.spreadsheet.dialogRemoveLink|The text of the **Remove link** button in the Link tool dialog."
            dialogRemoveLink="Remove link"
            i18n-rename="kendo.spreadsheet.rename|The title of the Rename sheet dialog."
            rename="Rename Sheet"
            i18n-delete="kendo.spreadsheet.delete|The title of the Delete sheet dialog."
            delete="Delete Sheet"
            i18n-nameBox="kendo.spreadsheet.nameBox|The title of the Name Box input."
            nameBox="Name Box"
            i18n-formulaInput="kendo.spreadsheet.formulaInput|The title of the Formula input."
            formulaInput="Formula Input"
            i18n-addSheet="kendo.spreadsheet.addSheet|The title of the Add new sheet button."
            addSheet="Add New Sheet"
            i18n-sheetsMenu="kendo.spreadsheet.sheetsMenu|The title of the Sheets menu button."
            sheetsMenu="All Sheets"
            i18n-openUnsupported="kendo.spreadsheet.openUnsupported|The content of the dialog that warns about an unsupported file type."
            openUnsupported="Unsupported format. Please select an .xlsx file."
            i18n-modifyMerged="kendo.spreadsheet.modifyMerged|The content of the dialog that warns about modifying a merged cell."
            modifyMerged="Cannot change part of a merged cell."
            i18n-cannotModifyDisabled="kendo.spreadsheet.cannotModifyDisabled|The content of the dialog that warns about modifying a disabled cell."
            cannotModifyDisabled="Cannot modify disabled cells."
            i18n-dialogOk="kendo.spreadsheet.dialogOk|The text of the **OK** dialog button."
            dialogOk="OK"
            i18n-dialogError="kendo.spreadsheet.dialogError|The title of an error dialog."
            dialogError="Error"
            i18n-duplicateSheetName="kendo.spreadsheet.duplicateSheetName|The content of the dialog that warns about duplicated sheet name."
            duplicateSheetName="There is an existing sheet with this name. Please enter another name."
            i18n-copy="kendo.spreadsheet.copy|The Copy command text."
            copy="Copy"
            i18n-cut="kendo.spreadsheet.cut|The Cut command text."
            cut="Cut"
            i18n-paste="kendo.spreadsheet.paste|The Paste command text."
            paste="Paste (use Ctrl/⌘ + V)"
            i18n-hideRow="kendo.spreadsheet.hideRow|The Hide row command text."
            hideRow="Hide"
            i18n-unhideRow="kendo.spreadsheet.unhideRow|The Unhide row command text."
            unhideRow="Unhide"
            i18n-hideColumn="kendo.spreadsheet.hideColumn|The Hide column command text."
            hideColumn="Hide"
            i18n-unhideColumn="kendo.spreadsheet.unhideColumn|The Unhide column command text."
            unhideColumn="Unhide"
            i18n-sheetDelete="kendo.spreadsheet.sheetDelete|The text of the Sheet menu Delete option."
            sheetDelete="Delete"
            i18n-sheetRename="kendo.spreadsheet.sheetRename|The text of the Sheet menu Rename option."
            sheetRename="Rename"
            i18n-sheetDuplicate="kendo.spreadsheet.sheetDuplicate|The text of the Sheet menu Duplicate option."
            sheetDuplicate="Duplicate"
            i18n-sheetHide="kendo.spreadsheet.sheetHide|The text of the Sheet menu Hide option."
            sheetHide="Hide"
            i18n-sheetMoveLeft="kendo.spreadsheet.sheetMoveLeft|The text of the Sheet menu Move Left option."
            sheetMoveLeft="Move Left"
            i18n-sheetMoveRight="kendo.spreadsheet.sheetMoveRight|The text of the Sheet menu Move Right option."
            sheetMoveRight="Move Right"
            i18n-invalidNameError="kendo.spreadsheet.invalidNameError|The content of the dialog that warns about invalid name input."
            invalidNameError="{{ 'Invalid name: {inputValue}' }}">
        </ng-container>
        <div class="k-spreadsheet-header">
            <kendo-menu kendoSpreadsheetMenu (select)="onMenuItemSelect($event)">
                <kendo-menu-item *ngFor="let item of menuItems" [text]="item.text" [cssClass]="item.cssClass"></kendo-menu-item>
            </kendo-menu>
            <kendo-toolbar *ngIf="selectedMenuItem?.active && selectedMenuItem.id === 'file'"
                [attr.aria-label]="messageFor('file')"
                fillMode="flat"
                class="k-spreadsheet-toolbar"
                [overflow]="overflow">
                <kendo-spreadsheet-load-file-tool></kendo-spreadsheet-load-file-tool>
                <kendo-toolbar-button kendoSpreadsheetSaveFile></kendo-toolbar-button>
            </kendo-toolbar>
            <kendo-toolbar *ngIf="selectedMenuItem?.active && selectedMenuItem.id === 'home'"
                [attr.aria-label]="messageFor('home')"
                class="k-spreadsheet-toolbar"
                fillMode="flat"
                [overflow]="overflow">
                <kendo-toolbar-button kendoSpreadsheetUndo></kendo-toolbar-button>
                <kendo-toolbar-button kendoSpreadsheetRedo></kendo-toolbar-button>
                <kendo-toolbar-separator></kendo-toolbar-separator>
                <kendo-toolbar-dropdownlist kendoSpreadsheetFontFamily></kendo-toolbar-dropdownlist>
                <kendo-toolbar-dropdownlist kendoSpreadsheetFontSize></kendo-toolbar-dropdownlist>
                <kendo-toolbar-buttongroup fillMode="flat">
                    <kendo-toolbar-button kendoSpreadsheetIncreaseFontSize></kendo-toolbar-button>
                    <kendo-toolbar-button kendoSpreadsheetDecreaseFontSize></kendo-toolbar-button>
                </kendo-toolbar-buttongroup>
                <kendo-toolbar-separator></kendo-toolbar-separator>
                <kendo-toolbar-buttongroup fillMode="flat">
                    <kendo-toolbar-button kendoSpreadsheetBold></kendo-toolbar-button>
                    <kendo-toolbar-button kendoSpreadsheetItalic></kendo-toolbar-button>
                    <kendo-toolbar-button kendoSpreadsheetUnderline></kendo-toolbar-button>
                </kendo-toolbar-buttongroup>
                <kendo-spreadsheet-forecolor-tool></kendo-spreadsheet-forecolor-tool>
                <kendo-toolbar-separator></kendo-toolbar-separator>
                <kendo-spreadsheet-backcolor-tool></kendo-spreadsheet-backcolor-tool>
                <kendo-toolbar-separator></kendo-toolbar-separator>
                <kendo-toolbar-dropdownbutton kendoSpreadsheetHorizontalTextAlign></kendo-toolbar-dropdownbutton>
                <kendo-toolbar-dropdownbutton kendoSpreadsheetVerticalTextAlign></kendo-toolbar-dropdownbutton>
                <kendo-toolbar-button kendoSpreadsheetTextWrap></kendo-toolbar-button>
                <kendo-toolbar-separator></kendo-toolbar-separator>
                <kendo-toolbar-dropdownbutton kendoSpreadsheetFormat></kendo-toolbar-dropdownbutton>
            </kendo-toolbar>
            <kendo-toolbar *ngIf="selectedMenuItem?.active && selectedMenuItem.id === 'insert'"
                [attr.aria-label]="messageFor('insert')"
                fillMode="flat"
                class="k-spreadsheet-toolbar"
                [overflow]="overflow">
                <kendo-toolbar-button kendoSpreadsheetInsertLink></kendo-toolbar-button>
                <kendo-toolbar-separator></kendo-toolbar-separator>
                <kendo-toolbar-button kendoSpreadsheetAddColumnLeftButton></kendo-toolbar-button>
                <kendo-toolbar-button kendoSpreadsheetAddColumnRightButton></kendo-toolbar-button>
                <kendo-toolbar-button kendoSpreadsheetAddRowBelowButton></kendo-toolbar-button>
                <kendo-toolbar-button kendoSpreadsheetAddRowAboveButton></kendo-toolbar-button>
                <kendo-toolbar-separator></kendo-toolbar-separator>
                <kendo-toolbar-button kendoSpreadsheetDeleteColumnButton></kendo-toolbar-button>
                <kendo-toolbar-button kendoSpreadsheetDeleteRowButton></kendo-toolbar-button>
            </kendo-toolbar>
            <kendo-toolbar *ngIf="selectedMenuItem?.active && selectedMenuItem.id === 'format'"
                [attr.aria-label]="messageFor('formatTab')"
                fillMode="flat"
                class="k-spreadsheet-toolbar"
                [overflow]="overflow">
                <kendo-toolbar-button kendoSpreadsheetDecreaseDecimal></kendo-toolbar-button>
                <kendo-toolbar-button kendoSpreadsheetIncreaseDecimal></kendo-toolbar-button>
            </kendo-toolbar>
            <kendo-toolbar *ngIf="selectedMenuItem?.active && selectedMenuItem.id === 'view'"
                [attr.aria-label]="messageFor('view')"
                fillMode="flat"
                class="k-spreadsheet-toolbar"
                [overflow]="overflow">
                <kendo-toolbar-dropdownbutton kendoSpreadsheetMerge></kendo-toolbar-dropdownbutton>
                <kendo-toolbar-separator></kendo-toolbar-separator>
                <kendo-toolbar-button kendoSpreadsheetGridLines></kendo-toolbar-button>
            </kendo-toolbar>
            <kendo-toolbar *ngIf="selectedMenuItem?.active && selectedMenuItem.id === 'data'"
                [attr.aria-label]="messageFor('dataTab')"
                fillMode="flat"
                class="k-spreadsheet-toolbar"
                [overflow]="overflow">
                <kendo-toolbar-button kendoSpreadsheetDataValidation></kendo-toolbar-button>
            </kendo-toolbar>
        </div>
        <div class="k-spreadsheet-action-bar">
            <div #nameBox kendoSpreadsheetNameBox [spreadsheetWidget]="spreadsheetWidget"></div>
            <div class="k-spreadsheet-formula-bar">
                <span class="k-separator k-separator-vertical"></span>
                <kendo-icon-wrapper
                    name="formula-fx"
                    [svgIcon]="formulaFxIcon">
                </kendo-icon-wrapper>
                <span class="k-separator k-separator-vertical"></span>
                <div
                    #formulaBar
                    kendoSpreadsheetFormulaInput
                    [formulaListMaxHeight]="formulaListMaxHeight"
                    class="k-textbox k-input k-input-md k-input-flat k-rounded-md"></div>
            </div>
        </div>
        <div class="k-spreadsheet-view">
            <div class="k-spreadsheet-fixed-container"></div>
                <div class="k-spreadsheet-scroller">
                    <div class="k-spreadsheet-view-size"></div>
                </div>
            <div tabIndex="0" class="k-spreadsheet-clipboard" contentEditable="true"></div>
            <div #formulaCell kendoSpreadsheetFormulaInput class="k-spreadsheet-cell-editor" data-role="formulainput"></div>
        </div>
        <div class="k-spreadsheet-sheets-bar"
            kendoSpreadsheetSheetsBar
            [sheets]="sheetsInfo"
            [sheetDescriptors]="sheets">
        </div>
        <ng-container #dialogContainer></ng-container>

        <kendo-contextmenu
            #contextMenu
            [items]="contextMenuItems"
            (select)="onContextMenuSelect($event)"></kendo-contextmenu>

        <div kendoWatermarkOverlay *ngIf="showLicenseWatermark"></div>
    `,
                    standalone: true,
                    imports: [LocalizedMessagesDirective, MenuComponent, MainMenuDirective, NgFor, MenuItemComponent, NgIf, ToolBarComponent, SpreadsheetLoadFileComponent, ToolBarButtonComponent, SpreadsheetSaveFileDirective, ToolBarButtonGroupComponent, SpreadsheetUndoDirective, SpreadsheetRedoDirective, ToolBarSeparatorComponent, SpreadsheetFontFamilyComponent, SpreadsheetFontSizeComponent, SpreadsheetIncreaseFontSizeDirective, SpreadsheetDecreaseFontSizeDirective, SpreadsheetBoldDirective, SpreadsheetItalicDirective, SpreadsheetUnderlineDirective, SpreadsheetForeColorComponent, SpreadsheetBackColorComponent, ToolBarDropDownButtonComponent, SpreadsheetHorizontalTextAlignDirective, SpreadsheetVerticalTextAlignDirective, SpreadsheetTextWrapDirective, SpreadsheetFormatDirective, SpreadsheetInsertLinkDirective, SpreadsheetAddColumnLeftButtonDirective, SpreadsheetAddColumnRightButtonDirective, SpreadsheetAddRowBelowButtonDirective, SpreadsheetAddRowAboveButtonDirective, SpreadsheetDeleteColumnButtonDirective, SpreadsheetDeleteRowButtonDirective, SpreadsheetDecreaseDecimalDirective, SpreadsheetIncreaseDecimalDirective, SpreadsheetMergeDirective, SpreadsheetGridLinesDirective, NameBoxComponent, IconWrapperComponent, FormulaInputDirective, SheetsBarComponent, ContextMenuComponent, WatermarkOverlayComponent, SpreadsheetDataValidationDirective]
                }]
        }], ctorParameters: function () { return [{ type: i0.NgZone }, { type: i1$4.IntlService }, { type: i0.ElementRef }, { type: i1.LocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }, { type: ErrorHandlingService }, { type: i1$2.DialogService }, { type: i1$1.PopupService }, { type: i0.ViewContainerRef }]; }, propDecorators: { formulaBarInputRef: [{
                type: ViewChild,
                args: ['formulaBar', { read: FormulaInputDirective }]
            }], formulaCellInputRef: [{
                type: ViewChild,
                args: ['formulaCell', { read: FormulaInputDirective }]
            }], nameBoxRef: [{
                type: ViewChild,
                args: ['nameBox']
            }], dialogContainer: [{
                type: ViewChild,
                args: ['dialogContainer', { read: ViewContainerRef }]
            }], contextMenu: [{
                type: ViewChild,
                args: ['contextMenu']
            }], hostClass: [{
                type: HostBinding,
                args: ['class.k-spreadsheet']
            }], role: [{
                type: HostBinding,
                args: ['attr.role']
            }], menuItems: [{
                type: Input
            }], overflow: [{
                type: Input
            }], formulaListMaxHeight: [{
                type: Input
            }], activeSheet: [{
                type: Input
            }], sheets: [{
                type: Input
            }], columns: [{
                type: Input
            }], columnWidth: [{
                type: Input
            }], defaultCellStyle: [{
                type: Input
            }], headerHeight: [{
                type: Input
            }], headerWidth: [{
                type: Input
            }], rowHeight: [{
                type: Input
            }], rows: [{
                type: Input
            }], images: [{
                type: Input
            }], excel: [{
                type: Input
            }], change: [{
                type: Output
            }], formatChange: [{
                type: Output
            }], selectionChange: [{
                type: Output
            }], excelExport: [{
                type: Output
            }], excelImport: [{
                type: Output
            }], activeSheetChange: [{
                type: Output
            }] } });

/**
 * Custom component messages override default component messages.
 */
class CustomMessagesComponent extends MessagesDirective {
    service;
    constructor(service) {
        super();
        this.service = service;
    }
    get override() {
        return true;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CustomMessagesComponent, deps: [{ token: i1.LocalizationService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: CustomMessagesComponent, isStandalone: true, selector: "kendo-spreadsheet-messages", providers: [
            {
                provide: MessagesDirective,
                useExisting: forwardRef(() => CustomMessagesComponent)
            }
        ], usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: CustomMessagesComponent, decorators: [{
            type: Directive,
            args: [{
                    providers: [
                        {
                            provide: MessagesDirective,
                            useExisting: forwardRef(() => CustomMessagesComponent)
                        }
                    ],
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: 'kendo-spreadsheet-messages',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1.LocalizationService }]; } });

/**
 * @hidden
 */
class SpreadsheetTextAlignDirective {
    host;
    spreadsheetService;
    toolsService;
    commandName = 'align';
    subs = new Subscription();
    constructor(host, localization, spreadsheetService, toolsService) {
        this.host = host;
        this.spreadsheetService = spreadsheetService;
        this.toolsService = toolsService;
        host.svgIcon = commandSVGIcons[this.commandName];
        host.icon = commandIcons[this.commandName];
        host.arrowIcon = true;
        host.fillMode = 'flat';
        host.data = ALIGNS.map(item => ({ ...item, textKey: localization.get(item.commandId) }));
        this.subs.add(host.itemClick.subscribe((e) => this.onItemClick(e)));
        host.title = localization.get(this.commandName);
        host.textField = 'textKey';
    }
    ngOnInit() {
        this.subs.add(this.toolsService.stateChange.subscribe(state => this.host.data.forEach(i => i.cssClass = i.value === state[i.commandName] ? 'k-selected' : '')));
    }
    ngOnDestroy() {
        this.subs.unsubscribe();
    }
    onItemClick(item) {
        const value = item.value || null;
        const options = {
            command: 'PropertyChangeCommand', options: { property: item.commandName, value }
        };
        this.spreadsheetService.spreadsheet.executeCommand(options);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetTextAlignDirective, deps: [{ token: i1$3.ToolBarDropDownButtonComponent }, { token: SpreadsheetLocalizationService }, { token: SpreadsheetService }, { token: SpreadsheetToolsService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: SpreadsheetTextAlignDirective, isStandalone: true, selector: "[kendoSpreadsheetTextAlign]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetTextAlignDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoSpreadsheetTextAlign]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$3.ToolBarDropDownButtonComponent }, { type: SpreadsheetLocalizationService }, { type: SpreadsheetService }, { type: SpreadsheetToolsService }]; } });

/**
* Utility array that contains all `@progress/kendo-angular-spreadsheet` related components and directives.
*/
const KENDO_SPREADSHEET = [
    SpreadsheetComponent,
    CustomMessagesComponent,
    SpreadsheetBoldDirective,
    SpreadsheetDataValidationDirective,
    SpreadsheetItalicDirective,
    SpreadsheetUnderlineDirective,
    SpreadsheetLoadFileComponent,
    SpreadsheetSaveFileDirective,
    SpreadsheetFormatDirective,
    SpreadsheetUndoDirective,
    SpreadsheetRedoDirective,
    SpreadsheetFontFamilyComponent,
    SpreadsheetFontSizeComponent,
    SpreadsheetBackColorComponent,
    SpreadsheetForeColorComponent,
    SpreadsheetGridLinesDirective,
    SpreadsheetAddColumnLeftButtonDirective,
    SpreadsheetAddColumnRightButtonDirective,
    SpreadsheetAddRowAboveButtonDirective,
    SpreadsheetAddRowBelowButtonDirective,
    SpreadsheetDeleteColumnButtonDirective,
    SpreadsheetDeleteRowButtonDirective,
    SpreadsheetTextAlignDirective,
    SpreadsheetTextWrapDirective,
    SpreadsheetMergeDirective,
    SpreadsheetInsertLinkDirective,
    SpreadsheetIncreaseFontSizeDirective,
    SpreadsheetDecreaseFontSizeDirective,
    SpreadsheetIncreaseDecimalDirective,
    SpreadsheetDecreaseDecimalDirective,
    SpreadsheetHorizontalTextAlignDirective,
    SpreadsheetVerticalTextAlignDirective
];

// IMPORTANT: NgModule export kept for backwards compatibility
/**
 * Represents the [NgModule](link:site.data.urls.angular['ngmoduleapi'])
 * definition for the Spreadsheet component.
 */
class SpreadsheetModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetModule, imports: [SpreadsheetComponent, CustomMessagesComponent, SpreadsheetBoldDirective, SpreadsheetDataValidationDirective, SpreadsheetItalicDirective, SpreadsheetUnderlineDirective, SpreadsheetLoadFileComponent, SpreadsheetSaveFileDirective, SpreadsheetFormatDirective, SpreadsheetUndoDirective, SpreadsheetRedoDirective, SpreadsheetFontFamilyComponent, SpreadsheetFontSizeComponent, SpreadsheetBackColorComponent, SpreadsheetForeColorComponent, SpreadsheetGridLinesDirective, SpreadsheetAddColumnLeftButtonDirective, SpreadsheetAddColumnRightButtonDirective, SpreadsheetAddRowAboveButtonDirective, SpreadsheetAddRowBelowButtonDirective, SpreadsheetDeleteColumnButtonDirective, SpreadsheetDeleteRowButtonDirective, SpreadsheetTextAlignDirective, SpreadsheetTextWrapDirective, SpreadsheetMergeDirective, SpreadsheetInsertLinkDirective, SpreadsheetIncreaseFontSizeDirective, SpreadsheetDecreaseFontSizeDirective, SpreadsheetIncreaseDecimalDirective, SpreadsheetDecreaseDecimalDirective, SpreadsheetHorizontalTextAlignDirective, SpreadsheetVerticalTextAlignDirective], exports: [SpreadsheetComponent, CustomMessagesComponent, SpreadsheetBoldDirective, SpreadsheetDataValidationDirective, SpreadsheetItalicDirective, SpreadsheetUnderlineDirective, SpreadsheetLoadFileComponent, SpreadsheetSaveFileDirective, SpreadsheetFormatDirective, SpreadsheetUndoDirective, SpreadsheetRedoDirective, SpreadsheetFontFamilyComponent, SpreadsheetFontSizeComponent, SpreadsheetBackColorComponent, SpreadsheetForeColorComponent, SpreadsheetGridLinesDirective, SpreadsheetAddColumnLeftButtonDirective, SpreadsheetAddColumnRightButtonDirective, SpreadsheetAddRowAboveButtonDirective, SpreadsheetAddRowBelowButtonDirective, SpreadsheetDeleteColumnButtonDirective, SpreadsheetDeleteRowButtonDirective, SpreadsheetTextAlignDirective, SpreadsheetTextWrapDirective, SpreadsheetMergeDirective, SpreadsheetInsertLinkDirective, SpreadsheetIncreaseFontSizeDirective, SpreadsheetDecreaseFontSizeDirective, SpreadsheetIncreaseDecimalDirective, SpreadsheetDecreaseDecimalDirective, SpreadsheetHorizontalTextAlignDirective, SpreadsheetVerticalTextAlignDirective] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetModule, providers: [IconsService, PopupService, ResizeBatchService, DialogContainerService, DialogService, WindowService, WindowContainerService], imports: [SpreadsheetComponent, SpreadsheetLoadFileComponent, SpreadsheetFontFamilyComponent, SpreadsheetFontSizeComponent, SpreadsheetBackColorComponent, SpreadsheetForeColorComponent] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: SpreadsheetModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [...KENDO_SPREADSHEET],
                    imports: [...KENDO_SPREADSHEET],
                    providers: [IconsService, PopupService, ResizeBatchService, DialogContainerService, DialogService, WindowService, WindowContainerService]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { CustomMessagesComponent, FormulaInputDirective, FormulaListComponent, KENDO_SPREADSHEET, NameBoxComponent, SheetsBarComponent, SpreadsheetAddColumnLeftButtonDirective, SpreadsheetAddColumnRightButtonDirective, SpreadsheetAddRowAboveButtonDirective, SpreadsheetAddRowBelowButtonDirective, SpreadsheetBackColorComponent, SpreadsheetBoldDirective, SpreadsheetComponent, SpreadsheetDataValidationDirective, SpreadsheetDecreaseDecimalDirective, SpreadsheetDecreaseFontSizeDirective, SpreadsheetDeleteColumnButtonDirective, SpreadsheetDeleteRowButtonDirective, SpreadsheetFontFamilyComponent, SpreadsheetFontSizeComponent, SpreadsheetForeColorComponent, SpreadsheetFormatDirective, SpreadsheetGridLinesDirective, SpreadsheetHorizontalTextAlignDirective, SpreadsheetIncreaseDecimalDirective, SpreadsheetIncreaseFontSizeDirective, SpreadsheetInsertLinkDirective, SpreadsheetItalicDirective, SpreadsheetLoadFileComponent, SpreadsheetMergeDirective, SpreadsheetModule, SpreadsheetRedoDirective, SpreadsheetSaveFileDirective, SpreadsheetTextAlignDirective, SpreadsheetTextWrapDirective, SpreadsheetUnderlineDirective, SpreadsheetUndoDirective, SpreadsheetVerticalTextAlignDirective };

